@charset "UTF-8";
/* Styles https://github.com/publichealthengland/coronavirus-dashboard via source: https://coronavirus.data.gov.uk/*/
/*# sourceMappingURL=_assets.scss.map */
/*# sourceMappingURL=_warnings.scss.map */
/*# sourceMappingURL=_compatibility.scss.map */
/*# sourceMappingURL=_global-styles.scss.map */
/*# sourceMappingURL=_ie8.scss.map */
/*# sourceMappingURL=_media-queries.scss.map */
/*# sourceMappingURL=_compatibility.scss.map */
/*# sourceMappingURL=_colours-palette.scss.map */
/*# sourceMappingURL=_colours-organisations.scss.map */
/*# sourceMappingURL=_compatibility.scss.map */
/*# sourceMappingURL=_compatibility.scss.map */
/*# sourceMappingURL=_colours-palette.scss.map */
/*# sourceMappingURL=_colours-organisations.scss.map */
/*# sourceMappingURL=_colour.scss.map */
/*# sourceMappingURL=_colours-applied.scss.map */
/*# sourceMappingURL=_spacing.scss.map */
/*# sourceMappingURL=_measurements.scss.map */
/*# sourceMappingURL=_typography-font-families.scss.map */
/*# sourceMappingURL=_compatibility.scss.map */
/*# sourceMappingURL=_typography-font-families.scss.map */
/*# sourceMappingURL=_typography-font.scss.map */
/*# sourceMappingURL=_compatibility.scss.map */
/*# sourceMappingURL=_typography-responsive.scss.map */
/*# sourceMappingURL=_links.scss.map */
/*# sourceMappingURL=_all.scss.map */
/*# sourceMappingURL=_compatibility.scss.map */
/*# sourceMappingURL=_exports.scss.map */
/*# sourceMappingURL=_font-url.scss.map */
/*# sourceMappingURL=_warnings.scss.map */
/*# sourceMappingURL=_ie8.scss.map */
/*# sourceMappingURL=_image-url.scss.map */
/*# sourceMappingURL=_px-to-em.scss.map */ /*# sourceMappingURL=_px-to-rem.scss.map */
/*# sourceMappingURL=_all.scss.map */
/*# sourceMappingURL=_clearfix.scss.map */
/*# sourceMappingURL=_compatibility.scss.map */
/*# sourceMappingURL=_compatibility.scss.map */
/*# sourceMappingURL=_colours-palette.scss.map */
/*# sourceMappingURL=_colours-organisations.scss.map */
/*# sourceMappingURL=_colour.scss.map */
/*# sourceMappingURL=_device-pixels.scss.map */
/*# sourceMappingURL=_focused.scss.map */ /*# sourceMappingURL=_exports.scss.map */
/*# sourceMappingURL=_font-faces.scss.map */
/*# sourceMappingURL=_grid.scss.map */
/*# sourceMappingURL=_links.scss.map */
/*# sourceMappingURL=_sass-mq.scss.map */
/*# sourceMappingURL=_media-queries.scss.map */
/*# sourceMappingURL=_shape-arrow.scss.map */
/*# sourceMappingURL=_spacing.scss.map */
/*# sourceMappingURL=_px-to-rem.scss.map */
/*# sourceMappingURL=_typography.scss.map */
/*# sourceMappingURL=_visually-hidden.scss.map */
/*# sourceMappingURL=_all.scss.map */
/*# sourceMappingURL=_base.scss.map */
:root {
  --govuk-frontend-version: "4.9.0";
}

/*# sourceMappingURL=_govuk-frontend-version.scss.map */
.govuk-link {
  font-family: Arial, sans-serif;
  -webkit-font-smoothing: antialiased;
  -moz-osx-font-smoothing: grayscale;
  text-decoration: underline;
}
@media print {
  .govuk-link {
    font-family: sans-serif;
  }
}
.govuk-link:focus {
  outline: 3px solid transparent;
  color: #0b0c0c;
  background-color: #ffdd00;
  box-shadow: 0 -2px #ffdd00, 0 4px #0b0c0c;
  text-decoration: none;
  -webkit-box-decoration-break: clone;
  box-decoration-break: clone;
}
.govuk-link:link {
  color: #1d70b8;
}
.govuk-link:visited {
  color: #4c2c92;
}
.govuk-link:hover {
  color: #003078;
}
.govuk-link:active {
  color: #0b0c0c;
}
.govuk-link:focus {
  color: #0b0c0c;
}
@media print {
  [href^="/"].govuk-link:after, [href^="http://"].govuk-link:after, [href^="https://"].govuk-link:after {
    content: " (" attr(href) ")";
    font-size: 90%;
    word-wrap: break-word;
  }
}

.govuk-link--muted:link, .govuk-link--muted:visited {
  color: #6B7276;
}
.govuk-link--muted:hover, .govuk-link--muted:active {
  color: #0b0c0c;
}
.govuk-link--muted:focus {
  color: #0b0c0c;
}

.govuk-link--text-colour:link, .govuk-link--text-colour:visited {
  color: #0b0c0c;
}
@media print {
  .govuk-link--text-colour:link, .govuk-link--text-colour:visited {
    color: #000000;
  }
}
.govuk-link--text-colour:hover {
  color: rgba(11, 12, 12, 0.99);
}
.govuk-link--text-colour:active, .govuk-link--text-colour:focus {
  color: #0b0c0c;
}
@media print {
  .govuk-link--text-colour:active, .govuk-link--text-colour:focus {
    color: #000000;
  }
}

.govuk-link--inverse:link, .govuk-link--inverse:visited {
  color: #ffffff;
}
.govuk-link--inverse:hover, .govuk-link--inverse:active {
  color: rgba(255, 255, 255, 0.99);
}
.govuk-link--inverse:focus {
  color: #0b0c0c;
}

.govuk-link--no-underline:not(:hover):not(:active) {
  text-decoration: none;
}

.govuk-link--no-visited-state:link {
  color: #1d70b8;
}
.govuk-link--no-visited-state:visited {
  color: #1d70b8;
}
.govuk-link--no-visited-state:hover {
  color: #003078;
}
.govuk-link--no-visited-state:active {
  color: #0b0c0c;
}
.govuk-link--no-visited-state:focus {
  color: #0b0c0c;
}

/*# sourceMappingURL=_links.scss.map */
.govuk-list {
  font-family: Arial, sans-serif;
  -webkit-font-smoothing: antialiased;
  -moz-osx-font-smoothing: grayscale;
  font-weight: 400;
  font-size: 16px;
  font-size: 1rem;
  line-height: 1.25;
  color: #0b0c0c;
  margin-top: 0;
  margin-bottom: 15px;
  padding-left: 0;
  list-style-type: none;
}
@media print {
  .govuk-list {
    font-family: sans-serif;
  }
}
@media (min-width: 40.0625em) {
  .govuk-list {
    font-size: 19px;
    font-size: 1.1875rem;
    line-height: 1.3157894737;
  }
}
@media print {
  .govuk-list {
    font-size: 14pt;
    line-height: 1.15;
  }
}
@media print {
  .govuk-list {
    color: #000000;
  }
}
@media (min-width: 40.0625em) {
  .govuk-list {
    margin-bottom: 20px;
  }
}
.govuk-list .govuk-list {
  margin-top: 10px;
}

.govuk-list > li {
  margin-bottom: 5px;
}

.govuk-list--bullet {
  padding-left: 20px;
  list-style-type: disc;
}

.govuk-list--number {
  padding-left: 20px;
  list-style-type: decimal;
}

.govuk-list--bullet > li,
.govuk-list--number > li {
  margin-bottom: 0;
}
@media (min-width: 40.0625em) {
  .govuk-list--bullet > li,
.govuk-list--number > li {
    margin-bottom: 5px;
  }
}

.govuk-list--spaced > li {
  margin-bottom: 10px;
}
@media (min-width: 40.0625em) {
  .govuk-list--spaced > li {
    margin-bottom: 15px;
  }
}

/*# sourceMappingURL=_lists.scss.map */
.govuk-heading-xl {
  color: #0b0c0c;
  font-family: Arial, sans-serif;
  -webkit-font-smoothing: antialiased;
  -moz-osx-font-smoothing: grayscale;
  font-weight: 700;
  font-size: 32px;
  font-size: 2rem;
  line-height: 1.09375;
  display: block;
  margin-top: 0;
  margin-bottom: 30px;
}
@media print {
  .govuk-heading-xl {
    color: #000000;
  }
}
@media print {
  .govuk-heading-xl {
    font-family: sans-serif;
  }
}
@media (min-width: 40.0625em) {
  .govuk-heading-xl {
    font-size: 48px;
    font-size: 3rem;
    line-height: 1.0416666667;
  }
}
@media print {
  .govuk-heading-xl {
    font-size: 32pt;
    line-height: 1.15;
  }
}
@media (min-width: 40.0625em) {
  .govuk-heading-xl {
    margin-bottom: 50px;
  }
}

.govuk-heading-l {
  color: #0b0c0c;
  font-family: Arial, sans-serif;
  -webkit-font-smoothing: antialiased;
  -moz-osx-font-smoothing: grayscale;
  font-weight: 700;
  font-size: 24px;
  font-size: 1.5rem;
  line-height: 1.0416666667;
  display: block;
  margin-top: 0;
  margin-bottom: 20px;
}
@media print {
  .govuk-heading-l {
    color: #000000;
  }
}
@media print {
  .govuk-heading-l {
    font-family: sans-serif;
  }
}
@media (min-width: 40.0625em) {
  .govuk-heading-l {
    font-size: 36px;
    font-size: 2.25rem;
    line-height: 1.1111111111;
  }
}
@media print {
  .govuk-heading-l {
    font-size: 24pt;
    line-height: 1.05;
  }
}
@media (min-width: 40.0625em) {
  .govuk-heading-l {
    margin-bottom: 30px;
  }
}

.govuk-heading-m {
  color: #0b0c0c;
  font-family: Arial, sans-serif;
  -webkit-font-smoothing: antialiased;
  -moz-osx-font-smoothing: grayscale;
  font-weight: 700;
  font-size: 18px;
  font-size: 1.125rem;
  line-height: 1.1111111111;
  display: block;
  margin-top: 0;
  margin-bottom: 15px;
}
@media print {
  .govuk-heading-m {
    color: #000000;
  }
}
@media print {
  .govuk-heading-m {
    font-family: sans-serif;
  }
}
@media (min-width: 40.0625em) {
  .govuk-heading-m {
    font-size: 24px;
    font-size: 1.5rem;
    line-height: 1.25;
  }
}
@media print {
  .govuk-heading-m {
    font-size: 18pt;
    line-height: 1.15;
  }
}
@media (min-width: 40.0625em) {
  .govuk-heading-m {
    margin-bottom: 20px;
  }
}

.govuk-heading-s {
  color: #0b0c0c;
  font-family: Arial, sans-serif;
  -webkit-font-smoothing: antialiased;
  -moz-osx-font-smoothing: grayscale;
  font-weight: 700;
  font-size: 16px;
  font-size: 1rem;
  line-height: 1.25;
  display: block;
  margin-top: 0;
  margin-bottom: 15px;
}
@media print {
  .govuk-heading-s {
    color: #000000;
  }
}
@media print {
  .govuk-heading-s {
    font-family: sans-serif;
  }
}
@media (min-width: 40.0625em) {
  .govuk-heading-s {
    font-size: 19px;
    font-size: 1.1875rem;
    line-height: 1.3157894737;
  }
}
@media print {
  .govuk-heading-s {
    font-size: 14pt;
    line-height: 1.15;
  }
}
@media (min-width: 40.0625em) {
  .govuk-heading-s {
    margin-bottom: 20px;
  }
}

.govuk-caption-xl {
  font-family: Arial, sans-serif;
  -webkit-font-smoothing: antialiased;
  -moz-osx-font-smoothing: grayscale;
  font-weight: 400;
  font-size: 18px;
  font-size: 1.125rem;
  line-height: 1.1111111111;
  display: block;
  margin-bottom: 5px;
  color: #6B7276;
}
@media print {
  .govuk-caption-xl {
    font-family: sans-serif;
  }
}
@media (min-width: 40.0625em) {
  .govuk-caption-xl {
    font-size: 27px;
    font-size: 1.6875rem;
    line-height: 1.1111111111;
  }
}
@media print {
  .govuk-caption-xl {
    font-size: 18pt;
    line-height: 1.15;
  }
}

.govuk-caption-l {
  font-family: Arial, sans-serif;
  -webkit-font-smoothing: antialiased;
  -moz-osx-font-smoothing: grayscale;
  font-weight: 400;
  font-size: 18px;
  font-size: 1.125rem;
  line-height: 1.1111111111;
  display: block;
  margin-bottom: 5px;
  color: #6B7276;
}
@media print {
  .govuk-caption-l {
    font-family: sans-serif;
  }
}
@media (min-width: 40.0625em) {
  .govuk-caption-l {
    font-size: 24px;
    font-size: 1.5rem;
    line-height: 1.25;
  }
}
@media print {
  .govuk-caption-l {
    font-size: 18pt;
    line-height: 1.15;
  }
}
@media (min-width: 40.0625em) {
  .govuk-caption-l {
    margin-bottom: 0;
  }
}

.govuk-caption-m {
  font-family: Arial, sans-serif;
  -webkit-font-smoothing: antialiased;
  -moz-osx-font-smoothing: grayscale;
  font-weight: 400;
  font-size: 16px;
  font-size: 1rem;
  line-height: 1.25;
  display: block;
  color: #6B7276;
}
@media print {
  .govuk-caption-m {
    font-family: sans-serif;
  }
}
@media (min-width: 40.0625em) {
  .govuk-caption-m {
    font-size: 19px;
    font-size: 1.1875rem;
    line-height: 1.3157894737;
  }
}
@media print {
  .govuk-caption-m {
    font-size: 14pt;
    line-height: 1.15;
  }
}

.govuk-body-lead, .govuk-body-l {
  color: #0b0c0c;
  font-family: Arial, sans-serif;
  -webkit-font-smoothing: antialiased;
  -moz-osx-font-smoothing: grayscale;
  font-weight: 400;
  font-size: 18px;
  font-size: 1.125rem;
  line-height: 1.1111111111;
  margin-top: 0;
  margin-bottom: 20px;
}
@media print {
  .govuk-body-lead, .govuk-body-l {
    color: #000000;
  }
}
@media print {
  .govuk-body-lead, .govuk-body-l {
    font-family: sans-serif;
  }
}
@media (min-width: 40.0625em) {
  .govuk-body-lead, .govuk-body-l {
    font-size: 24px;
    font-size: 1.5rem;
    line-height: 1.25;
  }
}
@media print {
  .govuk-body-lead, .govuk-body-l {
    font-size: 18pt;
    line-height: 1.15;
  }
}
@media (min-width: 40.0625em) {
  .govuk-body-lead, .govuk-body-l {
    margin-bottom: 30px;
  }
}

.govuk-body, .govuk-body-m {
  color: #0b0c0c;
  font-family: Arial, sans-serif;
  -webkit-font-smoothing: antialiased;
  -moz-osx-font-smoothing: grayscale;
  font-weight: 400;
  font-size: 16px;
  font-size: 1rem;
  line-height: 1.25;
  margin-top: 0;
  margin-bottom: 15px;
}
@media print {
  .govuk-body, .govuk-body-m {
    color: #000000;
  }
}
@media print {
  .govuk-body, .govuk-body-m {
    font-family: sans-serif;
  }
}
@media (min-width: 40.0625em) {
  .govuk-body, .govuk-body-m {
    font-size: 19px;
    font-size: 1.1875rem;
    line-height: 1.3157894737;
  }
}
@media print {
  .govuk-body, .govuk-body-m {
    font-size: 14pt;
    line-height: 1.15;
  }
}
@media (min-width: 40.0625em) {
  .govuk-body, .govuk-body-m {
    margin-bottom: 20px;
  }
}

.govuk-body-s {
  color: #0b0c0c;
  font-family: Arial, sans-serif;
  -webkit-font-smoothing: antialiased;
  -moz-osx-font-smoothing: grayscale;
  font-weight: 400;
  font-size: 14px;
  font-size: 0.875rem;
  line-height: 1.1428571429;
  margin-top: 0;
  margin-bottom: 15px;
}
@media print {
  .govuk-body-s {
    color: #000000;
  }
}
@media print {
  .govuk-body-s {
    font-family: sans-serif;
  }
}
@media (min-width: 40.0625em) {
  .govuk-body-s {
    font-size: 16px;
    font-size: 1rem;
    line-height: 1.25;
  }
}
@media print {
  .govuk-body-s {
    font-size: 14pt;
    line-height: 1.2;
  }
}
@media (min-width: 40.0625em) {
  .govuk-body-s {
    margin-bottom: 20px;
  }
}

.govuk-body-xs {
  color: #0b0c0c;
  font-family: Arial, sans-serif;
  -webkit-font-smoothing: antialiased;
  -moz-osx-font-smoothing: grayscale;
  font-weight: 400;
  font-size: 12px;
  font-size: 0.75rem;
  line-height: 1.25;
  margin-top: 0;
  margin-bottom: 15px;
}
@media print {
  .govuk-body-xs {
    color: #000000;
  }
}
@media print {
  .govuk-body-xs {
    font-family: sans-serif;
  }
}
@media (min-width: 40.0625em) {
  .govuk-body-xs {
    font-size: 14px;
    font-size: 0.875rem;
    line-height: 1.4285714286;
  }
}
@media print {
  .govuk-body-xs {
    font-size: 12pt;
    line-height: 1.2;
  }
}
@media (min-width: 40.0625em) {
  .govuk-body-xs {
    margin-bottom: 20px;
  }
}

.govuk-body-l + .govuk-heading-l, .govuk-body-lead + .govuk-heading-l {
  padding-top: 5px;
}
@media (min-width: 40.0625em) {
  .govuk-body-l + .govuk-heading-l, .govuk-body-lead + .govuk-heading-l {
    padding-top: 10px;
  }
}

.govuk-body-m + .govuk-heading-l, .govuk-body + .govuk-heading-l,
.govuk-body-s + .govuk-heading-l,
.govuk-list + .govuk-heading-l {
  padding-top: 15px;
}
@media (min-width: 40.0625em) {
  .govuk-body-m + .govuk-heading-l, .govuk-body + .govuk-heading-l,
.govuk-body-s + .govuk-heading-l,
.govuk-list + .govuk-heading-l {
    padding-top: 20px;
  }
}

.govuk-body-m + .govuk-heading-m, .govuk-body + .govuk-heading-m,
.govuk-body-s + .govuk-heading-m,
.govuk-list + .govuk-heading-m,
.govuk-body-m + .govuk-heading-s,
.govuk-body + .govuk-heading-s,
.govuk-body-s + .govuk-heading-s,
.govuk-list + .govuk-heading-s {
  padding-top: 5px;
}
@media (min-width: 40.0625em) {
  .govuk-body-m + .govuk-heading-m, .govuk-body + .govuk-heading-m,
.govuk-body-s + .govuk-heading-m,
.govuk-list + .govuk-heading-m,
.govuk-body-m + .govuk-heading-s,
.govuk-body + .govuk-heading-s,
.govuk-body-s + .govuk-heading-s,
.govuk-list + .govuk-heading-s {
    padding-top: 10px;
  }
}

/*# sourceMappingURL=_typography.scss.map */
.govuk-section-break {
  margin: 0;
  border: 0;
}

.govuk-section-break--xl {
  margin-top: 30px;
  margin-bottom: 30px;
}
@media (min-width: 40.0625em) {
  .govuk-section-break--xl {
    margin-top: 50px;
  }
}
@media (min-width: 40.0625em) {
  .govuk-section-break--xl {
    margin-bottom: 50px;
  }
}

.govuk-section-break--l {
  margin-top: 20px;
  margin-bottom: 20px;
}
@media (min-width: 40.0625em) {
  .govuk-section-break--l {
    margin-top: 30px;
  }
}
@media (min-width: 40.0625em) {
  .govuk-section-break--l {
    margin-bottom: 30px;
  }
}

.govuk-section-break--m {
  margin-top: 15px;
  margin-bottom: 15px;
}
@media (min-width: 40.0625em) {
  .govuk-section-break--m {
    margin-top: 20px;
  }
}
@media (min-width: 40.0625em) {
  .govuk-section-break--m {
    margin-bottom: 20px;
  }
}

.govuk-section-break--visible {
  border-bottom: 1px solid #b1b4b6;
}

/*# sourceMappingURL=_section-break.scss.map */
/*# sourceMappingURL=_links.scss.map */
/*# sourceMappingURL=_typography.scss.map */
/*# sourceMappingURL=_global-styles.scss.map */
/*# sourceMappingURL=_all.scss.map */
/*# sourceMappingURL=_assets.scss.map */
/*# sourceMappingURL=_warnings.scss.map */
/*# sourceMappingURL=_compatibility.scss.map */
/*# sourceMappingURL=_global-styles.scss.map */
/*# sourceMappingURL=_ie8.scss.map */
/*# sourceMappingURL=_media-queries.scss.map */
/*# sourceMappingURL=_compatibility.scss.map */
/*# sourceMappingURL=_colours-palette.scss.map */
/*# sourceMappingURL=_colours-organisations.scss.map */
/*# sourceMappingURL=_compatibility.scss.map */
/*# sourceMappingURL=_compatibility.scss.map */
/*# sourceMappingURL=_colours-palette.scss.map */
/*# sourceMappingURL=_colours-organisations.scss.map */
/*# sourceMappingURL=_colour.scss.map */
/*# sourceMappingURL=_colours-applied.scss.map */
/*# sourceMappingURL=_spacing.scss.map */
/*# sourceMappingURL=_measurements.scss.map */
/*# sourceMappingURL=_typography-font-families.scss.map */
/*# sourceMappingURL=_compatibility.scss.map */
/*# sourceMappingURL=_typography-font-families.scss.map */
/*# sourceMappingURL=_typography-font.scss.map */
/*# sourceMappingURL=_compatibility.scss.map */
/*# sourceMappingURL=_typography-responsive.scss.map */
/*# sourceMappingURL=_links.scss.map */
/*# sourceMappingURL=_all.scss.map */
/*# sourceMappingURL=_compatibility.scss.map */
/*# sourceMappingURL=_exports.scss.map */
/*# sourceMappingURL=_font-url.scss.map */
/*# sourceMappingURL=_warnings.scss.map */
/*# sourceMappingURL=_ie8.scss.map */
/*# sourceMappingURL=_image-url.scss.map */
/*# sourceMappingURL=_px-to-em.scss.map */ /*# sourceMappingURL=_px-to-rem.scss.map */
/*# sourceMappingURL=_all.scss.map */
/*# sourceMappingURL=_clearfix.scss.map */
/*# sourceMappingURL=_compatibility.scss.map */
/*# sourceMappingURL=_compatibility.scss.map */
/*# sourceMappingURL=_colours-palette.scss.map */
/*# sourceMappingURL=_colours-organisations.scss.map */
/*# sourceMappingURL=_colour.scss.map */
/*# sourceMappingURL=_device-pixels.scss.map */
/*# sourceMappingURL=_focused.scss.map */ /*# sourceMappingURL=_exports.scss.map */
/*# sourceMappingURL=_font-faces.scss.map */
/*# sourceMappingURL=_grid.scss.map */
/*# sourceMappingURL=_links.scss.map */
/*# sourceMappingURL=_sass-mq.scss.map */
/*# sourceMappingURL=_media-queries.scss.map */
/*# sourceMappingURL=_shape-arrow.scss.map */
/*# sourceMappingURL=_spacing.scss.map */
/*# sourceMappingURL=_px-to-rem.scss.map */
/*# sourceMappingURL=_typography.scss.map */
/*# sourceMappingURL=_visually-hidden.scss.map */
/*# sourceMappingURL=_all.scss.map */
/*# sourceMappingURL=_base.scss.map */
.govuk-button-group {
  margin-bottom: 5px;
  display: -ms-flexbox;
  display: flex;
  -ms-flex-direction: column;
  flex-direction: column;
  -ms-flex-align: center;
  align-items: center;
}
@media (min-width: 40.0625em) {
  .govuk-button-group {
    margin-bottom: 15px;
  }
}
.govuk-button-group .govuk-link {
  font-family: Arial, sans-serif;
  -webkit-font-smoothing: antialiased;
  -moz-osx-font-smoothing: grayscale;
  font-weight: 400;
  font-size: 16px;
  font-size: 1rem;
  line-height: 1.1875;
  display: inline-block;
  max-width: 100%;
  margin-top: 5px;
  margin-bottom: 20px;
  text-align: center;
}
@media print {
  .govuk-button-group .govuk-link {
    font-family: sans-serif;
  }
}
@media (min-width: 40.0625em) {
  .govuk-button-group .govuk-link {
    font-size: 19px;
    font-size: 1.1875rem;
    line-height: 1;
  }
}
@media print {
  .govuk-button-group .govuk-link {
    font-size: 14pt;
    line-height: 19px;
  }
}
.govuk-button-group .govuk-button {
  margin-bottom: 17px;
}
@media (min-width: 40.0625em) {
  .govuk-button-group {
    margin-right: -15px;
    -ms-flex-direction: row;
    flex-direction: row;
    -ms-flex-wrap: wrap;
    flex-wrap: wrap;
    -ms-flex-align: baseline;
    align-items: baseline;
  }
  .govuk-button-group .govuk-button,
.govuk-button-group .govuk-link {
    margin-right: 15px;
  }
  .govuk-button-group .govuk-link {
    text-align: left;
  }
}

/*# sourceMappingURL=_button-group.scss.map */
/*# sourceMappingURL=_assets.scss.map */
/*# sourceMappingURL=_warnings.scss.map */
/*# sourceMappingURL=_compatibility.scss.map */
/*# sourceMappingURL=_global-styles.scss.map */
/*# sourceMappingURL=_ie8.scss.map */
/*# sourceMappingURL=_media-queries.scss.map */
/*# sourceMappingURL=_compatibility.scss.map */
/*# sourceMappingURL=_colours-palette.scss.map */
/*# sourceMappingURL=_colours-organisations.scss.map */
/*# sourceMappingURL=_compatibility.scss.map */
/*# sourceMappingURL=_compatibility.scss.map */
/*# sourceMappingURL=_colours-palette.scss.map */
/*# sourceMappingURL=_colours-organisations.scss.map */
/*# sourceMappingURL=_colour.scss.map */
/*# sourceMappingURL=_colours-applied.scss.map */
/*# sourceMappingURL=_spacing.scss.map */
/*# sourceMappingURL=_measurements.scss.map */
/*# sourceMappingURL=_typography-font-families.scss.map */
/*# sourceMappingURL=_compatibility.scss.map */
/*# sourceMappingURL=_typography-font-families.scss.map */
/*# sourceMappingURL=_typography-font.scss.map */
/*# sourceMappingURL=_compatibility.scss.map */
/*# sourceMappingURL=_typography-responsive.scss.map */
/*# sourceMappingURL=_links.scss.map */
/*# sourceMappingURL=_all.scss.map */
/*# sourceMappingURL=_compatibility.scss.map */
/*# sourceMappingURL=_exports.scss.map */
/*# sourceMappingURL=_font-url.scss.map */
/*# sourceMappingURL=_warnings.scss.map */
/*# sourceMappingURL=_ie8.scss.map */
/*# sourceMappingURL=_image-url.scss.map */
/*# sourceMappingURL=_px-to-em.scss.map */ /*# sourceMappingURL=_px-to-rem.scss.map */
/*# sourceMappingURL=_all.scss.map */
/*# sourceMappingURL=_clearfix.scss.map */
/*# sourceMappingURL=_compatibility.scss.map */
/*# sourceMappingURL=_compatibility.scss.map */
/*# sourceMappingURL=_colours-palette.scss.map */
/*# sourceMappingURL=_colours-organisations.scss.map */
/*# sourceMappingURL=_colour.scss.map */
/*# sourceMappingURL=_device-pixels.scss.map */
/*# sourceMappingURL=_focused.scss.map */ /*# sourceMappingURL=_exports.scss.map */
/*# sourceMappingURL=_font-faces.scss.map */
/*# sourceMappingURL=_grid.scss.map */
/*# sourceMappingURL=_links.scss.map */
/*# sourceMappingURL=_sass-mq.scss.map */
/*# sourceMappingURL=_media-queries.scss.map */
/*# sourceMappingURL=_shape-arrow.scss.map */
/*# sourceMappingURL=_spacing.scss.map */
/*# sourceMappingURL=_px-to-rem.scss.map */
/*# sourceMappingURL=_typography.scss.map */
/*# sourceMappingURL=_visually-hidden.scss.map */
/*# sourceMappingURL=_all.scss.map */
/*# sourceMappingURL=_base.scss.map */
.govuk-form-group {
  margin-bottom: 20px;
}
.govuk-form-group:after {
  content: "";
  display: block;
  clear: both;
}
@media (min-width: 40.0625em) {
  .govuk-form-group {
    margin-bottom: 30px;
  }
}
.govuk-form-group .govuk-form-group:last-of-type {
  margin-bottom: 0;
}

.govuk-form-group--error {
  padding-left: 15px;
  border-left: 5px solid #d4351c;
}
.govuk-form-group--error .govuk-form-group {
  padding: 0;
  border: 0;
}

/*# sourceMappingURL=_form-group.scss.map */
/*# sourceMappingURL=_assets.scss.map */
/*# sourceMappingURL=_warnings.scss.map */
/*# sourceMappingURL=_compatibility.scss.map */
/*# sourceMappingURL=_global-styles.scss.map */
/*# sourceMappingURL=_ie8.scss.map */
/*# sourceMappingURL=_media-queries.scss.map */
/*# sourceMappingURL=_compatibility.scss.map */
/*# sourceMappingURL=_colours-palette.scss.map */
/*# sourceMappingURL=_colours-organisations.scss.map */
/*# sourceMappingURL=_compatibility.scss.map */
/*# sourceMappingURL=_compatibility.scss.map */
/*# sourceMappingURL=_colours-palette.scss.map */
/*# sourceMappingURL=_colours-organisations.scss.map */
/*# sourceMappingURL=_colour.scss.map */
/*# sourceMappingURL=_colours-applied.scss.map */
/*# sourceMappingURL=_spacing.scss.map */
/*# sourceMappingURL=_measurements.scss.map */
/*# sourceMappingURL=_typography-font-families.scss.map */
/*# sourceMappingURL=_compatibility.scss.map */
/*# sourceMappingURL=_typography-font-families.scss.map */
/*# sourceMappingURL=_typography-font.scss.map */
/*# sourceMappingURL=_compatibility.scss.map */
/*# sourceMappingURL=_typography-responsive.scss.map */
/*# sourceMappingURL=_links.scss.map */
/*# sourceMappingURL=_all.scss.map */
/*# sourceMappingURL=_compatibility.scss.map */
/*# sourceMappingURL=_exports.scss.map */
/*# sourceMappingURL=_font-url.scss.map */
/*# sourceMappingURL=_warnings.scss.map */
/*# sourceMappingURL=_ie8.scss.map */
/*# sourceMappingURL=_image-url.scss.map */
/*# sourceMappingURL=_px-to-em.scss.map */ /*# sourceMappingURL=_px-to-rem.scss.map */
/*# sourceMappingURL=_all.scss.map */
/*# sourceMappingURL=_clearfix.scss.map */
/*# sourceMappingURL=_compatibility.scss.map */
/*# sourceMappingURL=_compatibility.scss.map */
/*# sourceMappingURL=_colours-palette.scss.map */
/*# sourceMappingURL=_colours-organisations.scss.map */
/*# sourceMappingURL=_colour.scss.map */
/*# sourceMappingURL=_device-pixels.scss.map */
/*# sourceMappingURL=_focused.scss.map */ /*# sourceMappingURL=_exports.scss.map */
/*# sourceMappingURL=_font-faces.scss.map */
/*# sourceMappingURL=_grid.scss.map */
/*# sourceMappingURL=_links.scss.map */
/*# sourceMappingURL=_sass-mq.scss.map */
/*# sourceMappingURL=_media-queries.scss.map */
/*# sourceMappingURL=_shape-arrow.scss.map */
/*# sourceMappingURL=_spacing.scss.map */
/*# sourceMappingURL=_px-to-rem.scss.map */
/*# sourceMappingURL=_typography.scss.map */
/*# sourceMappingURL=_visually-hidden.scss.map */
/*# sourceMappingURL=_all.scss.map */
/*# sourceMappingURL=_base.scss.map */
.govuk-grid-row {
  margin-right: -15px;
  margin-left: -15px;
}
.govuk-grid-row:after {
  content: "";
  display: block;
  clear: both;
}

.govuk-grid-column-one-quarter {
  box-sizing: border-box;
  width: 100%;
  padding: 0 15px;
}
@media (min-width: 40.0625em) {
  .govuk-grid-column-one-quarter {
    width: 25%;
    float: left;
  }
}

.govuk-grid-column-one-third {
  box-sizing: border-box;
  width: 100%;
  padding: 0 15px;
}
@media (min-width: 40.0625em) {
  .govuk-grid-column-one-third {
    width: 33.3333333333%;
    float: left;
  }
}

.govuk-grid-column-one-half {
  box-sizing: border-box;
  width: 100%;
  padding: 0 15px;
}
@media (min-width: 40.0625em) {
  .govuk-grid-column-one-half {
    width: 50%;
    float: left;
  }
}

.govuk-grid-column-two-thirds {
  box-sizing: border-box;
  width: 100%;
  padding: 0 15px;
}
@media (min-width: 40.0625em) {
  .govuk-grid-column-two-thirds {
    width: 66.6666666667%;
    float: left;
  }
}

.govuk-grid-column-three-quarters {
  box-sizing: border-box;
  width: 100%;
  padding: 0 15px;
}
@media (min-width: 40.0625em) {
  .govuk-grid-column-three-quarters {
    width: 75%;
    float: left;
  }
}

.govuk-grid-column-full {
  box-sizing: border-box;
  width: 100%;
  padding: 0 15px;
}
@media (min-width: 40.0625em) {
  .govuk-grid-column-full {
    width: 100%;
    float: left;
  }
}

.govuk-grid-column-one-quarter-from-desktop {
  box-sizing: border-box;
  padding: 0 15px;
}
@media (min-width: 48.0625em) {
  .govuk-grid-column-one-quarter-from-desktop {
    width: 25%;
    float: left;
  }
}

.govuk-grid-column-one-third-from-desktop {
  box-sizing: border-box;
  padding: 0 15px;
}
@media (min-width: 48.0625em) {
  .govuk-grid-column-one-third-from-desktop {
    width: 33.3333333333%;
    float: left;
  }
}

.govuk-grid-column-one-half-from-desktop {
  box-sizing: border-box;
  padding: 0 15px;
}
@media (min-width: 48.0625em) {
  .govuk-grid-column-one-half-from-desktop {
    width: 50%;
    float: left;
  }
}

.govuk-grid-column-two-thirds-from-desktop {
  box-sizing: border-box;
  padding: 0 15px;
}
@media (min-width: 48.0625em) {
  .govuk-grid-column-two-thirds-from-desktop {
    width: 66.6666666667%;
    float: left;
  }
}

.govuk-grid-column-three-quarters-from-desktop {
  box-sizing: border-box;
  padding: 0 15px;
}
@media (min-width: 48.0625em) {
  .govuk-grid-column-three-quarters-from-desktop {
    width: 75%;
    float: left;
  }
}

.govuk-grid-column-full-from-desktop {
  box-sizing: border-box;
  padding: 0 15px;
}
@media (min-width: 48.0625em) {
  .govuk-grid-column-full-from-desktop {
    width: 100%;
    float: left;
  }
}

/*# sourceMappingURL=_grid.scss.map */
/*# sourceMappingURL=_assets.scss.map */
/*# sourceMappingURL=_warnings.scss.map */
/*# sourceMappingURL=_compatibility.scss.map */
/*# sourceMappingURL=_global-styles.scss.map */
/*# sourceMappingURL=_ie8.scss.map */
/*# sourceMappingURL=_media-queries.scss.map */
/*# sourceMappingURL=_compatibility.scss.map */
/*# sourceMappingURL=_colours-palette.scss.map */
/*# sourceMappingURL=_colours-organisations.scss.map */
/*# sourceMappingURL=_compatibility.scss.map */
/*# sourceMappingURL=_compatibility.scss.map */
/*# sourceMappingURL=_colours-palette.scss.map */
/*# sourceMappingURL=_colours-organisations.scss.map */
/*# sourceMappingURL=_colour.scss.map */
/*# sourceMappingURL=_colours-applied.scss.map */
/*# sourceMappingURL=_spacing.scss.map */
/*# sourceMappingURL=_measurements.scss.map */
/*# sourceMappingURL=_typography-font-families.scss.map */
/*# sourceMappingURL=_compatibility.scss.map */
/*# sourceMappingURL=_typography-font-families.scss.map */
/*# sourceMappingURL=_typography-font.scss.map */
/*# sourceMappingURL=_compatibility.scss.map */
/*# sourceMappingURL=_typography-responsive.scss.map */
/*# sourceMappingURL=_links.scss.map */
/*# sourceMappingURL=_all.scss.map */
/*# sourceMappingURL=_compatibility.scss.map */
/*# sourceMappingURL=_exports.scss.map */
/*# sourceMappingURL=_font-url.scss.map */
/*# sourceMappingURL=_warnings.scss.map */
/*# sourceMappingURL=_ie8.scss.map */
/*# sourceMappingURL=_image-url.scss.map */
/*# sourceMappingURL=_px-to-em.scss.map */ /*# sourceMappingURL=_px-to-rem.scss.map */
/*# sourceMappingURL=_all.scss.map */
/*# sourceMappingURL=_clearfix.scss.map */
/*# sourceMappingURL=_compatibility.scss.map */
/*# sourceMappingURL=_compatibility.scss.map */
/*# sourceMappingURL=_colours-palette.scss.map */
/*# sourceMappingURL=_colours-organisations.scss.map */
/*# sourceMappingURL=_colour.scss.map */
/*# sourceMappingURL=_device-pixels.scss.map */
/*# sourceMappingURL=_focused.scss.map */ /*# sourceMappingURL=_exports.scss.map */
/*# sourceMappingURL=_font-faces.scss.map */
/*# sourceMappingURL=_grid.scss.map */
/*# sourceMappingURL=_links.scss.map */
/*# sourceMappingURL=_sass-mq.scss.map */
/*# sourceMappingURL=_media-queries.scss.map */
/*# sourceMappingURL=_shape-arrow.scss.map */
/*# sourceMappingURL=_spacing.scss.map */
/*# sourceMappingURL=_px-to-rem.scss.map */
/*# sourceMappingURL=_typography.scss.map */
/*# sourceMappingURL=_visually-hidden.scss.map */
/*# sourceMappingURL=_all.scss.map */
/*# sourceMappingURL=_base.scss.map */
.govuk-main-wrapper {
  display: block;
  padding-top: 20px;
  padding-bottom: 20px;
}
@media (min-width: 40.0625em) {
  .govuk-main-wrapper {
    padding-top: 40px;
    padding-bottom: 40px;
  }
}

.govuk-main-wrapper--auto-spacing:first-child,
.govuk-main-wrapper--l {
  padding-top: 30px;
}
@media (min-width: 40.0625em) {
  .govuk-main-wrapper--auto-spacing:first-child,
.govuk-main-wrapper--l {
    padding-top: 50px;
  }
}

/*# sourceMappingURL=_main-wrapper.scss.map */
/*# sourceMappingURL=_assets.scss.map */
/*# sourceMappingURL=_warnings.scss.map */
/*# sourceMappingURL=_compatibility.scss.map */
/*# sourceMappingURL=_global-styles.scss.map */
/*# sourceMappingURL=_ie8.scss.map */
/*# sourceMappingURL=_media-queries.scss.map */
/*# sourceMappingURL=_compatibility.scss.map */
/*# sourceMappingURL=_colours-palette.scss.map */
/*# sourceMappingURL=_colours-organisations.scss.map */
/*# sourceMappingURL=_compatibility.scss.map */
/*# sourceMappingURL=_compatibility.scss.map */
/*# sourceMappingURL=_colours-palette.scss.map */
/*# sourceMappingURL=_colours-organisations.scss.map */
/*# sourceMappingURL=_colour.scss.map */
/*# sourceMappingURL=_colours-applied.scss.map */
/*# sourceMappingURL=_spacing.scss.map */
/*# sourceMappingURL=_measurements.scss.map */
/*# sourceMappingURL=_typography-font-families.scss.map */
/*# sourceMappingURL=_compatibility.scss.map */
/*# sourceMappingURL=_typography-font-families.scss.map */
/*# sourceMappingURL=_typography-font.scss.map */
/*# sourceMappingURL=_compatibility.scss.map */
/*# sourceMappingURL=_typography-responsive.scss.map */
/*# sourceMappingURL=_links.scss.map */
/*# sourceMappingURL=_all.scss.map */
/*# sourceMappingURL=_compatibility.scss.map */
/*# sourceMappingURL=_exports.scss.map */
/*# sourceMappingURL=_font-url.scss.map */
/*# sourceMappingURL=_warnings.scss.map */
/*# sourceMappingURL=_ie8.scss.map */
/*# sourceMappingURL=_image-url.scss.map */
/*# sourceMappingURL=_px-to-em.scss.map */ /*# sourceMappingURL=_px-to-rem.scss.map */
/*# sourceMappingURL=_all.scss.map */
/*# sourceMappingURL=_clearfix.scss.map */
/*# sourceMappingURL=_compatibility.scss.map */
/*# sourceMappingURL=_compatibility.scss.map */
/*# sourceMappingURL=_colours-palette.scss.map */
/*# sourceMappingURL=_colours-organisations.scss.map */
/*# sourceMappingURL=_colour.scss.map */
/*# sourceMappingURL=_device-pixels.scss.map */
/*# sourceMappingURL=_focused.scss.map */ /*# sourceMappingURL=_exports.scss.map */
/*# sourceMappingURL=_font-faces.scss.map */
/*# sourceMappingURL=_grid.scss.map */
/*# sourceMappingURL=_links.scss.map */
/*# sourceMappingURL=_sass-mq.scss.map */
/*# sourceMappingURL=_media-queries.scss.map */
/*# sourceMappingURL=_shape-arrow.scss.map */
/*# sourceMappingURL=_spacing.scss.map */
/*# sourceMappingURL=_px-to-rem.scss.map */
/*# sourceMappingURL=_typography.scss.map */
/*# sourceMappingURL=_visually-hidden.scss.map */
/*# sourceMappingURL=_all.scss.map */
/*# sourceMappingURL=_base.scss.map */
.govuk-template {
  background-color: #f3f2f1;
  -webkit-text-size-adjust: 100%;
  -moz-text-size-adjust: 100%;
  text-size-adjust: 100%;
}
@supports (position: -webkit-sticky) or (position: sticky) {
  .govuk-template {
    scroll-padding-top: 60px;
  }
  .govuk-template:not(:has(.govuk-exit-this-page)) {
    scroll-padding-top: 0;
  }
}
@media screen {
  .govuk-template {
    overflow-y: scroll;
  }
}

.govuk-template__body {
  margin: 0;
  background-color: #ffffff;
}

/*# sourceMappingURL=_template.scss.map */
/*# sourceMappingURL=_assets.scss.map */
/*# sourceMappingURL=_warnings.scss.map */
/*# sourceMappingURL=_compatibility.scss.map */
/*# sourceMappingURL=_global-styles.scss.map */
/*# sourceMappingURL=_ie8.scss.map */
/*# sourceMappingURL=_media-queries.scss.map */
/*# sourceMappingURL=_compatibility.scss.map */
/*# sourceMappingURL=_colours-palette.scss.map */
/*# sourceMappingURL=_colours-organisations.scss.map */
/*# sourceMappingURL=_compatibility.scss.map */
/*# sourceMappingURL=_compatibility.scss.map */
/*# sourceMappingURL=_colours-palette.scss.map */
/*# sourceMappingURL=_colours-organisations.scss.map */
/*# sourceMappingURL=_colour.scss.map */
/*# sourceMappingURL=_colours-applied.scss.map */
/*# sourceMappingURL=_spacing.scss.map */
/*# sourceMappingURL=_measurements.scss.map */
/*# sourceMappingURL=_typography-font-families.scss.map */
/*# sourceMappingURL=_compatibility.scss.map */
/*# sourceMappingURL=_typography-font-families.scss.map */
/*# sourceMappingURL=_typography-font.scss.map */
/*# sourceMappingURL=_compatibility.scss.map */
/*# sourceMappingURL=_typography-responsive.scss.map */
/*# sourceMappingURL=_links.scss.map */
/*# sourceMappingURL=_all.scss.map */
/*# sourceMappingURL=_compatibility.scss.map */
/*# sourceMappingURL=_exports.scss.map */
/*# sourceMappingURL=_font-url.scss.map */
/*# sourceMappingURL=_warnings.scss.map */
/*# sourceMappingURL=_ie8.scss.map */
/*# sourceMappingURL=_image-url.scss.map */
/*# sourceMappingURL=_px-to-em.scss.map */ /*# sourceMappingURL=_px-to-rem.scss.map */
/*# sourceMappingURL=_all.scss.map */
/*# sourceMappingURL=_clearfix.scss.map */
/*# sourceMappingURL=_compatibility.scss.map */
/*# sourceMappingURL=_compatibility.scss.map */
/*# sourceMappingURL=_colours-palette.scss.map */
/*# sourceMappingURL=_colours-organisations.scss.map */
/*# sourceMappingURL=_colour.scss.map */
/*# sourceMappingURL=_device-pixels.scss.map */
/*# sourceMappingURL=_focused.scss.map */ /*# sourceMappingURL=_exports.scss.map */
/*# sourceMappingURL=_font-faces.scss.map */
/*# sourceMappingURL=_grid.scss.map */
/*# sourceMappingURL=_links.scss.map */
/*# sourceMappingURL=_sass-mq.scss.map */
/*# sourceMappingURL=_media-queries.scss.map */
/*# sourceMappingURL=_shape-arrow.scss.map */
/*# sourceMappingURL=_spacing.scss.map */
/*# sourceMappingURL=_px-to-rem.scss.map */
/*# sourceMappingURL=_typography.scss.map */
/*# sourceMappingURL=_visually-hidden.scss.map */
/*# sourceMappingURL=_all.scss.map */
/*# sourceMappingURL=_base.scss.map */
.govuk-width-container {
  max-width: 1920px;
  margin-right: 15px;
  margin-left: 15px;
}
@supports (margin: max(calc(0px))) {
  .govuk-width-container {
    margin-right: max(15px, calc(15px + env(safe-area-inset-right)));
    margin-left: max(15px, calc(15px + env(safe-area-inset-left)));
  }
}
@media (min-width: 40.0625em) {
  .govuk-width-container {
    margin-right: 30px;
    margin-left: 30px;
  }
  @supports (margin: max(calc(0px))) {
    .govuk-width-container {
      margin-right: max(30px, calc(15px + env(safe-area-inset-right)));
      margin-left: max(30px, calc(15px + env(safe-area-inset-left)));
    }
  }
}
@media (min-width: 1980px) {
  .govuk-width-container {
    margin-right: auto;
    margin-left: auto;
  }
  @supports (margin: max(calc(0px))) {
    .govuk-width-container {
      margin-right: auto;
      margin-left: auto;
    }
  }
}

/*# sourceMappingURL=_width-container.scss.map */
/*# sourceMappingURL=_all.scss.map */
/*# sourceMappingURL=_assets.scss.map */
/*# sourceMappingURL=_warnings.scss.map */
/*# sourceMappingURL=_compatibility.scss.map */
/*# sourceMappingURL=_global-styles.scss.map */
/*# sourceMappingURL=_ie8.scss.map */
/*# sourceMappingURL=_media-queries.scss.map */
/*# sourceMappingURL=_compatibility.scss.map */
/*# sourceMappingURL=_colours-palette.scss.map */
/*# sourceMappingURL=_colours-organisations.scss.map */
/*# sourceMappingURL=_compatibility.scss.map */
/*# sourceMappingURL=_compatibility.scss.map */
/*# sourceMappingURL=_colours-palette.scss.map */
/*# sourceMappingURL=_colours-organisations.scss.map */
/*# sourceMappingURL=_colour.scss.map */
/*# sourceMappingURL=_colours-applied.scss.map */
/*# sourceMappingURL=_spacing.scss.map */
/*# sourceMappingURL=_measurements.scss.map */
/*# sourceMappingURL=_typography-font-families.scss.map */
/*# sourceMappingURL=_compatibility.scss.map */
/*# sourceMappingURL=_typography-font-families.scss.map */
/*# sourceMappingURL=_typography-font.scss.map */
/*# sourceMappingURL=_compatibility.scss.map */
/*# sourceMappingURL=_typography-responsive.scss.map */
/*# sourceMappingURL=_links.scss.map */
/*# sourceMappingURL=_all.scss.map */
/*# sourceMappingURL=_compatibility.scss.map */
/*# sourceMappingURL=_exports.scss.map */
/*# sourceMappingURL=_font-url.scss.map */
/*# sourceMappingURL=_warnings.scss.map */
/*# sourceMappingURL=_ie8.scss.map */
/*# sourceMappingURL=_image-url.scss.map */
/*# sourceMappingURL=_px-to-em.scss.map */ /*# sourceMappingURL=_px-to-rem.scss.map */
/*# sourceMappingURL=_all.scss.map */
/*# sourceMappingURL=_clearfix.scss.map */
/*# sourceMappingURL=_compatibility.scss.map */
/*# sourceMappingURL=_compatibility.scss.map */
/*# sourceMappingURL=_colours-palette.scss.map */
/*# sourceMappingURL=_colours-organisations.scss.map */
/*# sourceMappingURL=_colour.scss.map */
/*# sourceMappingURL=_device-pixels.scss.map */
/*# sourceMappingURL=_focused.scss.map */ /*# sourceMappingURL=_exports.scss.map */
/*# sourceMappingURL=_font-faces.scss.map */
/*# sourceMappingURL=_grid.scss.map */
/*# sourceMappingURL=_links.scss.map */
/*# sourceMappingURL=_sass-mq.scss.map */
/*# sourceMappingURL=_media-queries.scss.map */
/*# sourceMappingURL=_shape-arrow.scss.map */
/*# sourceMappingURL=_spacing.scss.map */
/*# sourceMappingURL=_px-to-rem.scss.map */
/*# sourceMappingURL=_typography.scss.map */
/*# sourceMappingURL=_visually-hidden.scss.map */
/*# sourceMappingURL=_all.scss.map */
/*# sourceMappingURL=_base.scss.map */
.govuk-accordion {
  margin-bottom: 20px;
}
@media (min-width: 40.0625em) {
  .govuk-accordion {
    margin-bottom: 30px;
  }
}

.govuk-accordion__section {
  padding-top: 15px;
}

.govuk-accordion__section-heading {
  margin-top: 0;
  margin-bottom: 0;
  padding-top: 15px;
  padding-bottom: 15px;
}

.govuk-accordion__section-button {
  font-family: Arial, sans-serif;
  -webkit-font-smoothing: antialiased;
  -moz-osx-font-smoothing: grayscale;
  font-weight: 700;
  font-size: 18px;
  font-size: 1.125rem;
  line-height: 1.1111111111;
  color: #0b0c0c;
  display: block;
  margin-bottom: 0;
  padding-top: 15px;
}
@media print {
  .govuk-accordion__section-button {
    font-family: sans-serif;
  }
}
@media (min-width: 40.0625em) {
  .govuk-accordion__section-button {
    font-size: 24px;
    font-size: 1.5rem;
    line-height: 1.25;
  }
}
@media print {
  .govuk-accordion__section-button {
    font-size: 18pt;
    line-height: 1.15;
  }
}
@media print {
  .govuk-accordion__section-button {
    color: #000000;
  }
}

.govuk-accordion__section-content > :last-child {
  margin-bottom: 0;
}

.js-enabled .govuk-accordion {
  border-bottom: 1px solid #b1b4b6;
}
.js-enabled .govuk-accordion__section {
  padding-top: 0;
}
.js-enabled .govuk-accordion__section-content {
  display: none;
  padding-top: 15px;
  padding-bottom: 30px;
}
@media (min-width: 40.0625em) {
  .js-enabled .govuk-accordion__section-content {
    padding-bottom: 50px;
  }
}
.js-enabled .govuk-accordion__section-content[hidden] {
  padding-top: 0;
  padding-bottom: 0;
}
@supports (content-visibility: hidden) {
  .js-enabled .govuk-accordion__section-content[hidden] {
    content-visibility: hidden;
    display: inherit;
  }
}
.js-enabled .govuk-accordion__section--expanded .govuk-accordion__section-content {
  display: block;
}
.js-enabled .govuk-accordion__show-all {
  font-family: Arial, sans-serif;
  -webkit-font-smoothing: antialiased;
  -moz-osx-font-smoothing: grayscale;
  font-weight: 400;
  font-size: 16px;
  font-size: 1rem;
  line-height: 1.25;
  position: relative;
  z-index: 1;
  margin-bottom: 9px;
  padding: 5px 2px 5px 0;
  border-width: 0;
  color: #1d70b8;
  background: none;
  cursor: pointer;
  -webkit-appearance: none;
}
@media print {
  .js-enabled .govuk-accordion__show-all {
    font-family: sans-serif;
  }
}
@media (min-width: 40.0625em) {
  .js-enabled .govuk-accordion__show-all {
    font-size: 19px;
    font-size: 1.1875rem;
    line-height: 1.3157894737;
  }
}
@media print {
  .js-enabled .govuk-accordion__show-all {
    font-size: 14pt;
    line-height: 1.15;
  }
}
@media (min-width: 40.0625em) {
  .js-enabled .govuk-accordion__show-all {
    margin-bottom: 14px;
  }
}
.js-enabled .govuk-accordion__show-all::-moz-focus-inner {
  padding: 0;
  border: 0;
}
.js-enabled .govuk-accordion__show-all:hover {
  color: #0b0c0c;
  background: #f3f2f1;
  box-shadow: 0 -2px #f3f2f1, 0 4px #f3f2f1;
}
.js-enabled .govuk-accordion__show-all:hover .govuk-accordion__section-toggle-text {
  color: #0b0c0c;
}
.js-enabled .govuk-accordion__show-all:hover .govuk-accordion-nav__chevron {
  color: #0b0c0c;
  background: #0b0c0c;
}
.js-enabled .govuk-accordion__show-all:hover .govuk-accordion-nav__chevron:after {
  color: #f3f2f1;
}
.js-enabled .govuk-accordion__show-all:focus {
  outline: 3px solid transparent;
  color: #0b0c0c;
  background-color: #ffdd00;
  box-shadow: 0 -2px #ffdd00, 0 4px #0b0c0c;
  text-decoration: none;
  -webkit-box-decoration-break: clone;
  box-decoration-break: clone;
}
.js-enabled .govuk-accordion__show-all:focus .govuk-accordion-nav__chevron {
  background: #0b0c0c;
}
.js-enabled .govuk-accordion__show-all:focus .govuk-accordion-nav__chevron:after {
  color: #ffdd00;
}
.js-enabled .govuk-accordion__section-heading {
  padding: 0;
}
.js-enabled .govuk-accordion-nav__chevron {
  box-sizing: border-box;
  display: inline-block;
  position: relative;
  width: 1.25rem;
  height: 1.25rem;
  border: 0.0625rem solid;
  border-radius: 50%;
  vertical-align: middle;
}
.js-enabled .govuk-accordion-nav__chevron:after {
  content: "";
  box-sizing: border-box;
  display: block;
  position: absolute;
  bottom: 0.3125rem;
  left: 0.375rem;
  width: 0.375rem;
  height: 0.375rem;
  -ms-transform: rotate(-45deg);
  transform: rotate(-45deg);
  border-top: 0.125rem solid;
  border-right: 0.125rem solid;
}
.js-enabled .govuk-accordion-nav__chevron--down {
  -ms-transform: rotate(180deg);
  transform: rotate(180deg);
}
.js-enabled .govuk-accordion__section-button {
  width: 100%;
  padding: 10px 0 0 0;
  border: 0;
  border-top: 1px solid #b1b4b6;
  border-bottom: 10px solid transparent;
  color: #0b0c0c;
  background: none;
  text-align: left;
  cursor: pointer;
  -webkit-appearance: none;
}
@media (min-width: 40.0625em) {
  .js-enabled .govuk-accordion__section-button {
    padding-bottom: 10px;
  }
}
.js-enabled .govuk-accordion__section-button:active {
  color: #0b0c0c;
  background: none;
}
.js-enabled .govuk-accordion__section-button:hover {
  color: #0b0c0c;
  background: #f3f2f1;
}
.js-enabled .govuk-accordion__section-button:hover .govuk-accordion__section-toggle-text {
  color: #0b0c0c;
}
.js-enabled .govuk-accordion__section-button:hover .govuk-accordion-nav__chevron {
  color: #0b0c0c;
  background: #0b0c0c;
}
.js-enabled .govuk-accordion__section-button:hover .govuk-accordion-nav__chevron:after {
  color: #f3f2f1;
}
.js-enabled .govuk-accordion__section-button:focus {
  outline: 0;
}
.js-enabled .govuk-accordion__section-button:focus .govuk-accordion__section-heading-text-focus,
.js-enabled .govuk-accordion__section-button:focus .govuk-accordion__section-summary-focus,
.js-enabled .govuk-accordion__section-button:focus .govuk-accordion__section-toggle-focus {
  outline: 3px solid transparent;
  color: #0b0c0c;
  background-color: #ffdd00;
  box-shadow: 0 -2px #ffdd00, 0 4px #0b0c0c;
  text-decoration: none;
  -webkit-box-decoration-break: clone;
  box-decoration-break: clone;
}
.js-enabled .govuk-accordion__section-button:focus .govuk-accordion-nav__chevron {
  color: #0b0c0c;
  background: #0b0c0c;
}
.js-enabled .govuk-accordion__section-button:focus .govuk-accordion-nav__chevron:after {
  color: #ffdd00;
}
.js-enabled .govuk-accordion__section-button::-moz-focus-inner {
  padding: 0;
  border: 0;
}
.js-enabled .govuk-accordion__section--expanded .govuk-accordion__section-button {
  padding-bottom: 15px;
  border-bottom: 0;
}
@media (min-width: 40.0625em) {
  .js-enabled .govuk-accordion__section--expanded .govuk-accordion__section-button {
    padding-bottom: 20px;
  }
}
.js-enabled .govuk-accordion__section-button:focus .govuk-accordion__section-toggle-focus {
  padding-bottom: 3px;
}
@media (min-width: 48.0625em) {
  .js-enabled .govuk-accordion__section-button:focus .govuk-accordion__section-toggle-focus {
    padding-bottom: 2px;
  }
}
.js-enabled .govuk-accordion__section-toggle,
.js-enabled .govuk-accordion__section-heading-text,
.js-enabled .govuk-accordion__section-summary {
  display: block;
  margin-bottom: 13px;
}
.js-enabled .govuk-accordion__section-toggle .govuk-accordion__section-heading-text-focus,
.js-enabled .govuk-accordion__section-toggle .govuk-accordion__section-summary-focus,
.js-enabled .govuk-accordion__section-toggle .govuk-accordion__section-toggle-focus,
.js-enabled .govuk-accordion__section-heading-text .govuk-accordion__section-heading-text-focus,
.js-enabled .govuk-accordion__section-heading-text .govuk-accordion__section-summary-focus,
.js-enabled .govuk-accordion__section-heading-text .govuk-accordion__section-toggle-focus,
.js-enabled .govuk-accordion__section-summary .govuk-accordion__section-heading-text-focus,
.js-enabled .govuk-accordion__section-summary .govuk-accordion__section-summary-focus,
.js-enabled .govuk-accordion__section-summary .govuk-accordion__section-toggle-focus {
  display: inline;
}
.js-enabled .govuk-accordion__section-toggle {
  font-size: 16px;
  font-size: 1rem;
  line-height: 1.25;
  font-weight: 400;
  color: #1d70b8;
}
@media (min-width: 40.0625em) {
  .js-enabled .govuk-accordion__section-toggle {
    font-size: 19px;
    font-size: 1.1875rem;
    line-height: 1.3157894737;
  }
}
@media print {
  .js-enabled .govuk-accordion__section-toggle {
    font-size: 14pt;
    line-height: 1.15;
  }
}
.js-enabled .govuk-accordion__show-all-text,
.js-enabled .govuk-accordion__section-toggle-text {
  margin-left: 5px;
  vertical-align: middle;
}
@media screen and (forced-colors: active) {
  .js-enabled .govuk-accordion__show-all:hover .govuk-accordion-nav__chevron,
.js-enabled .govuk-accordion__section-button:hover .govuk-accordion-nav__chevron {
    background-color: transparent;
  }
  .js-enabled .govuk-accordion__show-all:focus .govuk-accordion__section-heading-text-focus,
.js-enabled .govuk-accordion__show-all:focus .govuk-accordion__section-summary-focus,
.js-enabled .govuk-accordion__show-all:focus .govuk-accordion__section-toggle-focus,
.js-enabled .govuk-accordion__show-all:focus .govuk-accordion-nav__chevron,
.js-enabled .govuk-accordion__section-button:focus .govuk-accordion__section-heading-text-focus,
.js-enabled .govuk-accordion__section-button:focus .govuk-accordion__section-summary-focus,
.js-enabled .govuk-accordion__section-button:focus .govuk-accordion__section-toggle-focus,
.js-enabled .govuk-accordion__section-button:focus .govuk-accordion-nav__chevron {
    background: transparent;
    background-color: transparent;
  }
}
@media (hover: none) {
  .js-enabled .govuk-accordion__section-header:hover {
    border-top-color: #b1b4b6;
    box-shadow: inset 0 3px 0 0 #1d70b8;
  }
  .js-enabled .govuk-accordion__section-header:hover .govuk-accordion__section-button {
    border-top-color: #b1b4b6;
  }
}

/*# sourceMappingURL=_index.scss.map */
.govuk-back-link {
  font-size: 14px;
  font-size: 0.875rem;
  line-height: 1.1428571429;
  font-family: Arial, sans-serif;
  -webkit-font-smoothing: antialiased;
  -moz-osx-font-smoothing: grayscale;
  text-decoration: underline;
  display: inline-block;
  position: relative;
  margin-top: 15px;
  margin-bottom: 15px;
  padding-left: 0.875em;
}
@media (min-width: 40.0625em) {
  .govuk-back-link {
    font-size: 16px;
    font-size: 1rem;
    line-height: 1.25;
  }
}
@media print {
  .govuk-back-link {
    font-size: 14pt;
    line-height: 1.2;
  }
}
@media print {
  .govuk-back-link {
    font-family: sans-serif;
  }
}
.govuk-back-link:focus {
  outline: 3px solid transparent;
  color: #0b0c0c;
  background-color: #ffdd00;
  box-shadow: 0 -2px #ffdd00, 0 4px #0b0c0c;
  text-decoration: none;
  -webkit-box-decoration-break: clone;
  box-decoration-break: clone;
}
.govuk-back-link:link, .govuk-back-link:visited {
  color: #0b0c0c;
}
@media print {
  .govuk-back-link:link, .govuk-back-link:visited {
    color: #000000;
  }
}
.govuk-back-link:hover {
  color: rgba(11, 12, 12, 0.99);
}
.govuk-back-link:active, .govuk-back-link:focus {
  color: #0b0c0c;
}
@media print {
  .govuk-back-link:active, .govuk-back-link:focus {
    color: #000000;
  }
}

.govuk-back-link:before {
  content: "";
  display: block;
  position: absolute;
  top: 0;
  bottom: 0;
  left: 0.1875em;
  width: 0.4375em;
  height: 0.4375em;
  margin: auto 0;
  -ms-transform: rotate(225deg);
  transform: rotate(225deg);
  border: solid;
  border-width: 1px 1px 0 0;
  border-color: #6B7276;
}
@supports (border-width: max(0px)) {
  .govuk-back-link:before {
    border-width: max(1px, 0.0625em) max(1px, 0.0625em) 0 0;
    font-size: max(16px, 1em);
  }
}

.govuk-back-link:focus:before {
  border-color: #0b0c0c;
}

.govuk-back-link:after {
  content: "";
  position: absolute;
  top: -14px;
  right: 0;
  bottom: -14px;
  left: 0;
}

.govuk-back-link--inverse:link, .govuk-back-link--inverse:visited {
  color: #ffffff;
}
.govuk-back-link--inverse:hover, .govuk-back-link--inverse:active {
  color: rgba(255, 255, 255, 0.99);
}
.govuk-back-link--inverse:focus {
  color: #0b0c0c;
}
.govuk-back-link--inverse:before {
  border-color: currentcolor;
}

/*# sourceMappingURL=_index.scss.map */
.govuk-breadcrumbs {
  font-family: Arial, sans-serif;
  -webkit-font-smoothing: antialiased;
  -moz-osx-font-smoothing: grayscale;
  font-weight: 400;
  font-size: 14px;
  font-size: 0.875rem;
  line-height: 1.1428571429;
  color: #0b0c0c;
  margin-top: 15px;
  margin-bottom: 10px;
}
@media print {
  .govuk-breadcrumbs {
    font-family: sans-serif;
  }
}
@media (min-width: 40.0625em) {
  .govuk-breadcrumbs {
    font-size: 16px;
    font-size: 1rem;
    line-height: 1.25;
  }
}
@media print {
  .govuk-breadcrumbs {
    font-size: 14pt;
    line-height: 1.2;
  }
}
@media print {
  .govuk-breadcrumbs {
    color: #000000;
  }
}

.govuk-breadcrumbs__list {
  margin: 0;
  padding: 0;
  list-style-type: none;
}
.govuk-breadcrumbs__list:after {
  content: "";
  display: block;
  clear: both;
}

.govuk-breadcrumbs__list-item {
  display: inline-block;
  position: relative;
  margin-bottom: 5px;
  margin-left: 0.625em;
  padding-left: 0.9784375em;
  float: left;
}
.govuk-breadcrumbs__list-item:before {
  content: "";
  display: block;
  position: absolute;
  top: 0;
  bottom: 0;
  left: -0.206875em;
  width: 0.4375em;
  height: 0.4375em;
  margin: auto 0;
  -ms-transform: rotate(45deg);
  transform: rotate(45deg);
  border: solid;
  border-width: 1px 1px 0 0;
  border-color: #6B7276;
}
@supports (border-width: max(0px)) {
  .govuk-breadcrumbs__list-item:before {
    border-width: max(1px, 0.0625em) max(1px, 0.0625em) 0 0;
    font-size: max(16px, 1em);
  }
}
.govuk-breadcrumbs__list-item:first-child {
  margin-left: 0;
  padding-left: 0;
}
.govuk-breadcrumbs__list-item:first-child:before {
  content: none;
  display: none;
}

.govuk-breadcrumbs__link {
  font-family: Arial, sans-serif;
  -webkit-font-smoothing: antialiased;
  -moz-osx-font-smoothing: grayscale;
  text-decoration: underline;
}
@media print {
  .govuk-breadcrumbs__link {
    font-family: sans-serif;
  }
}
.govuk-breadcrumbs__link:focus {
  outline: 3px solid transparent;
  color: #0b0c0c;
  background-color: #ffdd00;
  box-shadow: 0 -2px #ffdd00, 0 4px #0b0c0c;
  text-decoration: none;
  -webkit-box-decoration-break: clone;
  box-decoration-break: clone;
}
.govuk-breadcrumbs__link:link, .govuk-breadcrumbs__link:visited {
  color: #0b0c0c;
}
@media print {
  .govuk-breadcrumbs__link:link, .govuk-breadcrumbs__link:visited {
    color: #000000;
  }
}
.govuk-breadcrumbs__link:hover {
  color: rgba(11, 12, 12, 0.99);
}
.govuk-breadcrumbs__link:active, .govuk-breadcrumbs__link:focus {
  color: #0b0c0c;
}
@media print {
  .govuk-breadcrumbs__link:active, .govuk-breadcrumbs__link:focus {
    color: #000000;
  }
}

@media (max-width: 40.0525em) {
  .govuk-breadcrumbs--collapse-on-mobile .govuk-breadcrumbs__list-item {
    display: none;
  }
  .govuk-breadcrumbs--collapse-on-mobile .govuk-breadcrumbs__list-item:first-child, .govuk-breadcrumbs--collapse-on-mobile .govuk-breadcrumbs__list-item:last-child {
    display: inline-block;
  }
  .govuk-breadcrumbs--collapse-on-mobile .govuk-breadcrumbs__list-item:before {
    top: 0.375em;
    margin: 0;
  }
  .govuk-breadcrumbs--collapse-on-mobile .govuk-breadcrumbs__list {
    display: -ms-flexbox;
    display: flex;
  }
}

.govuk-breadcrumbs--inverse {
  color: #ffffff;
}
.govuk-breadcrumbs--inverse .govuk-breadcrumbs__link:link, .govuk-breadcrumbs--inverse .govuk-breadcrumbs__link:visited {
  color: #ffffff;
}
.govuk-breadcrumbs--inverse .govuk-breadcrumbs__link:hover, .govuk-breadcrumbs--inverse .govuk-breadcrumbs__link:active {
  color: rgba(255, 255, 255, 0.99);
}
.govuk-breadcrumbs--inverse .govuk-breadcrumbs__link:focus {
  color: #0b0c0c;
}
.govuk-breadcrumbs--inverse .govuk-breadcrumbs__list-item:before {
  border-color: currentcolor;
}

/*# sourceMappingURL=_index.scss.map */
.govuk-button {
  font-family: Arial, sans-serif;
  -webkit-font-smoothing: antialiased;
  -moz-osx-font-smoothing: grayscale;
  font-weight: 400;
  font-size: 16px;
  font-size: 1rem;
  line-height: 1.1875;
  box-sizing: border-box;
  display: inline-block;
  position: relative;
  width: 100%;
  margin-top: 0;
  margin-right: 0;
  margin-left: 0;
  margin-bottom: 22px;
  padding: 8px 10px 7px;
  border: 2px solid transparent;
  border-radius: 0;
  color: #ffffff;
  background-color: #00703c;
  box-shadow: 0 2px 0 #002d18;
  text-align: center;
  vertical-align: top;
  cursor: pointer;
  -webkit-appearance: none;
}
@media print {
  .govuk-button {
    font-family: sans-serif;
  }
}
@media (min-width: 40.0625em) {
  .govuk-button {
    font-size: 19px;
    font-size: 1.1875rem;
    line-height: 1;
  }
}
@media print {
  .govuk-button {
    font-size: 14pt;
    line-height: 19px;
  }
}
@media (min-width: 40.0625em) {
  .govuk-button {
    margin-bottom: 32px;
  }
}
@media (min-width: 40.0625em) {
  .govuk-button {
    width: auto;
  }
}
.govuk-button:link, .govuk-button:visited, .govuk-button:active, .govuk-button:hover {
  color: #ffffff;
  text-decoration: none;
}
.govuk-button::-moz-focus-inner {
  padding: 0;
  border: 0;
}
.govuk-button:hover {
  background-color: #005a30;
}
.govuk-button:active {
  top: 2px;
}
.govuk-button:focus {
  border-color: #ffdd00;
  outline: 3px solid transparent;
  box-shadow: inset 0 0 0 1px #ffdd00;
}
.govuk-button:focus:not(:active):not(:hover) {
  border-color: #ffdd00;
  color: #0b0c0c;
  background-color: #ffdd00;
  box-shadow: 0 2px 0 #0b0c0c;
}
.govuk-button:before {
  content: "";
  display: block;
  position: absolute;
  top: -2px;
  right: -2px;
  bottom: -4px;
  left: -2px;
  background: transparent;
}
.govuk-button:active:before {
  top: -4px;
}

.govuk-button--disabled,
.govuk-button[disabled=disabled],
.govuk-button[disabled] {
  opacity: 0.5;
}
.govuk-button--disabled:hover,
.govuk-button[disabled=disabled]:hover,
.govuk-button[disabled]:hover {
  background-color: #00703c;
  cursor: not-allowed;
}
.govuk-button--disabled:active,
.govuk-button[disabled=disabled]:active,
.govuk-button[disabled]:active {
  top: 0;
  box-shadow: 0 2px 0 #002d18;
}

.govuk-button--secondary {
  background-color: #f3f2f1;
  box-shadow: 0 2px 0 #929191;
}
.govuk-button--secondary, .govuk-button--secondary:link, .govuk-button--secondary:visited, .govuk-button--secondary:active, .govuk-button--secondary:hover {
  color: #0b0c0c;
}
.govuk-button--secondary:hover {
  background-color: #dbdad9;
}
.govuk-button--secondary:hover[disabled] {
  background-color: #f3f2f1;
}

.govuk-button--warning {
  background-color: #d4351c;
  box-shadow: 0 2px 0 #55150b;
}
.govuk-button--warning, .govuk-button--warning:link, .govuk-button--warning:visited, .govuk-button--warning:active, .govuk-button--warning:hover {
  color: #ffffff;
}
.govuk-button--warning:hover {
  background-color: #aa2a16;
}
.govuk-button--warning:hover[disabled] {
  background-color: #d4351c;
}

.govuk-button--inverse {
  background-color: #ffffff;
  box-shadow: 0 2px 0 #144e81;
}
.govuk-button--inverse, .govuk-button--inverse:link, .govuk-button--inverse:visited, .govuk-button--inverse:active, .govuk-button--inverse:hover {
  color: #1d70b8;
}
.govuk-button--inverse:hover {
  background-color: #e8f1f8;
}
.govuk-button--inverse:hover[disabled] {
  background-color: #ffffff;
}

.govuk-button--start {
  font-weight: 700;
  font-size: 18px;
  font-size: 1.125rem;
  line-height: 1;
  display: -ms-inline-flexbox;
  display: inline-flex;
  min-height: auto;
  -ms-flex-pack: center;
  justify-content: center;
}
@media (min-width: 40.0625em) {
  .govuk-button--start {
    font-size: 24px;
    font-size: 1.5rem;
    line-height: 1;
  }
}
@media print {
  .govuk-button--start {
    font-size: 18pt;
    line-height: 1;
  }
}

.govuk-button__start-icon {
  margin-left: 5px;
  vertical-align: middle;
  -ms-flex-negative: 0;
  flex-shrink: 0;
  -ms-flex-item-align: center;
  align-self: center;
  forced-color-adjust: auto;
}
@media (min-width: 48.0625em) {
  .govuk-button__start-icon {
    margin-left: 10px;
  }
}

/*# sourceMappingURL=_index.scss.map */
.govuk-error-message {
  font-family: Arial, sans-serif;
  -webkit-font-smoothing: antialiased;
  -moz-osx-font-smoothing: grayscale;
  font-weight: 700;
  font-size: 16px;
  font-size: 1rem;
  line-height: 1.25;
  display: block;
  margin-top: 0;
  margin-bottom: 15px;
  clear: both;
  color: #d4351c;
}
@media print {
  .govuk-error-message {
    font-family: sans-serif;
  }
}
@media (min-width: 40.0625em) {
  .govuk-error-message {
    font-size: 19px;
    font-size: 1.1875rem;
    line-height: 1.3157894737;
  }
}
@media print {
  .govuk-error-message {
    font-size: 14pt;
    line-height: 1.15;
  }
}

/*# sourceMappingURL=_index.scss.map */
.govuk-fieldset {
  min-width: 0;
  margin: 0;
  padding: 0;
  border: 0;
}
.govuk-fieldset:after {
  content: "";
  display: block;
  clear: both;
}

@supports not (caret-color: auto) {
  .govuk-fieldset,
x:-moz-any-link {
    display: table-cell;
  }
}
.govuk-fieldset__legend {
  font-family: Arial, sans-serif;
  -webkit-font-smoothing: antialiased;
  -moz-osx-font-smoothing: grayscale;
  font-weight: 400;
  font-size: 16px;
  font-size: 1rem;
  line-height: 1.25;
  color: #0b0c0c;
  box-sizing: border-box;
  display: table;
  max-width: 100%;
  margin-bottom: 10px;
  padding: 0;
  white-space: normal;
}
@media print {
  .govuk-fieldset__legend {
    font-family: sans-serif;
  }
}
@media (min-width: 40.0625em) {
  .govuk-fieldset__legend {
    font-size: 19px;
    font-size: 1.1875rem;
    line-height: 1.3157894737;
  }
}
@media print {
  .govuk-fieldset__legend {
    font-size: 14pt;
    line-height: 1.15;
  }
}
@media print {
  .govuk-fieldset__legend {
    color: #000000;
  }
}

.govuk-fieldset__legend--xl {
  font-family: Arial, sans-serif;
  -webkit-font-smoothing: antialiased;
  -moz-osx-font-smoothing: grayscale;
  font-weight: 700;
  font-size: 32px;
  font-size: 2rem;
  line-height: 1.09375;
  margin-bottom: 15px;
}
@media print {
  .govuk-fieldset__legend--xl {
    font-family: sans-serif;
  }
}
@media (min-width: 40.0625em) {
  .govuk-fieldset__legend--xl {
    font-size: 48px;
    font-size: 3rem;
    line-height: 1.0416666667;
  }
}
@media print {
  .govuk-fieldset__legend--xl {
    font-size: 32pt;
    line-height: 1.15;
  }
}

.govuk-fieldset__legend--l {
  font-family: Arial, sans-serif;
  -webkit-font-smoothing: antialiased;
  -moz-osx-font-smoothing: grayscale;
  font-weight: 700;
  font-size: 24px;
  font-size: 1.5rem;
  line-height: 1.0416666667;
  margin-bottom: 15px;
}
@media print {
  .govuk-fieldset__legend--l {
    font-family: sans-serif;
  }
}
@media (min-width: 40.0625em) {
  .govuk-fieldset__legend--l {
    font-size: 36px;
    font-size: 2.25rem;
    line-height: 1.1111111111;
  }
}
@media print {
  .govuk-fieldset__legend--l {
    font-size: 24pt;
    line-height: 1.05;
  }
}

.govuk-fieldset__legend--m {
  font-family: Arial, sans-serif;
  -webkit-font-smoothing: antialiased;
  -moz-osx-font-smoothing: grayscale;
  font-weight: 700;
  font-size: 18px;
  font-size: 1.125rem;
  line-height: 1.1111111111;
  margin-bottom: 15px;
}
@media print {
  .govuk-fieldset__legend--m {
    font-family: sans-serif;
  }
}
@media (min-width: 40.0625em) {
  .govuk-fieldset__legend--m {
    font-size: 24px;
    font-size: 1.5rem;
    line-height: 1.25;
  }
}
@media print {
  .govuk-fieldset__legend--m {
    font-size: 18pt;
    line-height: 1.15;
  }
}

.govuk-fieldset__legend--s {
  font-family: Arial, sans-serif;
  -webkit-font-smoothing: antialiased;
  -moz-osx-font-smoothing: grayscale;
  font-weight: 700;
  font-size: 16px;
  font-size: 1rem;
  line-height: 1.25;
}
@media print {
  .govuk-fieldset__legend--s {
    font-family: sans-serif;
  }
}
@media (min-width: 40.0625em) {
  .govuk-fieldset__legend--s {
    font-size: 19px;
    font-size: 1.1875rem;
    line-height: 1.3157894737;
  }
}
@media print {
  .govuk-fieldset__legend--s {
    font-size: 14pt;
    line-height: 1.15;
  }
}

.govuk-fieldset__heading {
  margin: 0;
  font-size: inherit;
  font-weight: inherit;
}

/*# sourceMappingURL=_index.scss.map */
.govuk-hint {
  font-family: Arial, sans-serif;
  -webkit-font-smoothing: antialiased;
  -moz-osx-font-smoothing: grayscale;
  font-weight: 400;
  font-size: 16px;
  font-size: 1rem;
  line-height: 1.25;
  margin-bottom: 15px;
  color: #6B7276;
}
@media print {
  .govuk-hint {
    font-family: sans-serif;
  }
}
@media (min-width: 40.0625em) {
  .govuk-hint {
    font-size: 19px;
    font-size: 1.1875rem;
    line-height: 1.3157894737;
  }
}
@media print {
  .govuk-hint {
    font-size: 14pt;
    line-height: 1.15;
  }
}

.govuk-label:not(.govuk-label--m):not(.govuk-label--l):not(.govuk-label--xl) + .govuk-hint {
  margin-bottom: 10px;
}

.govuk-fieldset__legend:not(.govuk-fieldset__legend--m):not(.govuk-fieldset__legend--l):not(.govuk-fieldset__legend--xl) + .govuk-hint {
  margin-bottom: 10px;
}

.govuk-fieldset__legend + .govuk-hint {
  margin-top: -5px;
}

/*# sourceMappingURL=_index.scss.map */
.govuk-label {
  font-family: Arial, sans-serif;
  -webkit-font-smoothing: antialiased;
  -moz-osx-font-smoothing: grayscale;
  font-weight: 400;
  font-size: 16px;
  font-size: 1rem;
  line-height: 1.25;
  color: #0b0c0c;
  display: block;
  margin-bottom: 5px;
}
@media print {
  .govuk-label {
    font-family: sans-serif;
  }
}
@media (min-width: 40.0625em) {
  .govuk-label {
    font-size: 19px;
    font-size: 1.1875rem;
    line-height: 1.3157894737;
  }
}
@media print {
  .govuk-label {
    font-size: 14pt;
    line-height: 1.15;
  }
}
@media print {
  .govuk-label {
    color: #000000;
  }
}

.govuk-label--xl {
  font-family: Arial, sans-serif;
  -webkit-font-smoothing: antialiased;
  -moz-osx-font-smoothing: grayscale;
  font-weight: 700;
  font-size: 32px;
  font-size: 2rem;
  line-height: 1.09375;
  margin-bottom: 15px;
}
@media print {
  .govuk-label--xl {
    font-family: sans-serif;
  }
}
@media (min-width: 40.0625em) {
  .govuk-label--xl {
    font-size: 48px;
    font-size: 3rem;
    line-height: 1.0416666667;
  }
}
@media print {
  .govuk-label--xl {
    font-size: 32pt;
    line-height: 1.15;
  }
}

.govuk-label--l {
  font-family: Arial, sans-serif;
  -webkit-font-smoothing: antialiased;
  -moz-osx-font-smoothing: grayscale;
  font-weight: 700;
  font-size: 24px;
  font-size: 1.5rem;
  line-height: 1.0416666667;
  margin-bottom: 15px;
}
@media print {
  .govuk-label--l {
    font-family: sans-serif;
  }
}
@media (min-width: 40.0625em) {
  .govuk-label--l {
    font-size: 36px;
    font-size: 2.25rem;
    line-height: 1.1111111111;
  }
}
@media print {
  .govuk-label--l {
    font-size: 24pt;
    line-height: 1.05;
  }
}

.govuk-label--m {
  font-family: Arial, sans-serif;
  -webkit-font-smoothing: antialiased;
  -moz-osx-font-smoothing: grayscale;
  font-weight: 700;
  font-size: 18px;
  font-size: 1.125rem;
  line-height: 1.1111111111;
  margin-bottom: 10px;
}
@media print {
  .govuk-label--m {
    font-family: sans-serif;
  }
}
@media (min-width: 40.0625em) {
  .govuk-label--m {
    font-size: 24px;
    font-size: 1.5rem;
    line-height: 1.25;
  }
}
@media print {
  .govuk-label--m {
    font-size: 18pt;
    line-height: 1.15;
  }
}

.govuk-label--s {
  font-family: Arial, sans-serif;
  -webkit-font-smoothing: antialiased;
  -moz-osx-font-smoothing: grayscale;
  font-weight: 700;
  font-size: 16px;
  font-size: 1rem;
  line-height: 1.25;
}
@media print {
  .govuk-label--s {
    font-family: sans-serif;
  }
}
@media (min-width: 40.0625em) {
  .govuk-label--s {
    font-size: 19px;
    font-size: 1.1875rem;
    line-height: 1.3157894737;
  }
}
@media print {
  .govuk-label--s {
    font-size: 14pt;
    line-height: 1.15;
  }
}

.govuk-label-wrapper {
  margin: 0;
}

/*# sourceMappingURL=_index.scss.map */
.govuk-checkboxes__item {
  font-family: Arial, sans-serif;
  -webkit-font-smoothing: antialiased;
  -moz-osx-font-smoothing: grayscale;
  font-weight: 400;
  font-size: 16px;
  font-size: 1rem;
  line-height: 1.25;
  display: block;
  position: relative;
  min-height: 40px;
  margin-bottom: 10px;
  padding-left: 40px;
  clear: left;
}
@media print {
  .govuk-checkboxes__item {
    font-family: sans-serif;
  }
}
@media (min-width: 40.0625em) {
  .govuk-checkboxes__item {
    font-size: 19px;
    font-size: 1.1875rem;
    line-height: 1.3157894737;
  }
}
@media print {
  .govuk-checkboxes__item {
    font-size: 14pt;
    line-height: 1.15;
  }
}

.govuk-checkboxes__item:last-child,
.govuk-checkboxes__item:last-of-type {
  margin-bottom: 0;
}

.govuk-checkboxes__input {
  cursor: pointer;
  position: absolute;
  z-index: 1;
  top: -2px;
  left: -2px;
  width: 44px;
  height: 44px;
  margin: 0;
  opacity: 0;
}

.govuk-checkboxes__label {
  display: inline-block;
  margin-bottom: 0;
  padding: 8px 15px 5px;
  cursor: pointer;
  -ms-touch-action: manipulation;
  touch-action: manipulation;
}

.govuk-checkboxes__label:before {
  content: "";
  box-sizing: border-box;
  position: absolute;
  top: 0;
  left: 0;
  width: 40px;
  height: 40px;
  border: 2px solid currentcolor;
  background: transparent;
}

.govuk-checkboxes__label:after {
  content: "";
  box-sizing: border-box;
  position: absolute;
  top: 11px;
  left: 9px;
  width: 23px;
  height: 12px;
  -ms-transform: rotate(-45deg);
  transform: rotate(-45deg);
  border: solid;
  border-width: 0 0 5px 5px;
  border-top-color: transparent;
  opacity: 0;
  background: transparent;
}

.govuk-checkboxes__hint {
  display: block;
  padding-right: 15px;
  padding-left: 15px;
}

.govuk-checkboxes__input:focus + .govuk-checkboxes__label:before {
  border-width: 4px;
  outline: 3px solid transparent;
  outline-offset: 1px;
  box-shadow: 0 0 0 3px #ffdd00;
}
@media screen and (forced-colors: active), (-ms-high-contrast: active) {
  .govuk-checkboxes__input:focus + .govuk-checkboxes__label:before {
    outline-color: Highlight;
  }
}

.govuk-checkboxes__input:checked + .govuk-checkboxes__label:after {
  opacity: 1;
}

.govuk-checkboxes__input:disabled,
.govuk-checkboxes__input:disabled + .govuk-checkboxes__label {
  cursor: not-allowed;
}

.govuk-checkboxes__input:disabled + .govuk-checkboxes__label,
.govuk-checkboxes__input:disabled ~ .govuk-hint {
  opacity: 0.5;
}

.govuk-checkboxes__divider {
  font-family: Arial, sans-serif;
  -webkit-font-smoothing: antialiased;
  -moz-osx-font-smoothing: grayscale;
  font-weight: 400;
  font-size: 16px;
  font-size: 1rem;
  line-height: 1.25;
  color: #0b0c0c;
  width: 40px;
  margin-bottom: 10px;
  text-align: center;
}
@media print {
  .govuk-checkboxes__divider {
    font-family: sans-serif;
  }
}
@media (min-width: 40.0625em) {
  .govuk-checkboxes__divider {
    font-size: 19px;
    font-size: 1.1875rem;
    line-height: 1.3157894737;
  }
}
@media print {
  .govuk-checkboxes__divider {
    font-size: 14pt;
    line-height: 1.15;
  }
}
@media print {
  .govuk-checkboxes__divider {
    color: #000000;
  }
}

.govuk-checkboxes__conditional {
  margin-bottom: 15px;
  margin-left: 18px;
  padding-left: 33px;
  border-left: 4px solid #b1b4b6;
}
@media (min-width: 40.0625em) {
  .govuk-checkboxes__conditional {
    margin-bottom: 20px;
  }
}
.js-enabled .govuk-checkboxes__conditional--hidden {
  display: none;
}
.govuk-checkboxes__conditional > :last-child {
  margin-bottom: 0;
}

.govuk-checkboxes--small .govuk-checkboxes__item {
  min-height: 0;
  margin-bottom: 0;
  padding-left: 34px;
  float: left;
}
.govuk-checkboxes--small .govuk-checkboxes__item:after {
  content: "";
  display: block;
  clear: both;
}
.govuk-checkboxes--small .govuk-checkboxes__input {
  left: -10px;
}
.govuk-checkboxes--small .govuk-checkboxes__label {
  margin-top: -2px;
  padding: 13px 15px 13px 1px;
  float: left;
}
@media (min-width: 40.0625em) {
  .govuk-checkboxes--small .govuk-checkboxes__label {
    padding: 11px 15px 10px 1px;
  }
}
.govuk-checkboxes--small .govuk-checkboxes__label:before {
  top: 8px;
  width: 24px;
  height: 24px;
}
.govuk-checkboxes--small .govuk-checkboxes__label:after {
  top: 15px;
  left: 6px;
  width: 12px;
  height: 6.5px;
  border-width: 0 0 3px 3px;
}
.govuk-checkboxes--small .govuk-checkboxes__hint {
  padding: 0;
  clear: both;
}
.govuk-checkboxes--small .govuk-checkboxes__conditional {
  margin-left: 10px;
  padding-left: 20px;
  clear: both;
}
.govuk-checkboxes--small .govuk-checkboxes__item:hover .govuk-checkboxes__input:not(:disabled) + .govuk-checkboxes__label:before {
  box-shadow: 0 0 0 10px #b1b4b6;
}
.govuk-checkboxes--small .govuk-checkboxes__item:hover .govuk-checkboxes__input:focus + .govuk-checkboxes__label:before {
  box-shadow: 0 0 0 3px #ffdd00, 0 0 0 10px #b1b4b6;
}
@media (hover: none), (pointer: coarse) {
  .govuk-checkboxes--small .govuk-checkboxes__item:hover .govuk-checkboxes__input:not(:disabled) + .govuk-checkboxes__label:before {
    box-shadow: initial;
  }
  .govuk-checkboxes--small .govuk-checkboxes__item:hover .govuk-checkboxes__input:focus + .govuk-checkboxes__label:before {
    box-shadow: 0 0 0 3px #ffdd00;
  }
}

/*# sourceMappingURL=_index.scss.map */
/*# sourceMappingURL=_index.scss.map */
/*# sourceMappingURL=_index.scss.map */
/*# sourceMappingURL=_index.scss.map */
/*# sourceMappingURL=_index.scss.map */
/*# sourceMappingURL=_index.scss.map */
/*# sourceMappingURL=_index.scss.map */
.govuk-textarea {
  font-family: Arial, sans-serif;
  -webkit-font-smoothing: antialiased;
  -moz-osx-font-smoothing: grayscale;
  font-weight: 400;
  font-size: 16px;
  font-size: 1rem;
  line-height: 1.25;
  box-sizing: border-box;
  display: block;
  width: 100%;
  min-height: 40px;
  margin-bottom: 20px;
  padding: 5px;
  resize: vertical;
  border: 2px solid #0b0c0c;
  border-radius: 0;
  -webkit-appearance: none;
}
@media print {
  .govuk-textarea {
    font-family: sans-serif;
  }
}
@media (min-width: 40.0625em) {
  .govuk-textarea {
    font-size: 19px;
    font-size: 1.1875rem;
    line-height: 1.25;
  }
}
@media print {
  .govuk-textarea {
    font-size: 14pt;
    line-height: 1.25;
  }
}
@media (min-width: 40.0625em) {
  .govuk-textarea {
    margin-bottom: 30px;
  }
}
.govuk-textarea:focus {
  outline: 3px solid #ffdd00;
  outline-offset: 0;
  box-shadow: inset 0 0 0 2px;
}
.govuk-textarea:disabled {
  opacity: 0.5;
  color: inherit;
  background-color: transparent;
  cursor: not-allowed;
}

.govuk-textarea--error {
  border-color: #d4351c;
}
.govuk-textarea--error:focus {
  border-color: #0b0c0c;
}

/*# sourceMappingURL=_index.scss.map */
.govuk-character-count {
  margin-bottom: 20px;
}
@media (min-width: 40.0625em) {
  .govuk-character-count {
    margin-bottom: 30px;
  }
}
.govuk-character-count .govuk-form-group,
.govuk-character-count .govuk-textarea {
  margin-bottom: 5px;
}

.govuk-character-count__message {
  font-family: Arial, sans-serif;
  -webkit-font-smoothing: antialiased;
  -moz-osx-font-smoothing: grayscale;
  font-feature-settings: "tnum" 1;
  font-weight: 400;
  margin-top: 0;
  margin-bottom: 0;
}
@media print {
  .govuk-character-count__message {
    font-family: sans-serif;
  }
}
@supports (font-variant-numeric: tabular-nums) {
  .govuk-character-count__message {
    font-feature-settings: normal;
    font-variant-numeric: tabular-nums;
  }
}
.govuk-character-count__message:after {
  content: "​";
}

.govuk-character-count__message--disabled {
  visibility: hidden;
}

/*# sourceMappingURL=_index.scss.map */
.govuk-cookie-banner {
  padding-top: 20px;
  border-bottom: 10px solid transparent;
  background-color: #f3f2f1;
}

.govuk-cookie-banner[hidden] {
  display: none;
}

.govuk-cookie-banner__message {
  margin-bottom: -10px;
}
.govuk-cookie-banner__message[hidden] {
  display: none;
}
.govuk-cookie-banner__message:focus {
  outline: none;
}

/*# sourceMappingURL=_index.scss.map */
/*# sourceMappingURL=_index.scss.map */
/*# sourceMappingURL=_index.scss.map */
/*# sourceMappingURL=_index.scss.map */
/*# sourceMappingURL=_index.scss.map */
.govuk-input {
  font-family: Arial, sans-serif;
  -webkit-font-smoothing: antialiased;
  -moz-osx-font-smoothing: grayscale;
  font-weight: 400;
  font-size: 16px;
  font-size: 1rem;
  line-height: 1.25;
  box-sizing: border-box;
  width: 100%;
  height: 40px;
  height: 2.5rem;
  margin-top: 0;
  padding: 5px;
  border: 2px solid #0b0c0c;
  border-radius: 0;
  -webkit-appearance: none;
  appearance: none;
}
@media print {
  .govuk-input {
    font-family: sans-serif;
  }
}
@media (min-width: 40.0625em) {
  .govuk-input {
    font-size: 19px;
    font-size: 1.1875rem;
    line-height: 1.3157894737;
  }
}
@media print {
  .govuk-input {
    font-size: 14pt;
    line-height: 1.15;
  }
}
.govuk-input:focus {
  outline: 3px solid #ffdd00;
  outline-offset: 0;
  box-shadow: inset 0 0 0 2px;
}
.govuk-input:disabled {
  opacity: 0.5;
  color: inherit;
  background-color: transparent;
  cursor: not-allowed;
}

.govuk-input::-webkit-outer-spin-button,
.govuk-input::-webkit-inner-spin-button {
  margin: 0;
  -webkit-appearance: none;
}

.govuk-input[type=number] {
  -moz-appearance: textfield;
}

.govuk-input--error {
  border-color: #d4351c;
}
.govuk-input--error:focus {
  border-color: #0b0c0c;
}

.govuk-input--extra-letter-spacing {
  font-family: Arial, sans-serif;
  -webkit-font-smoothing: antialiased;
  -moz-osx-font-smoothing: grayscale;
  font-feature-settings: "tnum" 1;
  font-weight: 400;
  letter-spacing: 0.05em;
}
@media print {
  .govuk-input--extra-letter-spacing {
    font-family: sans-serif;
  }
}
@supports (font-variant-numeric: tabular-nums) {
  .govuk-input--extra-letter-spacing {
    font-feature-settings: normal;
    font-variant-numeric: tabular-nums;
  }
}

.govuk-input--width-30 {
  max-width: 29.5em;
}

.govuk-input--width-20 {
  max-width: 20.5em;
}

.govuk-input--width-10 {
  max-width: 11.5em;
}

.govuk-input--width-5 {
  max-width: 5.5em;
}

.govuk-input--width-4 {
  max-width: 4.5em;
}

.govuk-input--width-3 {
  max-width: 3.75em;
}

.govuk-input--width-2 {
  max-width: 2.75em;
}

.govuk-input__wrapper {
  display: -ms-flexbox;
  display: flex;
}
.govuk-input__wrapper .govuk-input {
  -ms-flex: 0 1 auto;
  flex: 0 1 auto;
}
.govuk-input__wrapper .govuk-input:focus {
  z-index: 1;
}
@media (max-width: 19.99em) {
  .govuk-input__wrapper {
    display: block;
  }
  .govuk-input__wrapper .govuk-input {
    max-width: 100%;
  }
}

.govuk-input__prefix,
.govuk-input__suffix {
  font-family: Arial, sans-serif;
  -webkit-font-smoothing: antialiased;
  -moz-osx-font-smoothing: grayscale;
  font-weight: 400;
  font-size: 16px;
  font-size: 1rem;
  line-height: 1.25;
  box-sizing: border-box;
  display: inline-block;
  min-width: 40px;
  min-width: 2.5rem;
  height: 40px;
  height: 2.5rem;
  padding: 5px;
  border: 2px solid #0b0c0c;
  background-color: #f3f2f1;
  text-align: center;
  white-space: nowrap;
  cursor: default;
  -ms-flex: 0 0 auto;
  flex: 0 0 auto;
}
@media print {
  .govuk-input__prefix,
.govuk-input__suffix {
    font-family: sans-serif;
  }
}
@media (min-width: 40.0625em) {
  .govuk-input__prefix,
.govuk-input__suffix {
    font-size: 19px;
    font-size: 1.1875rem;
    line-height: 1.3157894737;
  }
}
@media print {
  .govuk-input__prefix,
.govuk-input__suffix {
    font-size: 14pt;
    line-height: 1.15;
  }
}
@media (max-width: 40.0525em) {
  .govuk-input__prefix,
.govuk-input__suffix {
    line-height: 1.6;
  }
}
@media (max-width: 19.99em) {
  .govuk-input__prefix,
.govuk-input__suffix {
    display: block;
    height: 100%;
    white-space: normal;
  }
}

@media (max-width: 19.99em) {
  .govuk-input__prefix {
    border-bottom: 0;
  }
}
@media (min-width: 20em) {
  .govuk-input__prefix {
    border-right: 0;
  }
}

@media (max-width: 19.99em) {
  .govuk-input__suffix {
    border-top: 0;
  }
}
@media (min-width: 20em) {
  .govuk-input__suffix {
    border-left: 0;
  }
}

/*# sourceMappingURL=_index.scss.map */
/*# sourceMappingURL=_index.scss.map */
/*# sourceMappingURL=_index.scss.map */
.govuk-date-input {
  font-size: 0;
}
.govuk-date-input:after {
  content: "";
  display: block;
  clear: both;
}

.govuk-date-input__item {
  display: inline-block;
  margin-right: 20px;
  margin-bottom: 0;
}

.govuk-date-input__label {
  display: block;
}

.govuk-date-input__input {
  margin-bottom: 0;
}

/*# sourceMappingURL=_index.scss.map */
.govuk-details {
  font-family: Arial, sans-serif;
  -webkit-font-smoothing: antialiased;
  -moz-osx-font-smoothing: grayscale;
  font-weight: 400;
  font-size: 16px;
  font-size: 1rem;
  line-height: 1.25;
  color: #0b0c0c;
  margin-bottom: 20px;
  display: block;
}
@media print {
  .govuk-details {
    font-family: sans-serif;
  }
}
@media (min-width: 40.0625em) {
  .govuk-details {
    font-size: 19px;
    font-size: 1.1875rem;
    line-height: 1.3157894737;
  }
}
@media print {
  .govuk-details {
    font-size: 14pt;
    line-height: 1.15;
  }
}
@media print {
  .govuk-details {
    color: #000000;
  }
}
@media (min-width: 40.0625em) {
  .govuk-details {
    margin-bottom: 30px;
  }
}

.govuk-details__summary {
  display: inline-block;
  position: relative;
  margin-bottom: 5px;
  padding-left: 25px;
  color: #1d70b8;
  cursor: pointer;
}
.govuk-details__summary:hover {
  color: #003078;
}
.govuk-details__summary:focus {
  outline: 3px solid transparent;
  color: #0b0c0c;
  background-color: #ffdd00;
  box-shadow: 0 -2px #ffdd00, 0 4px #0b0c0c;
  text-decoration: none;
  -webkit-box-decoration-break: clone;
  box-decoration-break: clone;
}

.govuk-details__summary-text {
  text-decoration: underline;
}

.govuk-details__summary:focus .govuk-details__summary-text {
  text-decoration: none;
}

.govuk-details__summary::-webkit-details-marker {
  display: none;
}

.govuk-details__summary:before {
  content: "";
  position: absolute;
  top: -1px;
  bottom: 0;
  left: 0;
  margin: auto;
  display: block;
  width: 0;
  height: 0;
  border-style: solid;
  border-color: transparent;
  -webkit-clip-path: polygon(0% 0%, 100% 50%, 0% 100%);
  clip-path: polygon(0% 0%, 100% 50%, 0% 100%);
  border-width: 7px 0 7px 12.124px;
  border-left-color: inherit;
}
.govuk-details[open] > .govuk-details__summary:before {
  display: block;
  width: 0;
  height: 0;
  border-style: solid;
  border-color: transparent;
  -webkit-clip-path: polygon(0% 0%, 50% 100%, 100% 0%);
  clip-path: polygon(0% 0%, 50% 100%, 100% 0%);
  border-width: 12.124px 7px 0 7px;
  border-top-color: inherit;
}

.govuk-details__text {
  padding-top: 15px;
  padding-bottom: 15px;
  padding-left: 20px;
  border-left: 5px solid #b1b4b6;
}

.govuk-details__text p {
  margin-top: 0;
  margin-bottom: 20px;
}

.govuk-details__text > :last-child {
  margin-bottom: 0;
}

/*# sourceMappingURL=_index.scss.map */
/*# sourceMappingURL=_index.scss.map */
/*# sourceMappingURL=_lists.scss.map */
.govuk-error-summary {
  color: #0b0c0c;
  padding: 15px;
  margin-bottom: 30px;
  border: 5px solid #d4351c;
}
@media print {
  .govuk-error-summary {
    color: #000000;
  }
}
@media (min-width: 40.0625em) {
  .govuk-error-summary {
    padding: 20px;
  }
}
@media (min-width: 40.0625em) {
  .govuk-error-summary {
    margin-bottom: 50px;
  }
}
.govuk-error-summary:focus {
  outline: 3px solid #ffdd00;
}

.govuk-error-summary__title {
  font-family: Arial, sans-serif;
  -webkit-font-smoothing: antialiased;
  -moz-osx-font-smoothing: grayscale;
  font-weight: 700;
  font-size: 18px;
  font-size: 1.125rem;
  line-height: 1.1111111111;
  margin-top: 0;
  margin-bottom: 15px;
}
@media print {
  .govuk-error-summary__title {
    font-family: sans-serif;
  }
}
@media (min-width: 40.0625em) {
  .govuk-error-summary__title {
    font-size: 24px;
    font-size: 1.5rem;
    line-height: 1.25;
  }
}
@media print {
  .govuk-error-summary__title {
    font-size: 18pt;
    line-height: 1.15;
  }
}
@media (min-width: 40.0625em) {
  .govuk-error-summary__title {
    margin-bottom: 20px;
  }
}

.govuk-error-summary__body {
  font-family: Arial, sans-serif;
  -webkit-font-smoothing: antialiased;
  -moz-osx-font-smoothing: grayscale;
  font-weight: 400;
  font-size: 16px;
  font-size: 1rem;
  line-height: 1.25;
}
@media print {
  .govuk-error-summary__body {
    font-family: sans-serif;
  }
}
@media (min-width: 40.0625em) {
  .govuk-error-summary__body {
    font-size: 19px;
    font-size: 1.1875rem;
    line-height: 1.3157894737;
  }
}
@media print {
  .govuk-error-summary__body {
    font-size: 14pt;
    line-height: 1.15;
  }
}
.govuk-error-summary__body p {
  margin-top: 0;
  margin-bottom: 15px;
}
@media (min-width: 40.0625em) {
  .govuk-error-summary__body p {
    margin-bottom: 20px;
  }
}

.govuk-error-summary__list {
  margin-top: 0;
  margin-bottom: 0;
}

.govuk-error-summary__list a {
  font-weight: 700;
  font-family: Arial, sans-serif;
  -webkit-font-smoothing: antialiased;
  -moz-osx-font-smoothing: grayscale;
  text-decoration: underline;
}
@media print {
  .govuk-error-summary__list a {
    font-family: sans-serif;
  }
}
.govuk-error-summary__list a:focus {
  outline: 3px solid transparent;
  color: #0b0c0c;
  background-color: #ffdd00;
  box-shadow: 0 -2px #ffdd00, 0 4px #0b0c0c;
  text-decoration: none;
  -webkit-box-decoration-break: clone;
  box-decoration-break: clone;
}
.govuk-error-summary__list a:link, .govuk-error-summary__list a:visited {
  color: #d4351c;
}
.govuk-error-summary__list a:hover {
  color: #942514;
}
.govuk-error-summary__list a:active {
  color: #d4351c;
}
.govuk-error-summary__list a:focus {
  color: #0b0c0c;
}

/*# sourceMappingURL=_index.scss.map */
/*# sourceMappingURL=_index.scss.map */
.govuk-exit-this-page {
  margin-bottom: 30px;
  position: -webkit-sticky;
  position: sticky;
  z-index: 1000;
  top: 0;
  left: 0;
  width: 100%;
}
@media (min-width: 40.0625em) {
  .govuk-exit-this-page {
    margin-bottom: 50px;
  }
}
@media (min-width: 40.0625em) {
  .govuk-exit-this-page {
    display: inline-block;
    right: 0;
    left: auto;
    width: auto;
    float: right;
  }
}

.govuk-exit-this-page__button {
  margin-bottom: 0;
}

.govuk-exit-this-page__indicator {
  padding: 10px;
  display: none;
  padding-bottom: 0;
  color: inherit;
  line-height: 0;
  text-align: center;
  pointer-events: none;
}

.govuk-exit-this-page__indicator--visible {
  display: block;
}

.govuk-exit-this-page__indicator-light {
  box-sizing: border-box;
  display: inline-block;
  width: 0.75em;
  height: 0.75em;
  margin: 0 0.125em;
  border-width: 2px;
  border-style: solid;
  border-radius: 50%;
  border-color: currentcolor;
}

.govuk-exit-this-page__indicator-light--on {
  border-width: 0.375em;
}

@media only print {
  .govuk-exit-this-page {
    display: none;
  }
}
.govuk-exit-this-page-overlay {
  position: fixed;
  z-index: 9999;
  top: 0;
  right: 0;
  bottom: 0;
  left: 0;
  background-color: #ffffff;
}

.govuk-exit-this-page-hide-content * {
  display: none !important;
}
.govuk-exit-this-page-hide-content .govuk-exit-this-page-overlay {
  display: block !important;
}

/*# sourceMappingURL=_index.scss.map */
/*# sourceMappingURL=_index.scss.map */
/*# sourceMappingURL=_index.scss.map */
/*# sourceMappingURL=_index.scss.map */
/*# sourceMappingURL=_index.scss.map */
.govuk-file-upload {
  font-family: Arial, sans-serif;
  -webkit-font-smoothing: antialiased;
  -moz-osx-font-smoothing: grayscale;
  font-weight: 400;
  font-size: 16px;
  font-size: 1rem;
  line-height: 1.25;
  color: #0b0c0c;
  max-width: 100%;
  margin-left: -5px;
  padding: 5px;
}
@media print {
  .govuk-file-upload {
    font-family: sans-serif;
  }
}
@media (min-width: 40.0625em) {
  .govuk-file-upload {
    font-size: 19px;
    font-size: 1.1875rem;
    line-height: 1.3157894737;
  }
}
@media print {
  .govuk-file-upload {
    font-size: 14pt;
    line-height: 1.15;
  }
}
@media print {
  .govuk-file-upload {
    color: #000000;
  }
}
.govuk-file-upload::-webkit-file-upload-button {
  -webkit-appearance: button;
  color: inherit;
  font: inherit;
}
.govuk-file-upload:focus {
  outline: 3px solid #ffdd00;
  box-shadow: inset 0 0 0 4px #0b0c0c;
}
.govuk-file-upload:focus-within {
  outline: 3px solid #ffdd00;
  box-shadow: inset 0 0 0 4px #0b0c0c;
}
.govuk-file-upload:disabled {
  opacity: 0.5;
  cursor: not-allowed;
}

/*# sourceMappingURL=_index.scss.map */
.govuk-footer {
  font-family: Arial, sans-serif;
  -webkit-font-smoothing: antialiased;
  -moz-osx-font-smoothing: grayscale;
  font-weight: 400;
  font-size: 14px;
  font-size: 0.875rem;
  line-height: 1.1428571429;
  padding-top: 25px;
  padding-bottom: 15px;
  border-top: 1px solid #b1b4b6;
  color: #0b0c0c;
  background: #f3f2f1;
}
@media print {
  .govuk-footer {
    font-family: sans-serif;
  }
}
@media (min-width: 40.0625em) {
  .govuk-footer {
    font-size: 16px;
    font-size: 1rem;
    line-height: 1.25;
  }
}
@media print {
  .govuk-footer {
    font-size: 14pt;
    line-height: 1.2;
  }
}
@media (min-width: 40.0625em) {
  .govuk-footer {
    padding-top: 40px;
  }
}
@media (min-width: 40.0625em) {
  .govuk-footer {
    padding-bottom: 25px;
  }
}

.govuk-footer__link {
  font-family: Arial, sans-serif;
  -webkit-font-smoothing: antialiased;
  -moz-osx-font-smoothing: grayscale;
  text-decoration: underline;
}
@media print {
  .govuk-footer__link {
    font-family: sans-serif;
  }
}
.govuk-footer__link:focus {
  outline: 3px solid transparent;
  color: #0b0c0c;
  background-color: #ffdd00;
  box-shadow: 0 -2px #ffdd00, 0 4px #0b0c0c;
  text-decoration: none;
  -webkit-box-decoration-break: clone;
  box-decoration-break: clone;
}
.govuk-footer__link:link, .govuk-footer__link:visited {
  color: #0b0c0c;
}
@media print {
  .govuk-footer__link:link, .govuk-footer__link:visited {
    color: #000000;
  }
}
.govuk-footer__link:hover {
  color: rgba(11, 12, 12, 0.99);
}
.govuk-footer__link:active, .govuk-footer__link:focus {
  color: #0b0c0c;
}
@media print {
  .govuk-footer__link:active, .govuk-footer__link:focus {
    color: #000000;
  }
}

.govuk-footer__section-break {
  margin: 0;
  margin-bottom: 30px;
  border: 0;
  border-bottom: 1px solid #b1b4b6;
}
@media (min-width: 40.0625em) {
  .govuk-footer__section-break {
    margin-bottom: 50px;
  }
}

.govuk-footer__meta {
  display: -ms-flexbox;
  display: flex;
  margin-right: -15px;
  margin-left: -15px;
  -ms-flex-wrap: wrap;
  flex-wrap: wrap;
  -ms-flex-align: end;
  align-items: flex-end;
  -ms-flex-pack: center;
  justify-content: center;
}

.govuk-footer__meta-item {
  margin-right: 15px;
  margin-bottom: 25px;
  margin-left: 15px;
}

.govuk-footer__meta-item--grow {
  -ms-flex: 1;
  flex: 1;
}
@media (max-width: 40.0525em) {
  .govuk-footer__meta-item--grow {
    -ms-flex-preferred-size: 320px;
    flex-basis: 320px;
  }
}

.govuk-footer__licence-logo {
  display: inline-block;
  margin-right: 10px;
  vertical-align: top;
  forced-color-adjust: auto;
}
@media (max-width: 48.0525em) {
  .govuk-footer__licence-logo {
    margin-bottom: 15px;
  }
}

.govuk-footer__licence-description {
  display: inline-block;
}

.govuk-footer__copyright-logo {
  display: inline-block;
  min-width: 125px;
  padding-top: 112px;
  background-image: url("/assets/images/govuk-crest.png");
  background-repeat: no-repeat;
  background-position: 50% 0%;
  background-size: 125px 102px;
  text-align: center;
  white-space: nowrap;
}
@media only screen and (-webkit-min-device-pixel-ratio: 2), only screen and (min-resolution: 192dpi), only screen and (min-resolution: 2dppx) {
  .govuk-footer__copyright-logo {
    background-image: url("/assets/images/govuk-crest-2x.png");
  }
}

.govuk-footer__inline-list {
  margin-top: 0;
  margin-bottom: 15px;
  padding: 0;
}

.govuk-footer__meta-custom {
  margin-bottom: 20px;
}

.govuk-footer__inline-list-item {
  display: inline-block;
  margin-right: 15px;
  margin-bottom: 5px;
}

.govuk-footer__heading {
  margin-bottom: 30px;
  padding-bottom: 20px;
  border-bottom: 1px solid #b1b4b6;
}
@media (max-width: 40.0525em) {
  .govuk-footer__heading {
    padding-bottom: 10px;
  }
}

.govuk-footer__navigation {
  margin-right: -15px;
  margin-left: -15px;
}
.govuk-footer__navigation:after {
  content: "";
  display: block;
  clear: both;
}

.govuk-footer__section {
  display: inline-block;
  margin-bottom: 30px;
  vertical-align: top;
}

.govuk-footer__list {
  margin: 0;
  padding: 0;
  list-style: none;
  column-gap: 30px;
}

@media (min-width: 48.0625em) {
  .govuk-footer__list--columns-2 {
    column-count: 2;
  }
  .govuk-footer__list--columns-3 {
    column-count: 3;
  }
}
.govuk-footer__list-item {
  margin-bottom: 15px;
}
@media (min-width: 40.0625em) {
  .govuk-footer__list-item {
    margin-bottom: 20px;
  }
}

.govuk-footer__list-item:last-child {
  margin-bottom: 0;
}

/*# sourceMappingURL=_index.scss.map */
.govuk-header {
  font-family: Arial, sans-serif;
  -webkit-font-smoothing: antialiased;
  -moz-osx-font-smoothing: grayscale;
  font-weight: 400;
  font-size: 14px;
  font-size: 0.875rem;
  line-height: 1.1428571429;
  border-bottom: 10px solid #ffffff;
  color: #ffffff;
  background: #0b0c0c;
}
@media print {
  .govuk-header {
    font-family: sans-serif;
  }
}
@media (min-width: 40.0625em) {
  .govuk-header {
    font-size: 16px;
    font-size: 1rem;
    line-height: 1.25;
  }
}
@media print {
  .govuk-header {
    font-size: 14pt;
    line-height: 1.2;
  }
}

.govuk-header__container--full-width {
  padding: 0 15px;
  border-color: #1d70b8;
}
.govuk-header__container--full-width .govuk-header__menu-button {
  right: 15px;
}

.govuk-header__container {
  position: relative;
  margin-bottom: -10px;
  padding-top: 10px;
  border-bottom: 10px solid #1d70b8;
}
.govuk-header__container:after {
  content: "";
  display: block;
  clear: both;
}

.govuk-header__logotype {
  display: inline-block;
  margin-right: 5px;
}
@media (forced-colors: active) {
  .govuk-header__logotype {
    forced-color-adjust: none;
    color: linktext;
  }
}
.govuk-header__logotype:last-child {
  margin-right: 0;
}

.govuk-header__logotype-crown {
  position: relative;
  top: -1px;
  margin-right: 1px;
  fill: currentcolor;
  vertical-align: top;
}

.govuk-header__logotype-crown[width="32"] {
  top: -3px;
  margin-right: 2px;
}

.govuk-header__logotype-crown-fallback-image {
  width: 36px;
  height: 32px;
  border: 0;
  vertical-align: bottom;
}

.govuk-header__logotype-crown-fallback-image[width="32"] {
  width: 32px;
  height: 30px;
}

.govuk-header__product-name {
  font-family: Arial, sans-serif;
  -webkit-font-smoothing: antialiased;
  -moz-osx-font-smoothing: grayscale;
  font-weight: 400;
  font-size: 18px;
  font-size: 1.125rem;
  line-height: 1;
  display: inline-table;
}
@media print {
  .govuk-header__product-name {
    font-family: sans-serif;
  }
}
@media (min-width: 40.0625em) {
  .govuk-header__product-name {
    font-size: 24px;
    font-size: 1.5rem;
    line-height: 1;
  }
}
@media print {
  .govuk-header__product-name {
    font-size: 18pt;
    line-height: 1;
  }
}

.govuk-header__link {
  font-family: Arial, sans-serif;
  -webkit-font-smoothing: antialiased;
  -moz-osx-font-smoothing: grayscale;
  text-decoration: none;
}
@media print {
  .govuk-header__link {
    font-family: sans-serif;
  }
}
.govuk-header__link:link, .govuk-header__link:visited {
  color: #ffffff;
}
.govuk-header__link:hover, .govuk-header__link:active {
  color: rgba(255, 255, 255, 0.99);
}
.govuk-header__link:focus {
  color: #0b0c0c;
}
.govuk-header__link:hover {
  text-decoration: underline;
  text-decoration-thickness: 3px;
  text-underline-offset: 0.1578em;
}
.govuk-header__link:focus {
  outline: 3px solid transparent;
  color: #0b0c0c;
  background-color: #ffdd00;
  box-shadow: 0 -2px #ffdd00, 0 4px #0b0c0c;
  text-decoration: none;
  -webkit-box-decoration-break: clone;
  box-decoration-break: clone;
}

.govuk-header__link--homepage {
  font-family: Arial, sans-serif;
  -webkit-font-smoothing: antialiased;
  -moz-osx-font-smoothing: grayscale;
  font-weight: 700;
  display: inline-block;
  margin-right: 10px;
  font-size: 30px;
  line-height: 1;
}
@media print {
  .govuk-header__link--homepage {
    font-family: sans-serif;
  }
}
@media (min-width: 40.0625em) {
  .govuk-header__link--homepage {
    display: inline;
  }
  .govuk-header__link--homepage:focus {
    box-shadow: 0 0 #ffdd00;
  }
}
.govuk-header__link--homepage:link, .govuk-header__link--homepage:visited {
  text-decoration: none;
}
.govuk-header__link--homepage:hover, .govuk-header__link--homepage:active {
  margin-bottom: -3px;
  border-bottom: 3px solid;
}
.govuk-header__link--homepage:focus {
  margin-bottom: 0;
  border-bottom: 0;
}

.govuk-header__service-name,
.govuk-header__link--service-name {
  display: inline-block;
  margin-bottom: 10px;
  font-family: Arial, sans-serif;
  -webkit-font-smoothing: antialiased;
  -moz-osx-font-smoothing: grayscale;
  font-weight: 700;
  font-size: 18px;
  font-size: 1.125rem;
  line-height: 1.1111111111;
}
@media print {
  .govuk-header__service-name,
.govuk-header__link--service-name {
    font-family: sans-serif;
  }
}
@media (min-width: 40.0625em) {
  .govuk-header__service-name,
.govuk-header__link--service-name {
    font-size: 24px;
    font-size: 1.5rem;
    line-height: 1.25;
  }
}
@media print {
  .govuk-header__service-name,
.govuk-header__link--service-name {
    font-size: 18pt;
    line-height: 1.15;
  }
}

.govuk-header__logo,
.govuk-header__content {
  box-sizing: border-box;
}

.govuk-header__logo {
  margin-bottom: 10px;
  padding-right: 50px;
}
@media (min-width: 48.0625em) {
  .govuk-header__logo {
    width: 33.33%;
    padding-right: 15px;
    float: left;
    vertical-align: top;
  }
}

@media (min-width: 48.0625em) {
  .govuk-header__content {
    width: 66.66%;
    padding-left: 15px;
    float: left;
  }
}

.govuk-header__menu-button {
  font-family: Arial, sans-serif;
  -webkit-font-smoothing: antialiased;
  -moz-osx-font-smoothing: grayscale;
  font-weight: 400;
  font-size: 14px;
  font-size: 0.875rem;
  line-height: 1.1428571429;
  display: none;
  position: absolute;
  top: 20px;
  right: 0;
  margin: 0;
  padding: 0;
  border: 0;
  color: #ffffff;
  background: none;
  cursor: pointer;
}
@media print {
  .govuk-header__menu-button {
    font-family: sans-serif;
  }
}
@media (min-width: 40.0625em) {
  .govuk-header__menu-button {
    font-size: 16px;
    font-size: 1rem;
    line-height: 1.25;
  }
}
@media print {
  .govuk-header__menu-button {
    font-size: 14pt;
    line-height: 1.2;
  }
}
.govuk-header__menu-button:hover {
  -webkit-text-decoration: solid underline 3px;
  text-decoration: solid underline 3px;
  text-underline-offset: 0.1578em;
}
.govuk-header__menu-button:focus {
  outline: 3px solid transparent;
  color: #0b0c0c;
  background-color: #ffdd00;
  box-shadow: 0 -2px #ffdd00, 0 4px #0b0c0c;
  text-decoration: none;
  -webkit-box-decoration-break: clone;
  box-decoration-break: clone;
}
.govuk-header__menu-button:after {
  display: inline-block;
  width: 0;
  height: 0;
  border-style: solid;
  border-color: transparent;
  -webkit-clip-path: polygon(0% 0%, 50% 100%, 100% 0%);
  clip-path: polygon(0% 0%, 50% 100%, 100% 0%);
  border-width: 8.66px 5px 0 5px;
  border-top-color: inherit;
  content: "";
  margin-left: 5px;
}
.govuk-header__menu-button[aria-expanded=true]:after {
  display: inline-block;
  width: 0;
  height: 0;
  border-style: solid;
  border-color: transparent;
  -webkit-clip-path: polygon(50% 0%, 0% 100%, 100% 100%);
  clip-path: polygon(50% 0%, 0% 100%, 100% 100%);
  border-width: 0 5px 8.66px 5px;
  border-bottom-color: inherit;
}
@media (min-width: 40.0625em) {
  .govuk-header__menu-button {
    top: 15px;
  }
}
.js-enabled .govuk-header__menu-button {
  display: block;
}
.govuk-header__menu-button[hidden], .js-enabled .govuk-header__menu-button[hidden] {
  display: none;
}

@media (min-width: 48.0625em) {
  .govuk-header__navigation {
    margin-bottom: 10px;
  }
}

.govuk-header__navigation-list {
  margin: 0;
  padding: 0;
  list-style: none;
}
.govuk-header__navigation-list[hidden] {
  display: none;
}

@media (min-width: 48.0625em) {
  .govuk-header__navigation--end {
    margin: 0;
    padding: 5px 0;
    text-align: right;
  }
}

.govuk-header__navigation--no-service-name {
  padding-top: 40px;
}

.govuk-header__navigation-item {
  padding: 10px 0;
  border-bottom: 1px solid #2e3133;
}
@media (min-width: 48.0625em) {
  .govuk-header__navigation-item {
    display: inline-block;
    margin-right: 15px;
    padding: 5px 0;
    border: 0;
  }
}
.govuk-header__navigation-item a {
  font-family: Arial, sans-serif;
  -webkit-font-smoothing: antialiased;
  -moz-osx-font-smoothing: grayscale;
  font-weight: 700;
  font-size: 14px;
  font-size: 0.875rem;
  line-height: 1.1428571429;
  white-space: nowrap;
}
@media print {
  .govuk-header__navigation-item a {
    font-family: sans-serif;
  }
}
@media (min-width: 40.0625em) {
  .govuk-header__navigation-item a {
    font-size: 16px;
    font-size: 1rem;
    line-height: 1.25;
  }
}
@media print {
  .govuk-header__navigation-item a {
    font-size: 14pt;
    line-height: 1.2;
  }
}

.govuk-header__navigation-item--active a:link, .govuk-header__navigation-item--active a:hover, .govuk-header__navigation-item--active a:visited {
  color: #1d8feb;
}
@media print {
  .govuk-header__navigation-item--active a {
    color: #1d70b8;
  }
}
.govuk-header__navigation-item--active a:focus {
  color: #0b0c0c;
}

.govuk-header__navigation-item:last-child {
  margin-right: 0;
  border-bottom: 0;
}

@media print {
  .govuk-header {
    border-bottom-width: 0;
    color: #0b0c0c;
    background: transparent;
  }
  .govuk-header__logotype-crown-fallback-image {
    display: none;
  }
  .govuk-header__link:link, .govuk-header__link:visited {
    color: #0b0c0c;
  }
  .govuk-header__link:after {
    display: none;
  }
}
/*# sourceMappingURL=_index.scss.map */
/*# sourceMappingURL=_index.scss.map */
/*# sourceMappingURL=_index.scss.map */
/*# sourceMappingURL=_index.scss.map */
/*# sourceMappingURL=_index.scss.map */
/*# sourceMappingURL=_index.scss.map */
.govuk-inset-text {
  font-family: Arial, sans-serif;
  -webkit-font-smoothing: antialiased;
  -moz-osx-font-smoothing: grayscale;
  font-weight: 400;
  font-size: 16px;
  font-size: 1rem;
  line-height: 1.25;
  color: #0b0c0c;
  padding: 15px;
  margin-top: 20px;
  margin-bottom: 20px;
  clear: both;
  border-left: 10px solid #b1b4b6;
}
@media print {
  .govuk-inset-text {
    font-family: sans-serif;
  }
}
@media (min-width: 40.0625em) {
  .govuk-inset-text {
    font-size: 19px;
    font-size: 1.1875rem;
    line-height: 1.3157894737;
  }
}
@media print {
  .govuk-inset-text {
    font-size: 14pt;
    line-height: 1.15;
  }
}
@media print {
  .govuk-inset-text {
    color: #000000;
  }
}
@media (min-width: 40.0625em) {
  .govuk-inset-text {
    margin-top: 30px;
  }
}
@media (min-width: 40.0625em) {
  .govuk-inset-text {
    margin-bottom: 30px;
  }
}
.govuk-inset-text > :first-child {
  margin-top: 0;
}
.govuk-inset-text > :only-child,
.govuk-inset-text > :last-child {
  margin-bottom: 0;
}

/*# sourceMappingURL=_index.scss.map */
/*# sourceMappingURL=_index.scss.map */
.govuk-notification-banner {
  font-family: Arial, sans-serif;
  -webkit-font-smoothing: antialiased;
  -moz-osx-font-smoothing: grayscale;
  font-weight: 400;
  font-size: 16px;
  font-size: 1rem;
  line-height: 1.25;
  margin-bottom: 30px;
  border: 5px solid #1d70b8;
  background-color: #1d70b8;
}
@media print {
  .govuk-notification-banner {
    font-family: sans-serif;
  }
}
@media (min-width: 40.0625em) {
  .govuk-notification-banner {
    font-size: 19px;
    font-size: 1.1875rem;
    line-height: 1.3157894737;
  }
}
@media print {
  .govuk-notification-banner {
    font-size: 14pt;
    line-height: 1.15;
  }
}
@media (min-width: 40.0625em) {
  .govuk-notification-banner {
    margin-bottom: 50px;
  }
}
.govuk-notification-banner:focus {
  outline: 3px solid #ffdd00;
}

.govuk-notification-banner__header {
  padding: 2px 15px 5px;
  border-bottom: 1px solid transparent;
}
@media (min-width: 40.0625em) {
  .govuk-notification-banner__header {
    padding: 2px 20px 5px;
  }
}

.govuk-notification-banner__title {
  font-family: Arial, sans-serif;
  -webkit-font-smoothing: antialiased;
  -moz-osx-font-smoothing: grayscale;
  font-weight: 700;
  font-size: 16px;
  font-size: 1rem;
  line-height: 1.25;
  margin: 0;
  padding: 0;
  color: #ffffff;
}
@media print {
  .govuk-notification-banner__title {
    font-family: sans-serif;
  }
}
@media (min-width: 40.0625em) {
  .govuk-notification-banner__title {
    font-size: 19px;
    font-size: 1.1875rem;
    line-height: 1.3157894737;
  }
}
@media print {
  .govuk-notification-banner__title {
    font-size: 14pt;
    line-height: 1.15;
  }
}

.govuk-notification-banner__content {
  color: #0b0c0c;
  padding: 15px;
  background-color: #ffffff;
}
@media print {
  .govuk-notification-banner__content {
    color: #000000;
  }
}
@media (min-width: 40.0625em) {
  .govuk-notification-banner__content {
    padding: 20px;
  }
}
.govuk-notification-banner__content > * {
  box-sizing: border-box;
  max-width: 1245px;
}
.govuk-notification-banner__content > :last-child {
  margin-bottom: 0;
}

.govuk-notification-banner__heading {
  font-family: Arial, sans-serif;
  -webkit-font-smoothing: antialiased;
  -moz-osx-font-smoothing: grayscale;
  font-weight: 700;
  font-size: 18px;
  font-size: 1.125rem;
  line-height: 1.1111111111;
  margin: 0 0 15px 0;
  padding: 0;
}
@media print {
  .govuk-notification-banner__heading {
    font-family: sans-serif;
  }
}
@media (min-width: 40.0625em) {
  .govuk-notification-banner__heading {
    font-size: 24px;
    font-size: 1.5rem;
    line-height: 1.25;
  }
}
@media print {
  .govuk-notification-banner__heading {
    font-size: 18pt;
    line-height: 1.15;
  }
}

.govuk-notification-banner__link {
  font-family: Arial, sans-serif;
  -webkit-font-smoothing: antialiased;
  -moz-osx-font-smoothing: grayscale;
  text-decoration: underline;
}
@media print {
  .govuk-notification-banner__link {
    font-family: sans-serif;
  }
}
.govuk-notification-banner__link:focus {
  outline: 3px solid transparent;
  color: #0b0c0c;
  background-color: #ffdd00;
  box-shadow: 0 -2px #ffdd00, 0 4px #0b0c0c;
  text-decoration: none;
  -webkit-box-decoration-break: clone;
  box-decoration-break: clone;
}
.govuk-notification-banner__link:link {
  color: #1d70b8;
}
.govuk-notification-banner__link:visited {
  color: #1d70b8;
}
.govuk-notification-banner__link:hover {
  color: #003078;
}
.govuk-notification-banner__link:active {
  color: #0b0c0c;
}
.govuk-notification-banner__link:focus {
  color: #0b0c0c;
}

.govuk-notification-banner--success {
  border-color: #00703c;
  background-color: #00703c;
}
.govuk-notification-banner--success .govuk-notification-banner__link:link, .govuk-notification-banner--success .govuk-notification-banner__link:visited {
  color: #00703c;
}
.govuk-notification-banner--success .govuk-notification-banner__link:hover {
  color: #004e2a;
}
.govuk-notification-banner--success .govuk-notification-banner__link:active {
  color: #00703c;
}
.govuk-notification-banner--success .govuk-notification-banner__link:focus {
  color: #0b0c0c;
}

/*# sourceMappingURL=_index.scss.map */
.govuk-pagination {
  margin-bottom: 20px;
  display: -ms-flexbox;
  display: flex;
  -ms-flex-direction: column;
  flex-direction: column;
  -ms-flex-align: center;
  align-items: center;
  -ms-flex-wrap: wrap;
  flex-wrap: wrap;
}
@media (min-width: 40.0625em) {
  .govuk-pagination {
    margin-bottom: 30px;
  }
}
@media (min-width: 40.0625em) {
  .govuk-pagination {
    -ms-flex-direction: row;
    flex-direction: row;
    -ms-flex-align: start;
    align-items: flex-start;
  }
}

.govuk-pagination__list {
  margin: 0;
  padding: 0;
  list-style: none;
}

.govuk-pagination__item,
.govuk-pagination__next,
.govuk-pagination__prev {
  font-family: Arial, sans-serif;
  -webkit-font-smoothing: antialiased;
  -moz-osx-font-smoothing: grayscale;
  font-weight: 400;
  font-size: 16px;
  font-size: 1rem;
  line-height: 1.25;
  box-sizing: border-box;
  position: relative;
  min-width: 45px;
  min-height: 45px;
  padding: 10px 15px;
  float: left;
}
@media print {
  .govuk-pagination__item,
.govuk-pagination__next,
.govuk-pagination__prev {
    font-family: sans-serif;
  }
}
@media (min-width: 40.0625em) {
  .govuk-pagination__item,
.govuk-pagination__next,
.govuk-pagination__prev {
    font-size: 19px;
    font-size: 1.1875rem;
    line-height: 1.3157894737;
  }
}
@media print {
  .govuk-pagination__item,
.govuk-pagination__next,
.govuk-pagination__prev {
    font-size: 14pt;
    line-height: 1.15;
  }
}
.govuk-pagination__item:hover,
.govuk-pagination__next:hover,
.govuk-pagination__prev:hover {
  background-color: #f3f2f1;
}

.govuk-pagination__item {
  display: none;
  text-align: center;
}
@media (min-width: 40.0625em) {
  .govuk-pagination__item {
    display: block;
  }
}

.govuk-pagination__prev,
.govuk-pagination__next {
  font-weight: 700;
}
.govuk-pagination__prev .govuk-pagination__link,
.govuk-pagination__next .govuk-pagination__link {
  display: -ms-flexbox;
  display: flex;
  -ms-flex-align: center;
  align-items: center;
}

.govuk-pagination__prev {
  padding-left: 0;
}

.govuk-pagination__next {
  padding-right: 0;
}

.govuk-pagination__item--current,
.govuk-pagination__item--ellipses,
.govuk-pagination__item:first-child,
.govuk-pagination__item:last-child {
  display: block;
}

.govuk-pagination__item--current {
  font-weight: 700;
  outline: 1px solid transparent;
  background-color: #1d70b8;
}
.govuk-pagination__item--current:hover {
  background-color: #1d70b8;
}
.govuk-pagination__item--current .govuk-pagination__link:link, .govuk-pagination__item--current .govuk-pagination__link:visited {
  color: #ffffff;
}
.govuk-pagination__item--current .govuk-pagination__link:hover, .govuk-pagination__item--current .govuk-pagination__link:active {
  color: rgba(255, 255, 255, 0.99);
}
.govuk-pagination__item--current .govuk-pagination__link:focus {
  color: #0b0c0c;
}

.govuk-pagination__item--ellipses {
  font-weight: 700;
  color: #6B7276;
}
.govuk-pagination__item--ellipses:hover {
  background-color: transparent;
}

.govuk-pagination__link {
  display: block;
  min-width: 15px;
}
@media screen {
  .govuk-pagination__link:after {
    content: "";
    position: absolute;
    top: 0;
    right: 0;
    bottom: 0;
    left: 0;
  }
}
.govuk-pagination__link:hover .govuk-pagination__link-title--decorated, .govuk-pagination__link:active .govuk-pagination__link-title--decorated {
  text-decoration: underline;
}
.govuk-pagination__link:focus .govuk-pagination__icon {
  color: #0b0c0c;
}
.govuk-pagination__link:focus .govuk-pagination__link-label {
  text-decoration: none;
}
.govuk-pagination__link:focus .govuk-pagination__link-title--decorated {
  text-decoration: none;
}

.govuk-pagination__link-label {
  font-family: Arial, sans-serif;
  -webkit-font-smoothing: antialiased;
  -moz-osx-font-smoothing: grayscale;
  font-weight: 400;
  font-size: 16px;
  font-size: 1rem;
  line-height: 1.25;
  text-decoration: underline;
  display: inline-block;
  padding-left: 30px;
}
@media print {
  .govuk-pagination__link-label {
    font-family: sans-serif;
  }
}
@media (min-width: 40.0625em) {
  .govuk-pagination__link-label {
    font-size: 19px;
    font-size: 1.1875rem;
    line-height: 1.3157894737;
  }
}
@media print {
  .govuk-pagination__link-label {
    font-size: 14pt;
    line-height: 1.15;
  }
}

.govuk-pagination__icon {
  width: 0.9375rem;
  height: 0.8125rem;
  color: #6B7276;
  fill: currentcolor;
  forced-color-adjust: auto;
}

.govuk-pagination__icon--prev {
  margin-right: 15px;
}

.govuk-pagination__icon--next {
  margin-left: 15px;
}

.govuk-pagination--block {
  display: block;
}
.govuk-pagination--block .govuk-pagination__item {
  padding: 15px;
  float: none;
}
.govuk-pagination--block .govuk-pagination__next,
.govuk-pagination--block .govuk-pagination__prev {
  padding-left: 0;
  float: none;
}
.govuk-pagination--block .govuk-pagination__next {
  padding-right: 15px;
}
.govuk-pagination--block .govuk-pagination__next .govuk-pagination__icon {
  margin-left: 0;
}
.govuk-pagination--block .govuk-pagination__prev + .govuk-pagination__next {
  border-top: 1px solid #b1b4b6;
}
.govuk-pagination--block .govuk-pagination__link,
.govuk-pagination--block .govuk-pagination__link-title {
  display: inline;
}
.govuk-pagination--block .govuk-pagination__link-title:after {
  content: "";
  display: block;
}
.govuk-pagination--block .govuk-pagination__link {
  text-align: left;
}
.govuk-pagination--block .govuk-pagination__link:focus .govuk-pagination__link-label {
  outline: 3px solid transparent;
  color: #0b0c0c;
  background-color: #ffdd00;
  box-shadow: 0 -2px #ffdd00, 0 4px #0b0c0c;
  text-decoration: none;
  -webkit-box-decoration-break: clone;
  box-decoration-break: clone;
}
.govuk-pagination--block .govuk-pagination__link:not(:focus) {
  text-decoration: none;
}
.govuk-pagination--block .govuk-pagination__icon {
  margin-right: 10px;
}

/*# sourceMappingURL=_index.scss.map */
.govuk-panel {
  font-family: Arial, sans-serif;
  -webkit-font-smoothing: antialiased;
  -moz-osx-font-smoothing: grayscale;
  font-weight: 400;
  font-size: 16px;
  font-size: 1rem;
  line-height: 1.25;
  box-sizing: border-box;
  margin-bottom: 15px;
  padding: 35px;
  border: 5px solid transparent;
  text-align: center;
}
@media print {
  .govuk-panel {
    font-family: sans-serif;
  }
}
@media (min-width: 40.0625em) {
  .govuk-panel {
    font-size: 19px;
    font-size: 1.1875rem;
    line-height: 1.3157894737;
  }
}
@media print {
  .govuk-panel {
    font-size: 14pt;
    line-height: 1.15;
  }
}
@media (max-width: 40.0525em) {
  .govuk-panel {
    padding: 10px;
    overflow-wrap: break-word;
    word-wrap: break-word;
  }
}

.govuk-panel--confirmation {
  color: #ffffff;
  background: #00703c;
}
@media print {
  .govuk-panel--confirmation {
    border-color: currentcolor;
    color: #000000;
    background: none;
  }
}

.govuk-panel__title {
  margin-top: 0;
  margin-bottom: 30px;
  font-family: Arial, sans-serif;
  -webkit-font-smoothing: antialiased;
  -moz-osx-font-smoothing: grayscale;
  font-weight: 700;
  font-size: 32px;
  font-size: 2rem;
  line-height: 1.09375;
}
@media print {
  .govuk-panel__title {
    font-family: sans-serif;
  }
}
@media (min-width: 40.0625em) {
  .govuk-panel__title {
    font-size: 48px;
    font-size: 3rem;
    line-height: 1.0416666667;
  }
}
@media print {
  .govuk-panel__title {
    font-size: 32pt;
    line-height: 1.15;
  }
}

.govuk-panel__title:last-child {
  margin-bottom: 0;
}

.govuk-panel__body {
  font-family: Arial, sans-serif;
  -webkit-font-smoothing: antialiased;
  -moz-osx-font-smoothing: grayscale;
  font-weight: 400;
  font-size: 24px;
  font-size: 1.5rem;
  line-height: 1.0416666667;
}
@media print {
  .govuk-panel__body {
    font-family: sans-serif;
  }
}
@media (min-width: 40.0625em) {
  .govuk-panel__body {
    font-size: 36px;
    font-size: 2.25rem;
    line-height: 1.1111111111;
  }
}
@media print {
  .govuk-panel__body {
    font-size: 24pt;
    line-height: 1.05;
  }
}

/*# sourceMappingURL=_index.scss.map */
.govuk-tag {
  display: inline-block;
  outline: 2px solid transparent;
  outline-offset: -2px;
  color: #ffffff;
  background-color: #1d70b8;
  letter-spacing: 1px;
  text-decoration: none;
  text-transform: uppercase;
  font-family: Arial, sans-serif;
  -webkit-font-smoothing: antialiased;
  -moz-osx-font-smoothing: grayscale;
  font-weight: 700;
  font-size: 14px;
  font-size: 0.875rem;
  line-height: 1;
  padding-top: 5px;
  padding-right: 8px;
  padding-bottom: 4px;
  padding-left: 8px;
}
@media print {
  .govuk-tag {
    font-family: sans-serif;
  }
}
@media (min-width: 40.0625em) {
  .govuk-tag {
    font-size: 16px;
    font-size: 1rem;
    line-height: 1;
  }
}
@media print {
  .govuk-tag {
    font-size: 14pt;
    line-height: 1;
  }
}

.govuk-tag--grey {
  color: #383f43;
  background: #eeefef;
}

.govuk-tag--purple {
  color: #3d2375;
  background: #dbd5e9;
}

.govuk-tag--turquoise {
  color: #10403c;
  background: #bfe3e0;
}

.govuk-tag--blue {
  color: #144e81;
  background: #d2e2f1;
}

.govuk-tag--yellow {
  color: #594d00;
  background: #fff7bf;
}

.govuk-tag--orange {
  color: #6e3619;
  background: #fcd6c3;
}

.govuk-tag--red {
  color: #942514;
  background: #f6d7d2;
}

.govuk-tag--pink {
  color: #80224d;
  background: #f7d7e6;
}

.govuk-tag--green {
  color: #005a30;
  background: #cce2d8;
}

/*# sourceMappingURL=_index.scss.map */
.govuk-phase-banner {
  padding-top: 10px;
  padding-bottom: 10px;
  border-bottom: 1px solid #b1b4b6;
}

.govuk-phase-banner__content {
  font-family: Arial, sans-serif;
  -webkit-font-smoothing: antialiased;
  -moz-osx-font-smoothing: grayscale;
  font-weight: 400;
  font-size: 14px;
  font-size: 0.875rem;
  line-height: 1.1428571429;
  color: #0b0c0c;
  display: table;
  margin: 0;
}
@media print {
  .govuk-phase-banner__content {
    font-family: sans-serif;
  }
}
@media (min-width: 40.0625em) {
  .govuk-phase-banner__content {
    font-size: 16px;
    font-size: 1rem;
    line-height: 1.25;
  }
}
@media print {
  .govuk-phase-banner__content {
    font-size: 14pt;
    line-height: 1.2;
  }
}
@media print {
  .govuk-phase-banner__content {
    color: #000000;
  }
}

.govuk-phase-banner__content__tag {
  margin-right: 10px;
}

.govuk-phase-banner__text {
  display: table-cell;
  vertical-align: middle;
}

/*# sourceMappingURL=_index.scss.map */
.govuk-tabs {
  margin-top: 5px;
  margin-bottom: 20px;
}
@media (min-width: 40.0625em) {
  .govuk-tabs {
    margin-bottom: 30px;
  }
}

.govuk-tabs__title {
  font-family: Arial, sans-serif;
  -webkit-font-smoothing: antialiased;
  -moz-osx-font-smoothing: grayscale;
  font-weight: 400;
  font-size: 16px;
  font-size: 1rem;
  line-height: 1.25;
  color: #0b0c0c;
  margin-bottom: 10px;
}
@media print {
  .govuk-tabs__title {
    font-family: sans-serif;
  }
}
@media (min-width: 40.0625em) {
  .govuk-tabs__title {
    font-size: 19px;
    font-size: 1.1875rem;
    line-height: 1.3157894737;
  }
}
@media print {
  .govuk-tabs__title {
    font-size: 14pt;
    line-height: 1.15;
  }
}
@media print {
  .govuk-tabs__title {
    color: #000000;
  }
}

.govuk-tabs__list {
  margin: 0;
  padding: 0;
  list-style: none;
  margin-bottom: 20px;
}
@media (min-width: 40.0625em) {
  .govuk-tabs__list {
    margin-bottom: 30px;
  }
}

.govuk-tabs__list-item {
  font-family: Arial, sans-serif;
  -webkit-font-smoothing: antialiased;
  -moz-osx-font-smoothing: grayscale;
  font-weight: 400;
  font-size: 16px;
  font-size: 1rem;
  line-height: 1.25;
  margin-left: 25px;
}
@media print {
  .govuk-tabs__list-item {
    font-family: sans-serif;
  }
}
@media (min-width: 40.0625em) {
  .govuk-tabs__list-item {
    font-size: 19px;
    font-size: 1.1875rem;
    line-height: 1.3157894737;
  }
}
@media print {
  .govuk-tabs__list-item {
    font-size: 14pt;
    line-height: 1.15;
  }
}
.govuk-tabs__list-item:before {
  color: #0b0c0c;
  content: "—";
  margin-left: -25px;
  padding-right: 5px;
}
@media print {
  .govuk-tabs__list-item:before {
    color: #000000;
  }
}

.govuk-tabs__tab {
  font-family: Arial, sans-serif;
  -webkit-font-smoothing: antialiased;
  -moz-osx-font-smoothing: grayscale;
  text-decoration: underline;
  display: inline-block;
  margin-bottom: 10px;
}
@media print {
  .govuk-tabs__tab {
    font-family: sans-serif;
  }
}
.govuk-tabs__tab:focus {
  outline: 3px solid transparent;
  color: #0b0c0c;
  background-color: #ffdd00;
  box-shadow: 0 -2px #ffdd00, 0 4px #0b0c0c;
  text-decoration: none;
  -webkit-box-decoration-break: clone;
  box-decoration-break: clone;
}
.govuk-tabs__tab:link {
  color: #1d70b8;
}
.govuk-tabs__tab:visited {
  color: #4c2c92;
}
.govuk-tabs__tab:hover {
  color: #003078;
}
.govuk-tabs__tab:active {
  color: #0b0c0c;
}
.govuk-tabs__tab:focus {
  color: #0b0c0c;
}

.govuk-tabs__panel {
  margin-bottom: 30px;
}
@media (min-width: 40.0625em) {
  .govuk-tabs__panel {
    margin-bottom: 50px;
  }
}

@media (min-width: 40.0625em) {
  .js-enabled .govuk-tabs__list {
    margin-bottom: 0;
    border-bottom: 1px solid #b1b4b6;
  }
  .js-enabled .govuk-tabs__list:after {
    content: "";
    display: block;
    clear: both;
  }
  .js-enabled .govuk-tabs__title {
    display: none;
  }
  .js-enabled .govuk-tabs__list-item {
    position: relative;
    margin-right: 5px;
    margin-bottom: 0;
    margin-left: 0;
    padding: 10px 20px;
    float: left;
    background-color: #f3f2f1;
    text-align: center;
  }
  .js-enabled .govuk-tabs__list-item:before {
    content: none;
  }
  .js-enabled .govuk-tabs__list-item--selected {
    position: relative;
    margin-top: -5px;
    margin-bottom: -1px;
    padding-top: 14px;
    padding-right: 19px;
    padding-bottom: 16px;
    padding-left: 19px;
    border: 1px solid #b1b4b6;
    border-bottom: 0;
    background-color: #ffffff;
  }
  .js-enabled .govuk-tabs__list-item--selected .govuk-tabs__tab {
    text-decoration: none;
  }
  .js-enabled .govuk-tabs__tab {
    margin-bottom: 0;
  }
  .js-enabled .govuk-tabs__tab:link, .js-enabled .govuk-tabs__tab:visited {
    color: #0b0c0c;
  }
}
@media print and (min-width: 40.0625em) {
  .js-enabled .govuk-tabs__tab:link, .js-enabled .govuk-tabs__tab:visited {
    color: #000000;
  }
}
@media (min-width: 40.0625em) {
  .js-enabled .govuk-tabs__tab:hover {
    color: rgba(11, 12, 12, 0.99);
  }
}
@media (min-width: 40.0625em) {
  .js-enabled .govuk-tabs__tab:active, .js-enabled .govuk-tabs__tab:focus {
    color: #0b0c0c;
  }
}
@media print and (min-width: 40.0625em) {
  .js-enabled .govuk-tabs__tab:active, .js-enabled .govuk-tabs__tab:focus {
    color: #000000;
  }
}
@media (min-width: 40.0625em) {
  .js-enabled .govuk-tabs__tab:after {
    content: "";
    position: absolute;
    top: 0;
    right: 0;
    bottom: 0;
    left: 0;
  }
}
@media (min-width: 40.0625em) {
  .js-enabled .govuk-tabs__panel {
    margin-bottom: 0;
    padding: 30px 20px;
    border: 1px solid #b1b4b6;
    border-top: 0;
  }
  .js-enabled .govuk-tabs__panel > :last-child {
    margin-bottom: 0;
  }
}
@media (min-width: 40.0625em) {
  .js-enabled .govuk-tabs__panel--hidden {
    display: none;
  }
}

/*# sourceMappingURL=_index.scss.map */
/*# sourceMappingURL=_index.scss.map */
/*# sourceMappingURL=_index.scss.map */
/*# sourceMappingURL=_index.scss.map */
/*# sourceMappingURL=_index.scss.map */
/*# sourceMappingURL=_index.scss.map */
.govuk-radios__item {
  font-family: Arial, sans-serif;
  -webkit-font-smoothing: antialiased;
  -moz-osx-font-smoothing: grayscale;
  font-weight: 400;
  font-size: 16px;
  font-size: 1rem;
  line-height: 1.25;
  display: block;
  position: relative;
  min-height: 40px;
  margin-bottom: 10px;
  padding-left: 40px;
  clear: left;
}
@media print {
  .govuk-radios__item {
    font-family: sans-serif;
  }
}
@media (min-width: 40.0625em) {
  .govuk-radios__item {
    font-size: 19px;
    font-size: 1.1875rem;
    line-height: 1.3157894737;
  }
}
@media print {
  .govuk-radios__item {
    font-size: 14pt;
    line-height: 1.15;
  }
}

.govuk-radios__item:last-child,
.govuk-radios__item:last-of-type {
  margin-bottom: 0;
}

.govuk-radios__input {
  cursor: pointer;
  position: absolute;
  z-index: 1;
  top: -2px;
  left: -2px;
  width: 44px;
  height: 44px;
  margin: 0;
  opacity: 0;
}

.govuk-radios__label {
  display: inline-block;
  margin-bottom: 0;
  padding: 8px 15px 5px;
  cursor: pointer;
  -ms-touch-action: manipulation;
  touch-action: manipulation;
}

.govuk-radios__label:before {
  content: "";
  box-sizing: border-box;
  position: absolute;
  top: 0;
  left: 0;
  width: 40px;
  height: 40px;
  border: 2px solid currentcolor;
  border-radius: 50%;
  background: transparent;
}

.govuk-radios__label:after {
  content: "";
  position: absolute;
  top: 10px;
  left: 10px;
  width: 0;
  height: 0;
  border: 10px solid currentcolor;
  border-radius: 50%;
  opacity: 0;
  background: currentcolor;
}

.govuk-radios__hint {
  display: block;
  padding-right: 15px;
  padding-left: 15px;
}

.govuk-radios__input:focus + .govuk-radios__label:before {
  border-width: 4px;
  outline: 3px solid transparent;
  outline-offset: 1px;
  box-shadow: 0 0 0 4px #ffdd00;
}
@media screen and (forced-colors: active), (-ms-high-contrast: active) {
  .govuk-radios__input:focus + .govuk-radios__label:before {
    outline-color: Highlight;
  }
}

.govuk-radios__input:checked + .govuk-radios__label:after {
  opacity: 1;
}

.govuk-radios__input:disabled,
.govuk-radios__input:disabled + .govuk-radios__label {
  cursor: not-allowed;
}

.govuk-radios__input:disabled + .govuk-radios__label,
.govuk-radios__input:disabled ~ .govuk-hint {
  opacity: 0.5;
}

@media (min-width: 40.0625em) {
  .govuk-radios--inline:after {
    content: "";
    display: block;
    clear: both;
  }
  .govuk-radios--inline .govuk-radios__item {
    margin-right: 20px;
    float: left;
    clear: none;
  }
}

.govuk-radios__divider {
  font-family: Arial, sans-serif;
  -webkit-font-smoothing: antialiased;
  -moz-osx-font-smoothing: grayscale;
  font-weight: 400;
  font-size: 16px;
  font-size: 1rem;
  line-height: 1.25;
  color: #0b0c0c;
  width: 40px;
  margin-bottom: 10px;
  text-align: center;
}
@media print {
  .govuk-radios__divider {
    font-family: sans-serif;
  }
}
@media (min-width: 40.0625em) {
  .govuk-radios__divider {
    font-size: 19px;
    font-size: 1.1875rem;
    line-height: 1.3157894737;
  }
}
@media print {
  .govuk-radios__divider {
    font-size: 14pt;
    line-height: 1.15;
  }
}
@media print {
  .govuk-radios__divider {
    color: #000000;
  }
}

.govuk-radios__conditional {
  margin-bottom: 15px;
  margin-left: 18px;
  padding-left: 33px;
  border-left: 4px solid #b1b4b6;
}
@media (min-width: 40.0625em) {
  .govuk-radios__conditional {
    margin-bottom: 20px;
  }
}
.js-enabled .govuk-radios__conditional--hidden {
  display: none;
}
.govuk-radios__conditional > :last-child {
  margin-bottom: 0;
}

.govuk-radios--small .govuk-radios__item {
  min-height: 0;
  margin-bottom: 0;
  padding-left: 34px;
  float: left;
}
.govuk-radios--small .govuk-radios__item:after {
  content: "";
  display: block;
  clear: both;
}
.govuk-radios--small .govuk-radios__input {
  left: -10px;
}
.govuk-radios--small .govuk-radios__label {
  margin-top: -2px;
  padding: 13px 15px 13px 1px;
  float: left;
}
@media (min-width: 40.0625em) {
  .govuk-radios--small .govuk-radios__label {
    padding: 11px 15px 10px 1px;
  }
}
.govuk-radios--small .govuk-radios__label:before {
  top: 8px;
  width: 24px;
  height: 24px;
}
.govuk-radios--small .govuk-radios__label:after {
  top: 15px;
  left: 7px;
  border-width: 5px;
}
.govuk-radios--small .govuk-radios__hint {
  padding: 0;
  clear: both;
  pointer-events: none;
}
.govuk-radios--small .govuk-radios__conditional {
  margin-left: 10px;
  padding-left: 20px;
  clear: both;
}
.govuk-radios--small .govuk-radios__divider {
  width: 24px;
  margin-bottom: 5px;
}
.govuk-radios--small .govuk-radios__item:hover .govuk-radios__input:not(:disabled) + .govuk-radios__label:before {
  box-shadow: 0 0 0 10px #b1b4b6;
}
.govuk-radios--small .govuk-radios__item:hover .govuk-radios__input:focus + .govuk-radios__label:before {
  box-shadow: 0 0 0 4px #ffdd00, 0 0 0 10px #b1b4b6;
}
@media (hover: none), (pointer: coarse) {
  .govuk-radios--small .govuk-radios__item:hover .govuk-radios__input:not(:disabled) + .govuk-radios__label:before {
    box-shadow: initial;
  }
  .govuk-radios--small .govuk-radios__item:hover .govuk-radios__input:focus + .govuk-radios__label:before {
    box-shadow: 0 0 0 4px #ffdd00;
  }
}

/*# sourceMappingURL=_index.scss.map */
/*# sourceMappingURL=_index.scss.map */
/*# sourceMappingURL=_index.scss.map */
/*# sourceMappingURL=_index.scss.map */
.govuk-select {
  font-family: Arial, sans-serif;
  -webkit-font-smoothing: antialiased;
  -moz-osx-font-smoothing: grayscale;
  font-weight: 400;
  font-size: 16px;
  font-size: 1rem;
  line-height: 1.25;
  box-sizing: border-box;
  min-width: 11.5em;
  max-width: 100%;
  height: 40px;
  height: 2.5rem;
  padding: 5px;
  border: 2px solid #0b0c0c;
  color: #0b0c0c;
  background-color: #ffffff;
}
@media print {
  .govuk-select {
    font-family: sans-serif;
  }
}
@media (min-width: 40.0625em) {
  .govuk-select {
    font-size: 19px;
    font-size: 1.1875rem;
    line-height: 1.25;
  }
}
@media print {
  .govuk-select {
    font-size: 14pt;
    line-height: 1.25;
  }
}
.govuk-select:focus {
  outline: 3px solid #ffdd00;
  outline-offset: 0;
  box-shadow: inset 0 0 0 2px;
}
.govuk-select:disabled {
  opacity: 0.5;
  color: inherit;
  cursor: not-allowed;
}

.govuk-select option:active,
.govuk-select option:checked,
.govuk-select:focus::-ms-value {
  color: #ffffff;
  background-color: #1d70b8;
}

.govuk-select--error {
  border-color: #d4351c;
}
.govuk-select--error:focus {
  border-color: #0b0c0c;
}

/*# sourceMappingURL=_index.scss.map */
.govuk-skip-link {
  position: absolute !important;
  width: 1px !important;
  height: 1px !important;
  margin: 0 !important;
  overflow: hidden !important;
  clip: rect(0 0 0 0) !important;
  -webkit-clip-path: inset(50%) !important;
  clip-path: inset(50%) !important;
  white-space: nowrap !important;
  font-family: Arial, sans-serif;
  -webkit-font-smoothing: antialiased;
  -moz-osx-font-smoothing: grayscale;
  text-decoration: underline;
  font-size: 14px;
  font-size: 0.875rem;
  line-height: 1.1428571429;
  display: block;
  padding: 10px 15px;
}
.govuk-skip-link:active, .govuk-skip-link:focus {
  position: static !important;
  width: auto !important;
  height: auto !important;
  margin: inherit !important;
  overflow: visible !important;
  clip: auto !important;
  -webkit-clip-path: none !important;
  clip-path: none !important;
  white-space: inherit !important;
}
@media print {
  .govuk-skip-link {
    font-family: sans-serif;
  }
}
.govuk-skip-link:link, .govuk-skip-link:visited {
  color: #0b0c0c;
}
@media print {
  .govuk-skip-link:link, .govuk-skip-link:visited {
    color: #000000;
  }
}
.govuk-skip-link:hover {
  color: rgba(11, 12, 12, 0.99);
}
.govuk-skip-link:active, .govuk-skip-link:focus {
  color: #0b0c0c;
}
@media print {
  .govuk-skip-link:active, .govuk-skip-link:focus {
    color: #000000;
  }
}
@media (min-width: 40.0625em) {
  .govuk-skip-link {
    font-size: 16px;
    font-size: 1rem;
    line-height: 1.25;
  }
}
@media print {
  .govuk-skip-link {
    font-size: 14pt;
    line-height: 1.2;
  }
}
@supports (padding: max(calc(0px))) {
  .govuk-skip-link {
    padding-right: max(15px, calc(15px + env(safe-area-inset-right)));
    padding-left: max(15px, calc(15px + env(safe-area-inset-left)));
  }
}
.govuk-skip-link:focus {
  outline: 3px solid #ffdd00;
  outline-offset: 0;
  background-color: #ffdd00;
}

.govuk-skip-link-focused-element:focus {
  outline: none;
}

/*# sourceMappingURL=_index.scss.map */
.govuk-summary-list {
  font-family: Arial, sans-serif;
  -webkit-font-smoothing: antialiased;
  -moz-osx-font-smoothing: grayscale;
  font-weight: 400;
  font-size: 16px;
  font-size: 1rem;
  line-height: 1.25;
  color: #0b0c0c;
  margin: 0;
  margin-bottom: 20px;
}
@media print {
  .govuk-summary-list {
    font-family: sans-serif;
  }
}
@media (min-width: 40.0625em) {
  .govuk-summary-list {
    font-size: 19px;
    font-size: 1.1875rem;
    line-height: 1.3157894737;
  }
}
@media print {
  .govuk-summary-list {
    font-size: 14pt;
    line-height: 1.15;
  }
}
@media print {
  .govuk-summary-list {
    color: #000000;
  }
}
@media (min-width: 40.0625em) {
  .govuk-summary-list {
    display: table;
    width: 100%;
    table-layout: fixed;
    border-collapse: collapse;
  }
}
@media (min-width: 40.0625em) {
  .govuk-summary-list {
    margin-bottom: 30px;
  }
}

.govuk-summary-list__row {
  border-bottom: 1px solid #b1b4b6;
}
@media (max-width: 40.0525em) {
  .govuk-summary-list__row {
    margin-bottom: 15px;
  }
}
@media (min-width: 40.0625em) {
  .govuk-summary-list__row {
    display: table-row;
  }
}

.govuk-summary-list__row:not(.govuk-summary-list__row--no-actions) > :last-child {
  padding-right: 0;
}

@media (min-width: 40.0625em) {
  .govuk-summary-list__row--no-actions:after {
    content: "";
    display: table-cell;
    width: 20%;
  }
}

.govuk-summary-list__key,
.govuk-summary-list__value,
.govuk-summary-list__actions {
  margin: 0;
}
@media (min-width: 40.0625em) {
  .govuk-summary-list__key,
.govuk-summary-list__value,
.govuk-summary-list__actions {
    display: table-cell;
    padding-top: 10px;
    padding-right: 20px;
    padding-bottom: 10px;
  }
}

.govuk-summary-list__actions {
  margin-bottom: 15px;
}
@media (min-width: 40.0625em) {
  .govuk-summary-list__actions {
    width: 20%;
    padding-right: 0;
    text-align: right;
  }
}

.govuk-summary-list__key,
.govuk-summary-list__value {
  word-wrap: break-word;
  overflow-wrap: break-word;
}

.govuk-summary-list__key {
  margin-bottom: 5px;
  font-weight: 700;
}
@media (min-width: 40.0625em) {
  .govuk-summary-list__key {
    width: 30%;
  }
}

@media (max-width: 40.0525em) {
  .govuk-summary-list__value {
    margin-bottom: 15px;
  }
}

.govuk-summary-list__value > p {
  margin-bottom: 10px;
}

.govuk-summary-list__value > :last-child {
  margin-bottom: 0;
}

.govuk-summary-list__actions-list {
  width: 100%;
  margin: 0;
  padding: 0;
}

.govuk-summary-list__actions-list-item {
  display: inline-block;
}

@media (max-width: 40.0525em) {
  .govuk-summary-list__actions-list-item {
    margin-right: 10px;
    padding-right: 10px;
  }
  .govuk-summary-list__actions-list-item:not(:last-child) {
    border-right: 1px solid #b1b4b6;
  }
  .govuk-summary-list__actions-list-item:last-child {
    margin-right: 0;
    padding-right: 0;
    border: 0;
  }
}
@media (min-width: 40.0625em) {
  .govuk-summary-list__actions-list-item {
    margin-left: 10px;
    padding-left: 10px;
  }
  .govuk-summary-list__actions-list-item:not(:first-child) {
    border-left: 1px solid #b1b4b6;
  }
  .govuk-summary-list__actions-list-item:first-child {
    margin-left: 0;
    padding-left: 0;
    border: 0;
  }
}
.govuk-summary-list--no-border .govuk-summary-list__row {
  border: 0;
}
@media (min-width: 40.0625em) {
  .govuk-summary-list--no-border .govuk-summary-list__key,
.govuk-summary-list--no-border .govuk-summary-list__value,
.govuk-summary-list--no-border .govuk-summary-list__actions {
    padding-bottom: 11px;
  }
}

.govuk-summary-list__row--no-border {
  border: 0;
}
@media (min-width: 40.0625em) {
  .govuk-summary-list__row--no-border .govuk-summary-list__key,
.govuk-summary-list__row--no-border .govuk-summary-list__value,
.govuk-summary-list__row--no-border .govuk-summary-list__actions {
    padding-bottom: 11px;
  }
}

.govuk-summary-card {
  margin-bottom: 20px;
  border: 1px solid #b1b4b6;
}
@media (min-width: 40.0625em) {
  .govuk-summary-card {
    margin-bottom: 30px;
  }
}

.govuk-summary-card__title-wrapper {
  padding: 15px;
  border-bottom: 1px solid transparent;
  background-color: #f3f2f1;
}
@media (min-width: 40.0625em) {
  .govuk-summary-card__title-wrapper {
    display: -ms-flexbox;
    display: flex;
    -ms-flex-pack: justify;
    justify-content: space-between;
    -ms-flex-wrap: nowrap;
    flex-wrap: nowrap;
    padding: 15px 20px;
  }
}

.govuk-summary-card__title {
  font-family: Arial, sans-serif;
  -webkit-font-smoothing: antialiased;
  -moz-osx-font-smoothing: grayscale;
  font-weight: 700;
  font-size: 16px;
  font-size: 1rem;
  line-height: 1.25;
  margin: 5px 20px 10px 0;
}
@media print {
  .govuk-summary-card__title {
    font-family: sans-serif;
  }
}
@media (min-width: 40.0625em) {
  .govuk-summary-card__title {
    font-size: 19px;
    font-size: 1.1875rem;
    line-height: 1.3157894737;
  }
}
@media print {
  .govuk-summary-card__title {
    font-size: 14pt;
    line-height: 1.15;
  }
}
@media (min-width: 40.0625em) {
  .govuk-summary-card__title {
    margin-bottom: 5px;
  }
}

.govuk-summary-card__actions {
  font-family: Arial, sans-serif;
  -webkit-font-smoothing: antialiased;
  -moz-osx-font-smoothing: grayscale;
  font-weight: 700;
  font-size: 16px;
  font-size: 1rem;
  line-height: 1.25;
  display: -ms-flexbox;
  display: flex;
  -ms-flex-wrap: wrap;
  flex-wrap: wrap;
  row-gap: 10px;
  margin: 5px 0;
  padding: 0;
  list-style: none;
}
@media print {
  .govuk-summary-card__actions {
    font-family: sans-serif;
  }
}
@media (min-width: 40.0625em) {
  .govuk-summary-card__actions {
    font-size: 19px;
    font-size: 1.1875rem;
    line-height: 1.3157894737;
  }
}
@media print {
  .govuk-summary-card__actions {
    font-size: 14pt;
    line-height: 1.15;
  }
}
@media (min-width: 40.0625em) {
  .govuk-summary-card__actions {
    -ms-flex-pack: right;
    justify-content: right;
    text-align: right;
  }
}

.govuk-summary-card__action {
  display: inline;
  margin: 0 10px 0 0;
  padding-right: 10px;
  border-right: 1px solid #b1b4b6;
}
@media (min-width: 40.0625em) {
  .govuk-summary-card__action {
    margin-right: 0;
  }
}
@media screen and (-ms-high-contrast: active), (-ms-high-contrast: none) {
  .govuk-summary-card__action {
    margin-bottom: 5px;
  }
}

.govuk-summary-card__action:last-child {
  margin: 0;
  padding-right: 0;
  border-right: none;
}
@media (min-width: 40.0625em) {
  .govuk-summary-card__action:last-child {
    padding-left: 10px;
  }
}
@media screen and (-ms-high-contrast: active), (-ms-high-contrast: none) {
  .govuk-summary-card__action:last-child {
    margin-bottom: 0;
  }
}

.govuk-summary-card__content {
  padding: 15px 15px 0;
}
@media (min-width: 40.0625em) {
  .govuk-summary-card__content {
    padding: 15px 20px;
  }
}
.govuk-summary-card__content .govuk-summary-list {
  margin-bottom: 0;
}
.govuk-summary-card__content .govuk-summary-list__row:last-of-type {
  margin-bottom: 0;
  border-bottom: none;
}

/*# sourceMappingURL=_index.scss.map */
.govuk-table {
  font-family: Arial, sans-serif;
  -webkit-font-smoothing: antialiased;
  -moz-osx-font-smoothing: grayscale;
  font-weight: 400;
  font-size: 16px;
  font-size: 1rem;
  line-height: 1.25;
  color: #0b0c0c;
  width: 100%;
  margin-bottom: 20px;
  border-spacing: 0;
  border-collapse: collapse;
}
@media print {
  .govuk-table {
    font-family: sans-serif;
  }
}
@media (min-width: 40.0625em) {
  .govuk-table {
    font-size: 19px;
    font-size: 1.1875rem;
    line-height: 1.3157894737;
  }
}
@media print {
  .govuk-table {
    font-size: 14pt;
    line-height: 1.15;
  }
}
@media print {
  .govuk-table {
    color: #000000;
  }
}
@media (min-width: 40.0625em) {
  .govuk-table {
    margin-bottom: 30px;
  }
}

.govuk-table__header {
  font-weight: 700;
}

.govuk-table__header,
.govuk-table__cell {
  padding: 10px 20px 10px 0;
  border-bottom: 1px solid #b1b4b6;
  text-align: left;
  vertical-align: top;
}

.govuk-table__cell--numeric {
  font-family: Arial, sans-serif;
  -webkit-font-smoothing: antialiased;
  -moz-osx-font-smoothing: grayscale;
  font-feature-settings: "tnum" 1;
  font-weight: 400;
}
@media print {
  .govuk-table__cell--numeric {
    font-family: sans-serif;
  }
}
@supports (font-variant-numeric: tabular-nums) {
  .govuk-table__cell--numeric {
    font-feature-settings: normal;
    font-variant-numeric: tabular-nums;
  }
}

.govuk-table__header--numeric,
.govuk-table__cell--numeric {
  text-align: right;
}

.govuk-table__header:last-child,
.govuk-table__cell:last-child {
  padding-right: 0;
}

.govuk-table__caption {
  font-weight: 700;
  display: table-caption;
  text-align: left;
}

.govuk-table__caption--xl {
  font-family: Arial, sans-serif;
  -webkit-font-smoothing: antialiased;
  -moz-osx-font-smoothing: grayscale;
  font-weight: 700;
  font-size: 32px;
  font-size: 2rem;
  line-height: 1.09375;
  margin-bottom: 15px;
}
@media print {
  .govuk-table__caption--xl {
    font-family: sans-serif;
  }
}
@media (min-width: 40.0625em) {
  .govuk-table__caption--xl {
    font-size: 48px;
    font-size: 3rem;
    line-height: 1.0416666667;
  }
}
@media print {
  .govuk-table__caption--xl {
    font-size: 32pt;
    line-height: 1.15;
  }
}

.govuk-table__caption--l {
  font-family: Arial, sans-serif;
  -webkit-font-smoothing: antialiased;
  -moz-osx-font-smoothing: grayscale;
  font-weight: 700;
  font-size: 24px;
  font-size: 1.5rem;
  line-height: 1.0416666667;
  margin-bottom: 15px;
}
@media print {
  .govuk-table__caption--l {
    font-family: sans-serif;
  }
}
@media (min-width: 40.0625em) {
  .govuk-table__caption--l {
    font-size: 36px;
    font-size: 2.25rem;
    line-height: 1.1111111111;
  }
}
@media print {
  .govuk-table__caption--l {
    font-size: 24pt;
    line-height: 1.05;
  }
}

.govuk-table__caption--m {
  font-family: Arial, sans-serif;
  -webkit-font-smoothing: antialiased;
  -moz-osx-font-smoothing: grayscale;
  font-weight: 700;
  font-size: 18px;
  font-size: 1.125rem;
  line-height: 1.1111111111;
  margin-bottom: 15px;
}
@media print {
  .govuk-table__caption--m {
    font-family: sans-serif;
  }
}
@media (min-width: 40.0625em) {
  .govuk-table__caption--m {
    font-size: 24px;
    font-size: 1.5rem;
    line-height: 1.25;
  }
}
@media print {
  .govuk-table__caption--m {
    font-size: 18pt;
    line-height: 1.15;
  }
}

.govuk-table__caption--s {
  font-family: Arial, sans-serif;
  -webkit-font-smoothing: antialiased;
  -moz-osx-font-smoothing: grayscale;
  font-weight: 700;
  font-size: 16px;
  font-size: 1rem;
  line-height: 1.25;
}
@media print {
  .govuk-table__caption--s {
    font-family: sans-serif;
  }
}
@media (min-width: 40.0625em) {
  .govuk-table__caption--s {
    font-size: 19px;
    font-size: 1.1875rem;
    line-height: 1.3157894737;
  }
}
@media print {
  .govuk-table__caption--s {
    font-size: 14pt;
    line-height: 1.15;
  }
}

/*# sourceMappingURL=_index.scss.map */
/*# sourceMappingURL=_index.scss.map */
/*# sourceMappingURL=_index.scss.map */
/*# sourceMappingURL=_index.scss.map */
/*# sourceMappingURL=_index.scss.map */
.govuk-warning-text {
  position: relative;
  margin-bottom: 20px;
  padding: 10px 0;
}
@media (min-width: 40.0625em) {
  .govuk-warning-text {
    margin-bottom: 30px;
  }
}

.govuk-warning-text__assistive {
  position: absolute !important;
  width: 1px !important;
  height: 1px !important;
  margin: 0 !important;
  padding: 0 !important;
  overflow: hidden !important;
  clip: rect(0 0 0 0) !important;
  -webkit-clip-path: inset(50%) !important;
  clip-path: inset(50%) !important;
  border: 0 !important;
  white-space: nowrap !important;
}
.govuk-warning-text__assistive:before {
  content: " ";
}
.govuk-warning-text__assistive:after {
  content: " ";
}

.govuk-warning-text__icon {
  font-family: Arial, sans-serif;
  -webkit-font-smoothing: antialiased;
  -moz-osx-font-smoothing: grayscale;
  font-weight: 700;
  box-sizing: border-box;
  display: inline-block;
  position: absolute;
  left: 0;
  min-width: 35px;
  min-height: 35px;
  margin-top: -7px;
  border: 3px solid #0b0c0c;
  border-radius: 50%;
  color: #ffffff;
  background: #0b0c0c;
  font-size: 30px;
  line-height: 29px;
  text-align: center;
  -webkit-user-select: none;
  -ms-user-select: none;
  user-select: none;
  forced-color-adjust: none;
}
@media print {
  .govuk-warning-text__icon {
    font-family: sans-serif;
  }
}
@media (min-width: 40.0625em) {
  .govuk-warning-text__icon {
    margin-top: -5px;
  }
}
@media screen and (forced-colors: active) {
  .govuk-warning-text__icon {
    border-color: windowText;
    color: windowText;
    background: transparent;
  }
}

.govuk-warning-text__text {
  font-family: Arial, sans-serif;
  -webkit-font-smoothing: antialiased;
  -moz-osx-font-smoothing: grayscale;
  font-weight: 700;
  font-size: 16px;
  font-size: 1rem;
  line-height: 1.25;
  color: #0b0c0c;
  display: block;
  padding-left: 45px;
}
@media print {
  .govuk-warning-text__text {
    font-family: sans-serif;
  }
}
@media (min-width: 40.0625em) {
  .govuk-warning-text__text {
    font-size: 19px;
    font-size: 1.1875rem;
    line-height: 1.3157894737;
  }
}
@media print {
  .govuk-warning-text__text {
    font-size: 14pt;
    line-height: 1.15;
  }
}
@media print {
  .govuk-warning-text__text {
    color: #000000;
  }
}

/*# sourceMappingURL=_index.scss.map */
/*# sourceMappingURL=_all.scss.map */
.govuk-clearfix:after {
  content: "";
  display: block;
  clear: both;
}

/*# sourceMappingURL=_clearfix.scss.map */
.govuk-visually-hidden {
  position: absolute !important;
  width: 1px !important;
  height: 1px !important;
  margin: 0 !important;
  padding: 0 !important;
  overflow: hidden !important;
  clip: rect(0 0 0 0) !important;
  -webkit-clip-path: inset(50%) !important;
  clip-path: inset(50%) !important;
  border: 0 !important;
  white-space: nowrap !important;
}
.govuk-visually-hidden:before {
  content: " ";
}
.govuk-visually-hidden:after {
  content: " ";
}

.govuk-visually-hidden-focusable {
  position: absolute !important;
  width: 1px !important;
  height: 1px !important;
  margin: 0 !important;
  overflow: hidden !important;
  clip: rect(0 0 0 0) !important;
  -webkit-clip-path: inset(50%) !important;
  clip-path: inset(50%) !important;
  white-space: nowrap !important;
}
.govuk-visually-hidden-focusable:active, .govuk-visually-hidden-focusable:focus {
  position: static !important;
  width: auto !important;
  height: auto !important;
  margin: inherit !important;
  overflow: visible !important;
  clip: auto !important;
  -webkit-clip-path: none !important;
  clip-path: none !important;
  white-space: inherit !important;
}

/*# sourceMappingURL=_visually-hidden.scss.map */
/*# sourceMappingURL=_all.scss.map */
.govuk-\!-display-inline {
  display: inline !important;
}

.govuk-\!-display-inline-block {
  display: inline-block !important;
}

.govuk-\!-display-block {
  display: block !important;
}

.govuk-\!-display-none {
  display: none !important;
}

@media print {
  .govuk-\!-display-none-print {
    display: none !important;
  }
}
/*# sourceMappingURL=_display.scss.map */
.govuk-\!-margin-0 {
  margin: 0 !important;
}

.govuk-\!-margin-top-0 {
  margin-top: 0 !important;
}

.govuk-\!-margin-right-0 {
  margin-right: 0 !important;
}

.govuk-\!-margin-bottom-0 {
  margin-bottom: 0 !important;
}

.govuk-\!-margin-left-0 {
  margin-left: 0 !important;
}

.govuk-\!-margin-1 {
  margin: 5px !important;
}

.govuk-\!-margin-top-1 {
  margin-top: 5px !important;
}

.govuk-\!-margin-right-1 {
  margin-right: 5px !important;
}

.govuk-\!-margin-bottom-1 {
  margin-bottom: 5px !important;
}

.govuk-\!-margin-left-1 {
  margin-left: 5px !important;
}

.govuk-\!-margin-2 {
  margin: 10px !important;
}

.govuk-\!-margin-top-2 {
  margin-top: 10px !important;
}

.govuk-\!-margin-right-2 {
  margin-right: 10px !important;
}

.govuk-\!-margin-bottom-2 {
  margin-bottom: 10px !important;
}

.govuk-\!-margin-left-2 {
  margin-left: 10px !important;
}

.govuk-\!-margin-3 {
  margin: 15px !important;
}

.govuk-\!-margin-top-3 {
  margin-top: 15px !important;
}

.govuk-\!-margin-right-3 {
  margin-right: 15px !important;
}

.govuk-\!-margin-bottom-3 {
  margin-bottom: 15px !important;
}

.govuk-\!-margin-left-3 {
  margin-left: 15px !important;
}

.govuk-\!-margin-4 {
  margin: 15px !important;
}
@media (min-width: 40.0625em) {
  .govuk-\!-margin-4 {
    margin: 20px !important;
  }
}

.govuk-\!-margin-top-4 {
  margin-top: 15px !important;
}
@media (min-width: 40.0625em) {
  .govuk-\!-margin-top-4 {
    margin-top: 20px !important;
  }
}

.govuk-\!-margin-right-4 {
  margin-right: 15px !important;
}
@media (min-width: 40.0625em) {
  .govuk-\!-margin-right-4 {
    margin-right: 20px !important;
  }
}

.govuk-\!-margin-bottom-4 {
  margin-bottom: 15px !important;
}
@media (min-width: 40.0625em) {
  .govuk-\!-margin-bottom-4 {
    margin-bottom: 20px !important;
  }
}

.govuk-\!-margin-left-4 {
  margin-left: 15px !important;
}
@media (min-width: 40.0625em) {
  .govuk-\!-margin-left-4 {
    margin-left: 20px !important;
  }
}

.govuk-\!-margin-5 {
  margin: 15px !important;
}
@media (min-width: 40.0625em) {
  .govuk-\!-margin-5 {
    margin: 25px !important;
  }
}

.govuk-\!-margin-top-5 {
  margin-top: 15px !important;
}
@media (min-width: 40.0625em) {
  .govuk-\!-margin-top-5 {
    margin-top: 25px !important;
  }
}

.govuk-\!-margin-right-5 {
  margin-right: 15px !important;
}
@media (min-width: 40.0625em) {
  .govuk-\!-margin-right-5 {
    margin-right: 25px !important;
  }
}

.govuk-\!-margin-bottom-5 {
  margin-bottom: 15px !important;
}
@media (min-width: 40.0625em) {
  .govuk-\!-margin-bottom-5 {
    margin-bottom: 25px !important;
  }
}

.govuk-\!-margin-left-5 {
  margin-left: 15px !important;
}
@media (min-width: 40.0625em) {
  .govuk-\!-margin-left-5 {
    margin-left: 25px !important;
  }
}

.govuk-\!-margin-6 {
  margin: 20px !important;
}
@media (min-width: 40.0625em) {
  .govuk-\!-margin-6 {
    margin: 30px !important;
  }
}

.govuk-\!-margin-top-6 {
  margin-top: 20px !important;
}
@media (min-width: 40.0625em) {
  .govuk-\!-margin-top-6 {
    margin-top: 30px !important;
  }
}

.govuk-\!-margin-right-6 {
  margin-right: 20px !important;
}
@media (min-width: 40.0625em) {
  .govuk-\!-margin-right-6 {
    margin-right: 30px !important;
  }
}

.govuk-\!-margin-bottom-6 {
  margin-bottom: 20px !important;
}
@media (min-width: 40.0625em) {
  .govuk-\!-margin-bottom-6 {
    margin-bottom: 30px !important;
  }
}

.govuk-\!-margin-left-6 {
  margin-left: 20px !important;
}
@media (min-width: 40.0625em) {
  .govuk-\!-margin-left-6 {
    margin-left: 30px !important;
  }
}

.govuk-\!-margin-7 {
  margin: 25px !important;
}
@media (min-width: 40.0625em) {
  .govuk-\!-margin-7 {
    margin: 40px !important;
  }
}

.govuk-\!-margin-top-7 {
  margin-top: 25px !important;
}
@media (min-width: 40.0625em) {
  .govuk-\!-margin-top-7 {
    margin-top: 40px !important;
  }
}

.govuk-\!-margin-right-7 {
  margin-right: 25px !important;
}
@media (min-width: 40.0625em) {
  .govuk-\!-margin-right-7 {
    margin-right: 40px !important;
  }
}

.govuk-\!-margin-bottom-7 {
  margin-bottom: 25px !important;
}
@media (min-width: 40.0625em) {
  .govuk-\!-margin-bottom-7 {
    margin-bottom: 40px !important;
  }
}

.govuk-\!-margin-left-7 {
  margin-left: 25px !important;
}
@media (min-width: 40.0625em) {
  .govuk-\!-margin-left-7 {
    margin-left: 40px !important;
  }
}

.govuk-\!-margin-8 {
  margin: 30px !important;
}
@media (min-width: 40.0625em) {
  .govuk-\!-margin-8 {
    margin: 50px !important;
  }
}

.govuk-\!-margin-top-8 {
  margin-top: 30px !important;
}
@media (min-width: 40.0625em) {
  .govuk-\!-margin-top-8 {
    margin-top: 50px !important;
  }
}

.govuk-\!-margin-right-8 {
  margin-right: 30px !important;
}
@media (min-width: 40.0625em) {
  .govuk-\!-margin-right-8 {
    margin-right: 50px !important;
  }
}

.govuk-\!-margin-bottom-8 {
  margin-bottom: 30px !important;
}
@media (min-width: 40.0625em) {
  .govuk-\!-margin-bottom-8 {
    margin-bottom: 50px !important;
  }
}

.govuk-\!-margin-left-8 {
  margin-left: 30px !important;
}
@media (min-width: 40.0625em) {
  .govuk-\!-margin-left-8 {
    margin-left: 50px !important;
  }
}

.govuk-\!-margin-9 {
  margin: 40px !important;
}
@media (min-width: 40.0625em) {
  .govuk-\!-margin-9 {
    margin: 60px !important;
  }
}

.govuk-\!-margin-top-9 {
  margin-top: 40px !important;
}
@media (min-width: 40.0625em) {
  .govuk-\!-margin-top-9 {
    margin-top: 60px !important;
  }
}

.govuk-\!-margin-right-9 {
  margin-right: 40px !important;
}
@media (min-width: 40.0625em) {
  .govuk-\!-margin-right-9 {
    margin-right: 60px !important;
  }
}

.govuk-\!-margin-bottom-9 {
  margin-bottom: 40px !important;
}
@media (min-width: 40.0625em) {
  .govuk-\!-margin-bottom-9 {
    margin-bottom: 60px !important;
  }
}

.govuk-\!-margin-left-9 {
  margin-left: 40px !important;
}
@media (min-width: 40.0625em) {
  .govuk-\!-margin-left-9 {
    margin-left: 60px !important;
  }
}

.govuk-\!-padding-0 {
  padding: 0 !important;
}

.govuk-\!-padding-top-0 {
  padding-top: 0 !important;
}

.govuk-\!-padding-right-0 {
  padding-right: 0 !important;
}

.govuk-\!-padding-bottom-0 {
  padding-bottom: 0 !important;
}

.govuk-\!-padding-left-0 {
  padding-left: 0 !important;
}

.govuk-\!-padding-1 {
  padding: 5px !important;
}

.govuk-\!-padding-top-1 {
  padding-top: 5px !important;
}

.govuk-\!-padding-right-1 {
  padding-right: 5px !important;
}

.govuk-\!-padding-bottom-1 {
  padding-bottom: 5px !important;
}

.govuk-\!-padding-left-1 {
  padding-left: 5px !important;
}

.govuk-\!-padding-2 {
  padding: 10px !important;
}

.govuk-\!-padding-top-2 {
  padding-top: 10px !important;
}

.govuk-\!-padding-right-2 {
  padding-right: 10px !important;
}

.govuk-\!-padding-bottom-2 {
  padding-bottom: 10px !important;
}

.govuk-\!-padding-left-2 {
  padding-left: 10px !important;
}

.govuk-\!-padding-3 {
  padding: 15px !important;
}

.govuk-\!-padding-top-3 {
  padding-top: 15px !important;
}

.govuk-\!-padding-right-3 {
  padding-right: 15px !important;
}

.govuk-\!-padding-bottom-3 {
  padding-bottom: 15px !important;
}

.govuk-\!-padding-left-3 {
  padding-left: 15px !important;
}

.govuk-\!-padding-4 {
  padding: 15px !important;
}
@media (min-width: 40.0625em) {
  .govuk-\!-padding-4 {
    padding: 20px !important;
  }
}

.govuk-\!-padding-top-4 {
  padding-top: 15px !important;
}
@media (min-width: 40.0625em) {
  .govuk-\!-padding-top-4 {
    padding-top: 20px !important;
  }
}

.govuk-\!-padding-right-4 {
  padding-right: 15px !important;
}
@media (min-width: 40.0625em) {
  .govuk-\!-padding-right-4 {
    padding-right: 20px !important;
  }
}

.govuk-\!-padding-bottom-4 {
  padding-bottom: 15px !important;
}
@media (min-width: 40.0625em) {
  .govuk-\!-padding-bottom-4 {
    padding-bottom: 20px !important;
  }
}

.govuk-\!-padding-left-4 {
  padding-left: 15px !important;
}
@media (min-width: 40.0625em) {
  .govuk-\!-padding-left-4 {
    padding-left: 20px !important;
  }
}

.govuk-\!-padding-5 {
  padding: 15px !important;
}
@media (min-width: 40.0625em) {
  .govuk-\!-padding-5 {
    padding: 25px !important;
  }
}

.govuk-\!-padding-top-5 {
  padding-top: 15px !important;
}
@media (min-width: 40.0625em) {
  .govuk-\!-padding-top-5 {
    padding-top: 25px !important;
  }
}

.govuk-\!-padding-right-5 {
  padding-right: 15px !important;
}
@media (min-width: 40.0625em) {
  .govuk-\!-padding-right-5 {
    padding-right: 25px !important;
  }
}

.govuk-\!-padding-bottom-5 {
  padding-bottom: 15px !important;
}
@media (min-width: 40.0625em) {
  .govuk-\!-padding-bottom-5 {
    padding-bottom: 25px !important;
  }
}

.govuk-\!-padding-left-5 {
  padding-left: 15px !important;
}
@media (min-width: 40.0625em) {
  .govuk-\!-padding-left-5 {
    padding-left: 25px !important;
  }
}

.govuk-\!-padding-6 {
  padding: 20px !important;
}
@media (min-width: 40.0625em) {
  .govuk-\!-padding-6 {
    padding: 30px !important;
  }
}

.govuk-\!-padding-top-6 {
  padding-top: 20px !important;
}
@media (min-width: 40.0625em) {
  .govuk-\!-padding-top-6 {
    padding-top: 30px !important;
  }
}

.govuk-\!-padding-right-6 {
  padding-right: 20px !important;
}
@media (min-width: 40.0625em) {
  .govuk-\!-padding-right-6 {
    padding-right: 30px !important;
  }
}

.govuk-\!-padding-bottom-6 {
  padding-bottom: 20px !important;
}
@media (min-width: 40.0625em) {
  .govuk-\!-padding-bottom-6 {
    padding-bottom: 30px !important;
  }
}

.govuk-\!-padding-left-6 {
  padding-left: 20px !important;
}
@media (min-width: 40.0625em) {
  .govuk-\!-padding-left-6 {
    padding-left: 30px !important;
  }
}

.govuk-\!-padding-7 {
  padding: 25px !important;
}
@media (min-width: 40.0625em) {
  .govuk-\!-padding-7 {
    padding: 40px !important;
  }
}

.govuk-\!-padding-top-7 {
  padding-top: 25px !important;
}
@media (min-width: 40.0625em) {
  .govuk-\!-padding-top-7 {
    padding-top: 40px !important;
  }
}

.govuk-\!-padding-right-7 {
  padding-right: 25px !important;
}
@media (min-width: 40.0625em) {
  .govuk-\!-padding-right-7 {
    padding-right: 40px !important;
  }
}

.govuk-\!-padding-bottom-7 {
  padding-bottom: 25px !important;
}
@media (min-width: 40.0625em) {
  .govuk-\!-padding-bottom-7 {
    padding-bottom: 40px !important;
  }
}

.govuk-\!-padding-left-7 {
  padding-left: 25px !important;
}
@media (min-width: 40.0625em) {
  .govuk-\!-padding-left-7 {
    padding-left: 40px !important;
  }
}

.govuk-\!-padding-8 {
  padding: 30px !important;
}
@media (min-width: 40.0625em) {
  .govuk-\!-padding-8 {
    padding: 50px !important;
  }
}

.govuk-\!-padding-top-8 {
  padding-top: 30px !important;
}
@media (min-width: 40.0625em) {
  .govuk-\!-padding-top-8 {
    padding-top: 50px !important;
  }
}

.govuk-\!-padding-right-8 {
  padding-right: 30px !important;
}
@media (min-width: 40.0625em) {
  .govuk-\!-padding-right-8 {
    padding-right: 50px !important;
  }
}

.govuk-\!-padding-bottom-8 {
  padding-bottom: 30px !important;
}
@media (min-width: 40.0625em) {
  .govuk-\!-padding-bottom-8 {
    padding-bottom: 50px !important;
  }
}

.govuk-\!-padding-left-8 {
  padding-left: 30px !important;
}
@media (min-width: 40.0625em) {
  .govuk-\!-padding-left-8 {
    padding-left: 50px !important;
  }
}

.govuk-\!-padding-9 {
  padding: 40px !important;
}
@media (min-width: 40.0625em) {
  .govuk-\!-padding-9 {
    padding: 60px !important;
  }
}

.govuk-\!-padding-top-9 {
  padding-top: 40px !important;
}
@media (min-width: 40.0625em) {
  .govuk-\!-padding-top-9 {
    padding-top: 60px !important;
  }
}

.govuk-\!-padding-right-9 {
  padding-right: 40px !important;
}
@media (min-width: 40.0625em) {
  .govuk-\!-padding-right-9 {
    padding-right: 60px !important;
  }
}

.govuk-\!-padding-bottom-9 {
  padding-bottom: 40px !important;
}
@media (min-width: 40.0625em) {
  .govuk-\!-padding-bottom-9 {
    padding-bottom: 60px !important;
  }
}

.govuk-\!-padding-left-9 {
  padding-left: 40px !important;
}
@media (min-width: 40.0625em) {
  .govuk-\!-padding-left-9 {
    padding-left: 60px !important;
  }
}

.govuk-\!-margin-static-0,
.govuk-\!-static-margin-0 {
  margin: 0 !important;
}

.govuk-\!-margin-top-static-0,
.govuk-\!-static-margin-top-0 {
  margin-top: 0 !important;
}

.govuk-\!-margin-right-static-0,
.govuk-\!-static-margin-right-0 {
  margin-right: 0 !important;
}

.govuk-\!-margin-bottom-static-0,
.govuk-\!-static-margin-bottom-0 {
  margin-bottom: 0 !important;
}

.govuk-\!-margin-left-static-0,
.govuk-\!-static-margin-left-0 {
  margin-left: 0 !important;
}

.govuk-\!-margin-static-1,
.govuk-\!-static-margin-1 {
  margin: 5px !important;
}

.govuk-\!-margin-top-static-1,
.govuk-\!-static-margin-top-1 {
  margin-top: 5px !important;
}

.govuk-\!-margin-right-static-1,
.govuk-\!-static-margin-right-1 {
  margin-right: 5px !important;
}

.govuk-\!-margin-bottom-static-1,
.govuk-\!-static-margin-bottom-1 {
  margin-bottom: 5px !important;
}

.govuk-\!-margin-left-static-1,
.govuk-\!-static-margin-left-1 {
  margin-left: 5px !important;
}

.govuk-\!-margin-static-2,
.govuk-\!-static-margin-2 {
  margin: 10px !important;
}

.govuk-\!-margin-top-static-2,
.govuk-\!-static-margin-top-2 {
  margin-top: 10px !important;
}

.govuk-\!-margin-right-static-2,
.govuk-\!-static-margin-right-2 {
  margin-right: 10px !important;
}

.govuk-\!-margin-bottom-static-2,
.govuk-\!-static-margin-bottom-2 {
  margin-bottom: 10px !important;
}

.govuk-\!-margin-left-static-2,
.govuk-\!-static-margin-left-2 {
  margin-left: 10px !important;
}

.govuk-\!-margin-static-3,
.govuk-\!-static-margin-3 {
  margin: 15px !important;
}

.govuk-\!-margin-top-static-3,
.govuk-\!-static-margin-top-3 {
  margin-top: 15px !important;
}

.govuk-\!-margin-right-static-3,
.govuk-\!-static-margin-right-3 {
  margin-right: 15px !important;
}

.govuk-\!-margin-bottom-static-3,
.govuk-\!-static-margin-bottom-3 {
  margin-bottom: 15px !important;
}

.govuk-\!-margin-left-static-3,
.govuk-\!-static-margin-left-3 {
  margin-left: 15px !important;
}

.govuk-\!-margin-static-4,
.govuk-\!-static-margin-4 {
  margin: 20px !important;
}

.govuk-\!-margin-top-static-4,
.govuk-\!-static-margin-top-4 {
  margin-top: 20px !important;
}

.govuk-\!-margin-right-static-4,
.govuk-\!-static-margin-right-4 {
  margin-right: 20px !important;
}

.govuk-\!-margin-bottom-static-4,
.govuk-\!-static-margin-bottom-4 {
  margin-bottom: 20px !important;
}

.govuk-\!-margin-left-static-4,
.govuk-\!-static-margin-left-4 {
  margin-left: 20px !important;
}

.govuk-\!-margin-static-5,
.govuk-\!-static-margin-5 {
  margin: 25px !important;
}

.govuk-\!-margin-top-static-5,
.govuk-\!-static-margin-top-5 {
  margin-top: 25px !important;
}

.govuk-\!-margin-right-static-5,
.govuk-\!-static-margin-right-5 {
  margin-right: 25px !important;
}

.govuk-\!-margin-bottom-static-5,
.govuk-\!-static-margin-bottom-5 {
  margin-bottom: 25px !important;
}

.govuk-\!-margin-left-static-5,
.govuk-\!-static-margin-left-5 {
  margin-left: 25px !important;
}

.govuk-\!-margin-static-6,
.govuk-\!-static-margin-6 {
  margin: 30px !important;
}

.govuk-\!-margin-top-static-6,
.govuk-\!-static-margin-top-6 {
  margin-top: 30px !important;
}

.govuk-\!-margin-right-static-6,
.govuk-\!-static-margin-right-6 {
  margin-right: 30px !important;
}

.govuk-\!-margin-bottom-static-6,
.govuk-\!-static-margin-bottom-6 {
  margin-bottom: 30px !important;
}

.govuk-\!-margin-left-static-6,
.govuk-\!-static-margin-left-6 {
  margin-left: 30px !important;
}

.govuk-\!-margin-static-7,
.govuk-\!-static-margin-7 {
  margin: 40px !important;
}

.govuk-\!-margin-top-static-7,
.govuk-\!-static-margin-top-7 {
  margin-top: 40px !important;
}

.govuk-\!-margin-right-static-7,
.govuk-\!-static-margin-right-7 {
  margin-right: 40px !important;
}

.govuk-\!-margin-bottom-static-7,
.govuk-\!-static-margin-bottom-7 {
  margin-bottom: 40px !important;
}

.govuk-\!-margin-left-static-7,
.govuk-\!-static-margin-left-7 {
  margin-left: 40px !important;
}

.govuk-\!-margin-static-8,
.govuk-\!-static-margin-8 {
  margin: 50px !important;
}

.govuk-\!-margin-top-static-8,
.govuk-\!-static-margin-top-8 {
  margin-top: 50px !important;
}

.govuk-\!-margin-right-static-8,
.govuk-\!-static-margin-right-8 {
  margin-right: 50px !important;
}

.govuk-\!-margin-bottom-static-8,
.govuk-\!-static-margin-bottom-8 {
  margin-bottom: 50px !important;
}

.govuk-\!-margin-left-static-8,
.govuk-\!-static-margin-left-8 {
  margin-left: 50px !important;
}

.govuk-\!-margin-static-9,
.govuk-\!-static-margin-9 {
  margin: 60px !important;
}

.govuk-\!-margin-top-static-9,
.govuk-\!-static-margin-top-9 {
  margin-top: 60px !important;
}

.govuk-\!-margin-right-static-9,
.govuk-\!-static-margin-right-9 {
  margin-right: 60px !important;
}

.govuk-\!-margin-bottom-static-9,
.govuk-\!-static-margin-bottom-9 {
  margin-bottom: 60px !important;
}

.govuk-\!-margin-left-static-9,
.govuk-\!-static-margin-left-9 {
  margin-left: 60px !important;
}

.govuk-\!-padding-static-0,
.govuk-\!-static-padding-0 {
  padding: 0 !important;
}

.govuk-\!-padding-top-static-0,
.govuk-\!-static-padding-top-0 {
  padding-top: 0 !important;
}

.govuk-\!-padding-right-static-0,
.govuk-\!-static-padding-right-0 {
  padding-right: 0 !important;
}

.govuk-\!-padding-bottom-static-0,
.govuk-\!-static-padding-bottom-0 {
  padding-bottom: 0 !important;
}

.govuk-\!-padding-left-static-0,
.govuk-\!-static-padding-left-0 {
  padding-left: 0 !important;
}

.govuk-\!-padding-static-1,
.govuk-\!-static-padding-1 {
  padding: 5px !important;
}

.govuk-\!-padding-top-static-1,
.govuk-\!-static-padding-top-1 {
  padding-top: 5px !important;
}

.govuk-\!-padding-right-static-1,
.govuk-\!-static-padding-right-1 {
  padding-right: 5px !important;
}

.govuk-\!-padding-bottom-static-1,
.govuk-\!-static-padding-bottom-1 {
  padding-bottom: 5px !important;
}

.govuk-\!-padding-left-static-1,
.govuk-\!-static-padding-left-1 {
  padding-left: 5px !important;
}

.govuk-\!-padding-static-2,
.govuk-\!-static-padding-2 {
  padding: 10px !important;
}

.govuk-\!-padding-top-static-2,
.govuk-\!-static-padding-top-2 {
  padding-top: 10px !important;
}

.govuk-\!-padding-right-static-2,
.govuk-\!-static-padding-right-2 {
  padding-right: 10px !important;
}

.govuk-\!-padding-bottom-static-2,
.govuk-\!-static-padding-bottom-2 {
  padding-bottom: 10px !important;
}

.govuk-\!-padding-left-static-2,
.govuk-\!-static-padding-left-2 {
  padding-left: 10px !important;
}

.govuk-\!-padding-static-3,
.govuk-\!-static-padding-3 {
  padding: 15px !important;
}

.govuk-\!-padding-top-static-3,
.govuk-\!-static-padding-top-3 {
  padding-top: 15px !important;
}

.govuk-\!-padding-right-static-3,
.govuk-\!-static-padding-right-3 {
  padding-right: 15px !important;
}

.govuk-\!-padding-bottom-static-3,
.govuk-\!-static-padding-bottom-3 {
  padding-bottom: 15px !important;
}

.govuk-\!-padding-left-static-3,
.govuk-\!-static-padding-left-3 {
  padding-left: 15px !important;
}

.govuk-\!-padding-static-4,
.govuk-\!-static-padding-4 {
  padding: 20px !important;
}

.govuk-\!-padding-top-static-4,
.govuk-\!-static-padding-top-4 {
  padding-top: 20px !important;
}

.govuk-\!-padding-right-static-4,
.govuk-\!-static-padding-right-4 {
  padding-right: 20px !important;
}

.govuk-\!-padding-bottom-static-4,
.govuk-\!-static-padding-bottom-4 {
  padding-bottom: 20px !important;
}

.govuk-\!-padding-left-static-4,
.govuk-\!-static-padding-left-4 {
  padding-left: 20px !important;
}

.govuk-\!-padding-static-5,
.govuk-\!-static-padding-5 {
  padding: 25px !important;
}

.govuk-\!-padding-top-static-5,
.govuk-\!-static-padding-top-5 {
  padding-top: 25px !important;
}

.govuk-\!-padding-right-static-5,
.govuk-\!-static-padding-right-5 {
  padding-right: 25px !important;
}

.govuk-\!-padding-bottom-static-5,
.govuk-\!-static-padding-bottom-5 {
  padding-bottom: 25px !important;
}

.govuk-\!-padding-left-static-5,
.govuk-\!-static-padding-left-5 {
  padding-left: 25px !important;
}

.govuk-\!-padding-static-6,
.govuk-\!-static-padding-6 {
  padding: 30px !important;
}

.govuk-\!-padding-top-static-6,
.govuk-\!-static-padding-top-6 {
  padding-top: 30px !important;
}

.govuk-\!-padding-right-static-6,
.govuk-\!-static-padding-right-6 {
  padding-right: 30px !important;
}

.govuk-\!-padding-bottom-static-6,
.govuk-\!-static-padding-bottom-6 {
  padding-bottom: 30px !important;
}

.govuk-\!-padding-left-static-6,
.govuk-\!-static-padding-left-6 {
  padding-left: 30px !important;
}

.govuk-\!-padding-static-7,
.govuk-\!-static-padding-7 {
  padding: 40px !important;
}

.govuk-\!-padding-top-static-7,
.govuk-\!-static-padding-top-7 {
  padding-top: 40px !important;
}

.govuk-\!-padding-right-static-7,
.govuk-\!-static-padding-right-7 {
  padding-right: 40px !important;
}

.govuk-\!-padding-bottom-static-7,
.govuk-\!-static-padding-bottom-7 {
  padding-bottom: 40px !important;
}

.govuk-\!-padding-left-static-7,
.govuk-\!-static-padding-left-7 {
  padding-left: 40px !important;
}

.govuk-\!-padding-static-8,
.govuk-\!-static-padding-8 {
  padding: 50px !important;
}

.govuk-\!-padding-top-static-8,
.govuk-\!-static-padding-top-8 {
  padding-top: 50px !important;
}

.govuk-\!-padding-right-static-8,
.govuk-\!-static-padding-right-8 {
  padding-right: 50px !important;
}

.govuk-\!-padding-bottom-static-8,
.govuk-\!-static-padding-bottom-8 {
  padding-bottom: 50px !important;
}

.govuk-\!-padding-left-static-8,
.govuk-\!-static-padding-left-8 {
  padding-left: 50px !important;
}

.govuk-\!-padding-static-9,
.govuk-\!-static-padding-9 {
  padding: 60px !important;
}

.govuk-\!-padding-top-static-9,
.govuk-\!-static-padding-top-9 {
  padding-top: 60px !important;
}

.govuk-\!-padding-right-static-9,
.govuk-\!-static-padding-right-9 {
  padding-right: 60px !important;
}

.govuk-\!-padding-bottom-static-9,
.govuk-\!-static-padding-bottom-9 {
  padding-bottom: 60px !important;
}

.govuk-\!-padding-left-static-9,
.govuk-\!-static-padding-left-9 {
  padding-left: 60px !important;
}

/*# sourceMappingURL=_spacing.scss.map */
.govuk-\!-text-align-left {
  text-align: left !important;
}

.govuk-\!-text-align-centre {
  text-align: center !important;
}

.govuk-\!-text-align-right {
  text-align: right !important;
}

/*# sourceMappingURL=_text-align.scss.map */
.govuk-\!-font-size-80 {
  font-size: 53px !important;
  font-size: 3.3125rem !important;
  line-height: 1.0377358491 !important;
}
@media (min-width: 40.0625em) {
  .govuk-\!-font-size-80 {
    font-size: 80px !important;
    font-size: 5rem !important;
    line-height: 1 !important;
  }
}
@media print {
  .govuk-\!-font-size-80 {
    font-size: 53pt !important;
    line-height: 1.1 !important;
  }
}

.govuk-\!-font-size-48 {
  font-size: 32px !important;
  font-size: 2rem !important;
  line-height: 1.09375 !important;
}
@media (min-width: 40.0625em) {
  .govuk-\!-font-size-48 {
    font-size: 48px !important;
    font-size: 3rem !important;
    line-height: 1.0416666667 !important;
  }
}
@media print {
  .govuk-\!-font-size-48 {
    font-size: 32pt !important;
    line-height: 1.15 !important;
  }
}

.govuk-\!-font-size-36 {
  font-size: 24px !important;
  font-size: 1.5rem !important;
  line-height: 1.0416666667 !important;
}
@media (min-width: 40.0625em) {
  .govuk-\!-font-size-36 {
    font-size: 36px !important;
    font-size: 2.25rem !important;
    line-height: 1.1111111111 !important;
  }
}
@media print {
  .govuk-\!-font-size-36 {
    font-size: 24pt !important;
    line-height: 1.05 !important;
  }
}

.govuk-\!-font-size-27 {
  font-size: 18px !important;
  font-size: 1.125rem !important;
  line-height: 1.1111111111 !important;
}
@media (min-width: 40.0625em) {
  .govuk-\!-font-size-27 {
    font-size: 27px !important;
    font-size: 1.6875rem !important;
    line-height: 1.1111111111 !important;
  }
}
@media print {
  .govuk-\!-font-size-27 {
    font-size: 18pt !important;
    line-height: 1.15 !important;
  }
}

.govuk-\!-font-size-24 {
  font-size: 18px !important;
  font-size: 1.125rem !important;
  line-height: 1.1111111111 !important;
}
@media (min-width: 40.0625em) {
  .govuk-\!-font-size-24 {
    font-size: 24px !important;
    font-size: 1.5rem !important;
    line-height: 1.25 !important;
  }
}
@media print {
  .govuk-\!-font-size-24 {
    font-size: 18pt !important;
    line-height: 1.15 !important;
  }
}

.govuk-\!-font-size-19 {
  font-size: 16px !important;
  font-size: 1rem !important;
  line-height: 1.25 !important;
}
@media (min-width: 40.0625em) {
  .govuk-\!-font-size-19 {
    font-size: 19px !important;
    font-size: 1.1875rem !important;
    line-height: 1.3157894737 !important;
  }
}
@media print {
  .govuk-\!-font-size-19 {
    font-size: 14pt !important;
    line-height: 1.15 !important;
  }
}

.govuk-\!-font-size-16 {
  font-size: 14px !important;
  font-size: 0.875rem !important;
  line-height: 1.1428571429 !important;
}
@media (min-width: 40.0625em) {
  .govuk-\!-font-size-16 {
    font-size: 16px !important;
    font-size: 1rem !important;
    line-height: 1.25 !important;
  }
}
@media print {
  .govuk-\!-font-size-16 {
    font-size: 14pt !important;
    line-height: 1.2 !important;
  }
}

.govuk-\!-font-size-14 {
  font-size: 12px !important;
  font-size: 0.75rem !important;
  line-height: 1.25 !important;
}
@media (min-width: 40.0625em) {
  .govuk-\!-font-size-14 {
    font-size: 14px !important;
    font-size: 0.875rem !important;
    line-height: 1.4285714286 !important;
  }
}
@media print {
  .govuk-\!-font-size-14 {
    font-size: 12pt !important;
    line-height: 1.2 !important;
  }
}

.govuk-\!-font-weight-regular {
  font-weight: 400 !important;
}

.govuk-\!-font-weight-bold {
  font-weight: 700 !important;
}

/*# sourceMappingURL=_typography.scss.map */
.govuk-\!-width-full {
  width: 100% !important;
}

.govuk-\!-width-three-quarters {
  width: 100% !important;
}
@media (min-width: 40.0625em) {
  .govuk-\!-width-three-quarters {
    width: 75% !important;
  }
}

.govuk-\!-width-two-thirds {
  width: 100% !important;
}
@media (min-width: 40.0625em) {
  .govuk-\!-width-two-thirds {
    width: 66.66% !important;
  }
}

.govuk-\!-width-one-half {
  width: 100% !important;
}
@media (min-width: 40.0625em) {
  .govuk-\!-width-one-half {
    width: 50% !important;
  }
}

.govuk-\!-width-one-third {
  width: 100% !important;
}
@media (min-width: 40.0625em) {
  .govuk-\!-width-one-third {
    width: 33.33% !important;
  }
}

.govuk-\!-width-one-quarter {
  width: 100% !important;
}
@media (min-width: 40.0625em) {
  .govuk-\!-width-one-quarter {
    width: 25% !important;
  }
}

/*# sourceMappingURL=_width.scss.map */
/*# sourceMappingURL=_all.scss.map */
/*# sourceMappingURL=all.scss.map */
.header-image {
  flex: none;
  padding-right: 10px;
  padding-bottom: 7px;
}

.dashboard-title {
  text-align: center;
  flex: 1 1;
  padding-right: 10px;
}

.protective-marking {
  margin-bottom: 15px;
  flex: none;
}

#protective-marking {
  display: none;
}

@media (min-width: 49.9375em) {
  #protective-marking {
    display: unset;
  }
}
body {
  -webkit-font-smoothing: antialiased;
  -moz-ononesx-font-smoothing: grayscale;
}
body .govuk-header {
  border-color: #1d70b8;
}

pre,
code {
  font-family: Menlo, Monaco, Consolas, "Courier New", monospace;
  font-size: 10pt;
}

dl {
  display: flex;
  flex-wrap: wrap;
}

dl > * {
  margin-bottom: 1rem;
}

dl dt {
  font-size: smaller !important;
  display: inline-flex;
  flex: 1 2 30%;
  justify-content: flex-end;
  align-self: flex-start;
}

dl dt > * {
  font-size: smaller !important;
}

dl dd {
  font-size: smaller;
  display: inline-flex;
  flex: 1 4 50%;
  max-width: 50%;
  margin-left: 1rem;
}

dl dd > * {
  font-size: smaller;
}

button {
  overflow: visible;
  width: auto;
  padding: 0;
  border: 0;
  margin: 0;
  appearance: none;
  background: transparent;
  color: inherit;
  font: inherit;
  -webkit-font-smoothing: inherit;
  -moz-osx-font-smoothing: inherit;
  line-height: normal;
}

button::-moz-focus-inner {
  padding: 0;
  border: 0;
}

svg.back-to-top {
  display: inline-block;
  width: 0.8em;
  height: 1em;
  margin-top: -5px;
  margin-right: 10px;
  vertical-align: middle;
}

.mobile-menu-button {
  width: max-content !important;
  color: #fff !important;
  background-color: rgba(0, 0, 0, 0);
  border: 2px solid white !important;
  box-shadow: unset !important;
  padding: 0.3rem 0.5rem !important;
  padding-top: 5px;
  padding-right: 8px;
  padding-bottom: 4px;
  padding-left: 8px;
  margin: 0;
  margin-bottom: 16px;
  margin-left: 10px;
}

@media only screen and (min-width: 992px) {
  .mobile-menu-button {
    display: none !important;
    visibility: hidden !important;
  }
}
#mobile-navigation {
  display: none;
  position: sticky;
}

a:focus,
button:focus,
input[type=submit]:focus,
input[type=reset]:focus {
  background-color: #fd0 !important;
  outline: #1d70b8 solid 2px !important;
  border-bottom-color: transparent !important;
  box-shadow: unset !important;
  text-decoration: none !important;
}

.dashboard-container {
  display: flex;
  flex-direction: row;
}

.main {
  display: flex;
  flex-direction: column;
}

.moj-side-navigation {
  font-family: Arial, sans-serif;
  -webkit-font-smoothing: antialiased;
  -moz-osx-font-smoothing: grayscale;
  font-weight: 400;
  font-size: 16px;
  font-size: 1rem;
  line-height: 1.25;
}

@media print {
  .moj-side-navigation {
    font-family: sans-serif;
  }
}
@media (min-width: 49.9375em) {
  .moj-side-navigation {
    font-size: 19px;
    font-size: 1.1875rem;
    line-height: 1.3157894737;
  }
}
@media print {
  .moj-side-navigation {
    font-size: 14pt;
    line-height: 1.15;
  }
}
@media (min-width: 49.9375em) {
  .moj-side-navigation {
    font-family: Arial, sans-serif;
    -webkit-font-smoothing: antialiased;
    -moz-osx-font-smoothing: grayscale;
    font-weight: 400;
    font-size: 14px;
    font-size: 0.875rem;
    line-height: 1.1428571429;
  }
}
@media print and (min-width: 49.9375em) {
  .moj-side-navigation {
    font-family: sans-serif;
  }
}
@media (min-width: 49.9375em) and (min-width: 49.9375em) {
  .moj-side-navigation {
    font-size: 16px;
    font-size: 1rem;
    line-height: 1.25;
  }
}
@media print and (min-width: 49.9375em) {
  .moj-side-navigation {
    font-size: 14pt;
    line-height: 1.2;
  }
}
@media (min-width: 49.9375em) {
  .moj-side-navigation__list {
    margin-bottom: 20px;
  }
}
.moj-side-navigation__item a,
.moj-side-navigation__item a:link,
.moj-side-navigation__item a:visited {
  display: block;
  background-color: inherit;
  color: #1d70b8;
  text-decoration: none;
}

@media (max-width: 49.9275em) {
  .moj-side-navigation__item a,
.moj-side-navigation__item a:link,
.moj-side-navigation__item a:visited {
    padding: 15px;
    padding-bottom: 11px;
    border-left: 4px solid transparent;
    background-color: inherit;
  }
}
@media (min-width: 49.9375em) {
  .moj-side-navigation__item a,
.moj-side-navigation__item a:link,
.moj-side-navigation__item a:visited {
    padding: 10px;
    border-left: 4px solid transparent;
  }
}
.moj-side-navigation__item a:hover {
  border-color: #5694ca;
}

.moj-side-navigation__item a:focus {
  position: relative;
  border-color: #0b0c0c;
  border-left-color: transparent;
  background-color: #fd0;
  box-shadow: 0 -2px #fd0, 0 4px #0b0c0c;
  color: #0b0c0c;
}

.moj-side-navigation__item--active a:link,
.moj-side-navigation__item--active a:visited {
  border-color: #1d70b8;
  background-color: #f3f2f1;
  color: #1d70b8;
  font-family: Arial, sans-serif;
  -webkit-font-smoothing: antialiased;
  -moz-osx-font-smoothing: grayscale;
  font-weight: 700;
  font-size: 16px;
  font-size: 1rem;
  line-height: 1.25;
}

@media print {
  .moj-side-navigation__item--active a:link,
.moj-side-navigation__item--active a:visited {
    font-family: sans-serif;
  }
}
@media (min-width: 49.9375em) {
  .moj-side-navigation__item--active a:link,
.moj-side-navigation__item--active a:visited {
    font-size: 19px;
    font-size: 1.1875rem;
    line-height: 1.3157894737;
  }
}
@media print {
  .moj-side-navigation__item--active a:link,
.moj-side-navigation__item--active a:visited {
    font-size: 14pt;
    line-height: 1.15;
  }
}
@media (min-width: 49.9375em) {
  .moj-side-navigation__item--active a:link,
.moj-side-navigation__item--active a:visited {
    font-family: Arial, sans-serif;
    -webkit-font-smoothing: antialiased;
    -moz-osx-font-smoothing: grayscale;
    font-weight: 700;
    font-size: 14px;
    font-size: 0.875rem;
    line-height: 1.1428571429;
  }
}
@media print and (min-width: 49.9375em) {
  .moj-side-navigation__item--active a:link,
.moj-side-navigation__item--active a:visited {
    font-family: sans-serif;
  }
}
@media (min-width: 49.9375em) and (min-width: 49.9375em) {
  .moj-side-navigation__item--active a:link,
.moj-side-navigation__item--active a:visited {
    font-size: 16px;
    font-size: 1rem;
    line-height: 1.25;
  }
}
@media print and (min-width: 49.9375em) {
  .moj-side-navigation__item--active a:link,
.moj-side-navigation__item--active a:visited {
    font-size: 14pt;
    line-height: 1.2;
  }
}
.moj-side-navigation__item--active a:focus {
  border-color: #0b0c0c;
  border-left-color: transparent;
  background-color: #fd0;
  box-shadow: 0 -2px #1d70b8, 0 4px #1d70b8;
  color: #0b0c0c;
}

thead.govuk-table__head th {
  position: sticky;
  background: white;
  top: 0;
}

thead.govuk-table__head-short th {
  top: 0;
}

.js-enabled .govuk-tabs__panel {
  padding-top: 0;
}

.js-enabled .govuk-tabs__panel .govuk-table__header {
  padding-top: 20px;
}

.tooltip {
  width: 150px;
  padding: 8px 10px;
  font-family: Arial, sans-serif;
  -webkit-font-smoothing: antialiased;
  -moz-osx-font-smoothing: grayscale;
  font-weight: 400;
  font-size: 14px;
  font-size: 0.875rem;
  line-height: 1.1428571429;
  z-index: 999999999;
  font-weight: normal;
  line-height: 1.3rem;
}

@media print {
  .tooltip {
    font-family: sans-serif;
  }
}
@media (min-width: 49.9375em) {
  .tooltip {
    font-size: 16px;
    font-size: 1rem;
    line-height: 1.25;
  }
}
@media print {
  .tooltip {
    font-size: 14pt;
    line-height: 1.2;
  }
}
.sticky-menu {
  position: inherit;
  top: 20px;
  margin-bottom: 30px;
}

@media (min-width: 990px) {
  .sticky-menu {
    position: -webkit-sticky;
    position: sticky;
    top: 20px;
  }
}
.filter .govuk-accordion__controls {
  display: none;
}

.govuk-main-wrapper {
  padding-top: 15px !important;
}

.fullscreen-link a:link,
.fullscreen-link a:visited,
.fullscreen-link a:hover,
.fullscreen-link a:active {
  color: #fff;
}

.govuk-grid-column-menu {
  width: 14%;
  float: left;
  position: -webkit-sticky;
  position: sticky;
  top: 4px;
}

.govuk-grid-column-dashboard {
  width: 86%;
  float: left;
}

.cases .govuk-tabs__list-item {
  background-color: #f8f8f8;
  border: 0 solid #fff;
}

.cases .govuk-tabs__list-item .govuk-tabs__tab:link {
  color: #1d70b8 !important;
  text-decoration: none;
}

.cases .govuk-tabs__list-item .govuk-tabs__tab:visited {
  color: #1d70b8 !important;
  text-decoration: none;
}

.cases .govuk-tabs__panel {
  border: 0 solid #fff;
}

.cases .govuk-tabs__list {
  border-bottom: 0 solid #fff;
}

.js-enabled .govuk-tabs__list-item--selected {
  position: relative;
  margin-top: -5px;
  margin-bottom: -1px;
  padding-top: 14px;
  padding-right: 15px;
  padding-bottom: 20px;
  padding-left: 15px;
}

.js-enabled .govuk-tabs__list-item--selected .govuk-tabs__tab {
  text-decoration: none;
  font-weight: bold;
  padding-bottom: 2px;
  border-bottom: 4px solid #1e70b8;
}

.js-enabled .govuk-tabs__list-item {
  position: relative;
  margin-top: -5px;
  margin-bottom: -1px;
  padding-top: 14px;
  padding-right: 15px;
  padding-bottom: 20px;
  padding-left: 15px;
}

.tooltip {
  position: relative;
  display: inline-block;
  text-decoration: none;
}

.tooltip .tooltiptext {
  visibility: hidden;
  width: 120px;
  background-color: black;
  margin-left: 5px;
  color: #fff;
  text-align: left;
  padding-top: 5px;
  padding-right: 5px;
  padding-bottom: 5px;
  padding-left: 10px;
  position: absolute;
  z-index: 1;
}

.tooltip .tooltiptext {
  width: 120px;
  top: 100%;
  left: 50%;
  margin-left: -60px;
}

.tooltip:hover .tooltiptext {
  visibility: visible;
}

@media only screen and (max-width: 600px) {
  html,
body {
    position: relative;
  }
  .govuk-grid-column-dashboard {
    width: 100%;
  }
  .govuk-grid-column-one-half {
    width: 100%;
  }
  .govuk-grid-column-menu {
    display: none;
  }
  .mobile-menu-button {
    display: inline-block;
  }
  .govuk-header__logo {
    padding-right: 0;
  }
  .moj-search--inline {
    padding: 0 !important;
  }
}
.moj-search__button {
  margin-left: 0 !important;
  background-color: #000 !important;
}

.moj-primary-navigation__search {
  display: block;
  vertical-align: middle;
}

.govuk-select {
  background-color: #f8f8f8;
}

.govuk-tag--grey {
  background: #ebe9e7;
}

.govuk-tag--yellow {
  color: #206bc9;
  background: #d7e9ff;
}

.govuk-main-wrapper {
  padding-top: 0 !important;
}

main {
  font-family: Arial, sans-serif;
}

.mini-card-empty {
  background-color: white !important;
  border: 0px !important;
}

.mini-card,
.card-container > * {
  padding: 10px;
  display: grid;
  grid-auto-flow: row;
  grid-template-rows: auto;
  grid-row-gap: 0.5rem;
}

.mini-card > dl {
  display: flex;
  flex-direction: column;
  margin-block-start: auto;
  margin-block-end: auto;
  gap: 10px;
}

.mini-card .govuk-section-break,
.card-container > * .govuk-section-break {
  align-self: end;
}

.tooltip {
  padding: 0 !important;
  width: max-content !important;
  z-index: unset !important;
}

.tooltiptext {
  z-index: 999999999 !important;
  background: rgba(0, 0, 0, 0.9);
}

@media only print {
  .govuk-grid-column-menu {
    display: none;
  }
}
.main {
  display: flex;
  flex-direction: column;
  flex: 1 1 100%;
  min-height: 50vh;
}

.govuk-header__logo {
  width: unset;
}

.mobile-menu-button {
  display: inline-block;
}

.govuk-header__link--homepage {
  margin-right: 0;
}

@media (min-width: 25em) {
  .govuk-header__link--homepage {
    margin-right: 70px;
  }
}
.gray-text,
.mini-card > details.govuk-details .govuk-details__text,
.card-container > * > details.govuk-details .govuk-details__text {
  color: #636a6d !important;
}

.tooltiptext {
  background: rgba(0, 0, 0, 0.85) !important;
  border-radius: 3px;
  transition: opacity 0.3s ease-out;
  font-family: Arial, sans-serif;
  -webkit-font-smoothing: antialiased;
  -moz-osx-font-smoothing: grayscale;
  font-weight: 400;
  font-size: 14px;
  font-size: 0.875rem;
  line-height: 1.1428571429;
  padding: 0.5rem 1rem !important;
  width: 150px !important;
}

@media print {
  .tooltiptext {
    font-family: sans-serif;
  }
}
@media (min-width: 49.9375em) {
  .tooltiptext {
    font-size: 16px;
    font-size: 1rem;
    line-height: 1.25;
  }
}
@media print {
  .tooltiptext {
    font-size: 14pt;
    line-height: 1.2;
  }
}
#mobile-navigation {
  width: 100%;
}

.mini-card > details.govuk-details,
.card-container > * > details.govuk-details {
  margin-bottom: 0rem !important;
}

.mini-card > details.govuk-details > .govuk-details__summary,
.card-container > * > details.govuk-details > .govuk-details__summary {
  padding-left: 16px;
}

.mini-card > details.govuk-details > .govuk-details__summary > .govuk-details__summary-text,
.card-container > * > details.govuk-details > .govuk-details__summary > .govuk-details__summary-text {
  text-decoration: none;
  padding-right: 5px;
}

.mini-card > details.govuk-details > .govuk-details__summary:before,
.card-container > * > details.govuk-details > .govuk-details__summary:before {
  top: 5px;
  border-width: 5px 0 5px 9px;
}

.mini-card > details.govuk-details[open] .govuk-details__summary:before,
.card-container > * > details.govuk-details[open] .govuk-details__summary:before {
  top: 2px;
  border-width: 9px 5px 0 5px;
}

.mini-card > details.govuk-details .govuk-details__text,
.card-container > * > details.govuk-details .govuk-details__text {
  padding: 0.5rem;
}

.card-container {
  display: flex;
  flex-wrap: wrap;
  padding: unset;
  gap: 0.5rem;
}

.card-container,
.card-container ul:not(.govuk-list--bullet) {
  list-style: none;
}

.card-container > * {
  flex-grow: 4;
  flex-shrink: 1;
  flex-basis: 20%;
  min-width: 250px;
}

.mini-card hr,
.card-container > * hr {
  margin-left: -1.3rem;
  margin-right: -1.3rem;
}

.moj-side-navigation {
  font-family: Arial, sans-serif;
  -webkit-font-smoothing: antialiased;
  -moz-osx-font-smoothing: grayscale;
  font-weight: 400;
  font-size: 16px;
  font-size: 1rem;
  line-height: 1.25;
}

@media print {
  .moj-side-navigation {
    font-family: sans-serif;
  }
}
@media (min-width: 49.9375em) {
  .moj-side-navigation {
    font-size: 19px;
    font-size: 1.1875rem;
    line-height: 1.3157894737;
  }
}
@media print {
  .moj-side-navigation {
    font-size: 14pt;
    line-height: 1.15;
  }
}
@media (min-width: 49.9375em) {
  .moj-side-navigation {
    font-family: Arial, sans-serif;
    -webkit-font-smoothing: antialiased;
    -moz-osx-font-smoothing: grayscale;
    font-weight: 400;
    font-size: 14px;
    font-size: 0.875rem;
    line-height: 1.1428571429;
  }
}
@media print and (min-width: 49.9375em) {
  .moj-side-navigation {
    font-family: sans-serif;
  }
}
@media (min-width: 49.9375em) and (min-width: 49.9375em) {
  .moj-side-navigation {
    font-size: 16px;
    font-size: 1rem;
    line-height: 1.25;
  }
}
@media print and (min-width: 49.9375em) {
  .moj-side-navigation {
    font-size: 14pt;
    line-height: 1.2;
  }
}
@media (min-width: 49.9375em) {
  .moj-side-navigation-mobile {
    display: none;
  }
}
.moj-side-navigation__list {
  list-style-type: none;
  padding: 0;
  margin: 0;
}

@media (min-width: 49.9375em) {
  .moj-side-navigation__list {
    margin-bottom: 20px;
  }
}
.moj-side-navigation__item a,
.moj-side-navigation__item a:link,
.moj-side-navigation__item a:visited {
  display: block;
  background-color: inherit;
  color: #1d70b8;
  text-decoration: none;
}

@media (max-width: 49.9275em) {
  .moj-side-navigation__item a,
.moj-side-navigation__item a:link,
.moj-side-navigation__item a:visited {
    padding: 15px;
    padding-bottom: 11px;
    border-left: 4px solid transparent;
    background-color: inherit;
  }
}
@media (min-width: 49.9375em) {
  .moj-side-navigation__item a,
.moj-side-navigation__item a:link,
.moj-side-navigation__item a:visited {
    padding: 10px;
    border-left: 4px solid transparent;
  }
}
.moj-side-navigation__item a:hover {
  border-color: #5694ca;
}

.moj-side-navigation__item a:focus {
  position: relative;
  border-color: #0b0c0c;
  border-left-color: transparent;
  background-color: #fd0;
  box-shadow: 0 -2px #fd0, 0 4px #0b0c0c;
  color: #0b0c0c;
}

.moj-side-navigation__item--active a:link,
.moj-side-navigation__item--active a:visited {
  border-color: #1d70b8;
  background-color: #f3f2f1;
  color: #1d70b8;
  font-weight: bold;
}

.moj-side-navigation__item--active a:focus {
  border-color: #0b0c0c;
  border-left-color: transparent;
  background-color: #fd0;
  box-shadow: 0 -2px #1d70b8, 0 4px #1d70b8;
  color: #0b0c0c;
}

.change-log-banner {
  display: grid;
  padding: 0.7rem;
  justify-content: center;
  background-color: #f4fa4d;
  margin-bottom: 1px;
}

.change-log-banner,
.change-log-banner * {
  color: black;
  line-height: 25px;
}

#nav-section {
  width: 100%;
  border-bottom: 1px solid #b1b4b6;
}

@media (max-width: 991px) {
  .dashboard-container > .moj-side-navigation {
    display: none;
  }
}
/* This prevents the size of the menu changing when a link becomes active and therefore bold */
.dashboard-container .moj-side-navigation {
  width: 20%;
  padding-inline-end: 2%;
}

.jitter-desktop-only {
  display: none;
}

@media (min-width: 62em) {
  .jitter-desktop-only {
    display: unset;
  }
  .govuk-visually-hidden-desktop-only {
    position: absolute !important;
    width: 1px !important;
    height: 1px !important;
    margin: 0 !important;
    padding: 0 !important;
    overflow: hidden !important;
    clip: rect(0 0 0 0) !important;
    -webkit-clip-path: inset(50%) !important;
    clip-path: inset(50%) !important;
    border: 0 !important;
    white-space: nowrap !important;
  }
  .govuk-visually-hidden-desktop-only-focusable {
    position: absolute !important;
    width: 1px !important;
    height: 1px !important;
    margin: 0 !important;
    overflow: hidden !important;
    clip: rect(0 0 0 0) !important;
    -webkit-clip-path: inset(50%) !important;
    clip-path: inset(50%) !important;
    white-space: nowrap !important;
  }
  .govuk-visually-hidden-desktop-only-focusable:active,
.govuk-visually-hidden-desktop-only-focusable:focus {
    position: static !important;
    width: auto !important;
    height: auto !important;
    margin: inherit !important;
    overflow: visible !important;
    clip: auto !important;
    -webkit-clip-path: none !important;
    clip-path: none !important;
    white-space: inherit !important;
  }
}
mark.positive {
  background-color: #85994b;
  color: black;
  padding: 2px 5px;
  font-weight: bold;
}

mark.negative {
  background-color: #f499be;
  color: black;
  padding: 2px 5px;
  font-weight: bold;
}

mark.expenditure {
  background-color: #b58840;
  color: black;
  padding: 2px 5px;
  font-weight: bold;
}

#metrics-data-table td:nth-child(n+3), #metrics-data-table th:nth-child(n+3) {
  text-align: right;
}

.dash-graph path.legendundefined {
  d: path("M 8 8 H -8 V -8 H 8 Z");
}

.moj-side-navigation__list--nested {
  padding-left: 20px;
}

.moj-side-navigation {
  width: 20%;
}

.moj-side-navigation__item > a:after {
  content: "";
  height: 8px;
  position: relative;
  margin: 0 10px 0 2px;
  vertical-align: text-top;
  width: 8px;
  float: right;
}

.moj-side-navigation__item--expanded > a:after {
  transform: translateY(-35%) rotate(45deg) scale(1);
  transform: translateY(1px) rotate(225deg) scale(1);
  border-bottom: 2px solid #1d70b8;
  border-right: 2px solid #1d70b8;
}

.moj-side-navigation__item--collapsed > a:after {
  transform: translateY(-35%) rotate(225deg) scale(1);
  transform: translateY(1px) rotate(45deg) scale(1);
  border-bottom: 2px solid #1d70b8;
  border-right: 2px solid #1d70b8;
}

.govuk-header__logo,
.govuk-header__content {
  box-sizing: border-box;
  display: flex;
  flex-flow: row nowrap;
  justify-content: space-between;
  align-items: center;
}

@media (min-width: 50em) {
  .govuk-header__content {
    width: 100%;
    padding-left: 15px;
    float: left;
  }
}
.loading-div {
  font-weight: bold;
  font-size: 30px;
}

.grid-container-css {
  display: grid;
  grid-template-columns: repeat(3, 1fr);
  grid-auto-rows: 100px;
  padding: 0px 50px 50px 50px;
  gap: 20px 100px;
  align-items: stretch;
}

.grid-item-css {
  background-color: #1d70b8;
  color: white;
  padding: 50px;
  text-align: center;
  display: flex;
  justify-content: center;
  align-items: center;
  flex-direction: column;
  box-sizing: border-box;
  overflow: hidden;
  font-weight: bold;
}

@media (max-width: 600px) {
  .grid-container-css {
    grid-template-columns: 1fr;
  }
}
.combined-table-width {
  width: max-content;
  margin-top: 50px;
}

.comparison-button-background {
  background-color: #dbdad9;
}

.comparison-button-background:hover {
  background-color: #c9c8c7;
}

.notification-banner-under-filter-panel {
  padding-left: 0px;
  margin: 0px;
}

.govuk-button-group.button-group-margin {
  margin-bottom: -10px;
}

.container-class::after {
  content: "";
  display: table;
  clear: both;
}

.horizontal-button-group {
  float: right;
  display: flex;
  flex-wrap: nowrap;
  flex-direction: row;
  padding-top: 10px;
}

.padding-bottom-10px {
  padding-bottom: 10px;
}

/*Max-width set to 61.99em to fit with min-width of 62em for jitters changing*/
@media (max-width: 61.99em) {
  .hide-checkboxes-on-mobile {
    display: none;
  }
}
.visually-hidden {
  position: absolute;
  left: -9999px;
  width: 1px;
  height: 1px;
  overflow: hidden;
}

.default-cursor-graph .draglayer.cursor-crosshair {
  cursor: default !important;
}

.non-interactive-legend-cursor .legend text,
.non-interactive-legend-cursor .legend .traces .legendtoggle {
  cursor: default !important;
}

.pl-\[26px\], .changed-from-arrow_up_red, .changed-from-arrow_up_green, .changed-from-arrow_down_red, .changed-from-arrow_down_green {
  padding-left: 26px !important;
}

.changed-from-arrow_down_green {
  background-image: url("data:image/svg+xml,%3Csvg xmlns='http://www.w3.org/2000/svg' width='15' height='14' fill='none'%3E%3Cpath stroke='%23005A30' stroke-width='2' d='M8 0v12M7.793 12.657l6.364-6.364M7.657 12.071 1.293 5.707'/%3E%3Cpath stroke='%23005A30' stroke-width='1.02' d='m8.379 13.483-2.121-2.122'/%3E%3C/svg%3E") !important;
}

.changed-from-arrow_down_red {
  background-image: url("data:image/svg+xml,%3Csvg xmlns='http://www.w3.org/2000/svg' width='15' height='14' fill='none'%3E%3Cpath stroke='%23AA2A16' stroke-width='2' d='M8 0v12M7.793 12.657l6.364-6.364M7.657 12.071 1.293 5.707'/%3E%3Cpath stroke='%23AA2A16' stroke-width='1.02' d='m8.379 13.483-2.121-2.122'/%3E%3C/svg%3E") !important;
}

.changed-from-arrow_up_green {
  background-image: url("data:image/svg+xml,<svg xmlns='http://www.w3.org/2000/svg' width='15' height='15' fill='none'><path stroke='%23005A30' stroke-width='2' d='M6.864 14.364v-12M7.071 1.707.707 8.071M7.207 2.293l6.364 6.364'/><path stroke='%23005A30' stroke-width='1.02' d='m6.485.881 2.121 2.122'/></svg>") !important;
}

.changed-from-arrow_up_red {
  background-image: url("data:image/svg+xml,%3Csvg xmlns='http://www.w3.org/2000/svg' width='15' height='15' fill='none'%3E%3Cpath stroke='%23AA2A16' stroke-width='2' d='M6.864 14.364v-12M7.071 1.707.707 8.071M7.207 2.293l6.364 6.364'/%3E%3Cpath stroke='%23AA2A16' stroke-width='1.02' d='m6.485.881 2.121 2.122'/%3E%3C/svg%3E") !important;
}

.changed-from-box-formatting {
  margin-top: 2px !important;
  background-repeat: no-repeat !important;
  background-position: 6px !important;
}

.changed-from-number-formatting {
  font-weight: 700 !important;
  color: inherit !important;
}

.text-color-inherit {
  color: inherit !important;
}

.table-header-cell-top-padding th {
  padding-top: 10px !important;
}

.download-icon {
  width: 16px;
  height: 16px;
  background-image: url('data:image/svg+xml;utf8,<svg xmlns="http://www.w3.org/2000/svg" width="16" height="16" fill="none" aria-hidden="true"><path fill="%23ffffff" d="M7 0h2v11H7zM0 16v-2h16v2z"></path><path fill="%23ffffff" d="M8.414 12.11 7 10.698 11.696 6l1.414 1.414z"></path><path fill="%23ffffff" d="M9 11H7V1h2z"></path><path fill="%23ffffff" d="M3 7.414 4.414 6l4.696 4.696-1.414 1.414z"></path><path fill="%23ffffff" d="M7.168 11.574 7.742 11l.889.889-.574.574z"></path></svg>');
  background-size: contain;
  background-repeat: no-repeat;
  display: inline-block;
  vertical-align: middle;
}

.three_column_grid_layout {
  display: grid;
  grid-template-columns: repeat(3, 1fr);
  gap: 20px 7%;
}

@media (max-width: 600px) {
  .three_column_grid_layout {
    grid-template-columns: 1fr;
  }
}
.two_column_grid_layout {
  display: grid;
  grid-template-columns: repeat(2, 1fr);
  gap: 20px 7%;
}

@media (max-width: 600px) {
  .two_column_grid_layout {
    grid-template-columns: 1fr;
  }
}
.two_column_grid_layout_second_width_twice_first {
  display: grid;
  grid-template-columns: 1fr 2fr;
  gap: 20px 7%;
}

@media (max-width: 600px) {
  .two_column_grid_layout_second_width_twice_first {
    grid-template-columns: 1fr;
  }
}
.two_column_grid_layout_first_width_twice_second {
  display: grid;
  grid-template-columns: 2fr 1fr;
  gap: 20px 7%;
}

@media (max-width: 750px) {
  .two_column_grid_layout_first_width_twice_second {
    grid-template-columns: 1fr;
  }
}
.box_container_layout {
  background-color: #f3f2f1;
  padding: 20px 20px 10px 20px;
  margin-bottom: 20px;
  display: flex;
  flex-direction: column;
  align-items: stretch;
}

.bg_white {
  background-color: #ffffff !important; /* Override default color */
}

.govuk-table__caption--m.margin-if-subtitle {
  margin-bottom: 0 !important;
}

.govuk-table__caption.custom-subtitle {
  color: #505a5f;
  font-weight: normal !important;
  padding: 0;
}

.text-no-transform {
  text-transform: none !important;
}

.fix-width {
  width: 197px;
  display: inline-block;
}

.grid-labels {
  display: flex;
  align-items: center;
  width: calc(100% - 100px);
  height: 100px;
  padding: 0px 10px;
}

.grid-icons-img {
  height: 64px;
  width: 64px;
  padding: 18px;
}

.grid-item-home-page {
  background-color: #1d70b8;
  color: white;
  text-align: left;
  display: flex;
  box-sizing: border-box;
  overflow: hidden;
  font-weight: bold;
  height: 100px;
}

.grid-container-home-page {
  display: grid;
  grid-template-columns: repeat(2, 1fr);
  grid-auto-rows: 100px;
  padding: 20px 0px;
  gap: 20px 100px;
  align-items: stretch;
}

@media (max-width: 600px) {
  .grid-container-home-page {
    grid-template-columns: 1fr;
  }
}
.context-card-grid-item {
  background-color: #f3f2f1;
  padding: 20px 20px 10px 20px;
  margin-bottom: 20px;
  text-align: center;
  display: flex;
  align-items: center;
  flex-direction: column;
  box-sizing: border-box;
  overflow: hidden;
}

.homepage-card-grid-item {
  background-color: #e9e8e7;
  padding: 10px 20px 10px 20px;
  border: 3px solid #e9e8e7;
  border-radius: 10px;
  margin-bottom: 20px;
  text-align: center;
  text-decoration: none;
  font-weight: bold;
  display: flex;
  align-items: center;
  flex-direction: column;
  box-sizing: border-box;
  overflow: hidden;
  transition: all 0.3s ease; /* Smooth transition for hover effect */
  transform-origin: center; /* Ensures scaling is centered */
  position: relative; /* Makes it independent of surrounding elements */
  contain: layout paint; /* Prevents changes from affecting layout */
}

.homepage-card-grid-item:hover {
  border: 3px solid #ffdd00;
  transform: scale(1.05); /* Slightly enlarge the card on hover */
  z-index: 10; /* Ensures the card is above other elements while scaling */
}

.pyvis-govuk-footer__copyright-logo {
  display: inline-block;
  min-width: 125px;
  padding-top: 112px;
  background-image: url("/assets/images/govuk-crest.svg");
  background-repeat: no-repeat;
  background-position: 50% 0%;
  background-size: 125px 102px;
  text-align: center;
  white-space: nowrap;
}

[aria-sort] button, [aria-sort] button:hover {
  background-color: rgba(0, 0, 0, 0);
  border-width: 0;
  -webkit-box-shadow: 0 0 0 0;
  -moz-box-shadow: 0 0 0 0;
  box-shadow: 0 0 0 0;
  color: #005ea5;
  cursor: pointer;
  font-family: inherit;
  font-size: inherit;
  font-weight: inherit;
  padding: 0 10px 0 0;
  position: relative;
  text-align: inherit;
  font-size: 1em;
  margin: 0;
}

[aria-sort] button:focus {
  background-color: #fd0;
  color: #0b0c0c;
  box-shadow: 0 -2px #fd0, 0 4px #0b0c0c;
  outline: none;
}

[aria-sort]:first-child button {
  right: auto;
}

[aria-sort] button:before {
  content: " ▼";
  position: absolute;
  right: -1px;
  top: 9px;
  font-size: 0.5em;
}

[aria-sort] button:after {
  content: " ▲";
  position: absolute;
  right: -1px;
  top: 1px;
  font-size: 0.5em;
}

[aria-sort=ascending] button:before, [aria-sort=descending] button:before {
  content: none;
}

[aria-sort=ascending] button:after {
  content: " ▲";
  font-size: 0.8em;
  position: absolute;
  right: -5px;
  top: 2px;
}

[aria-sort=descending] button:after {
  content: " ▼";
  font-size: 0.8em;
  position: absolute;
  right: -5px;
  top: 2px;
}

.font-weight-normal-override {
  font-weight: normal !important;
}

.leaflet-interactive:focus {
  outline: none !important;
}

.horizontal-radios {
  display: flex;
  justify-content: space-between;
  width: 100%;
}

/* Each radio item becomes a vertical stack */
.horizontal-radio {
  display: flex;
  flex-direction: column;
  align-items: center;
  flex: 1;
  /* Keep GOV.UK relative positioning so pseudo-elements work */
  position: relative;
  /* Remove the large left indent */
  padding-left: 0 !important;
}

/* Let the GOV.UK pseudo-element circle appear ABOVE the label */
.horizontal-radio .govuk-radios__label {
  margin: 2rem 0 0; /* push label below the radio circle */
  text-align: center;
  max-width: 6rem;
}

/* Move the GOV.UK radio circle into place */
.horizontal-radio .govuk-radios__label::before,
.horizontal-radio .govuk-radios__label::after {
  left: 50% !important;
  transform: translateX(-50%);
}

/* Remove absolute positioning from the input so it doesn’t float somewhere random */
.horizontal-radio .govuk-radios__input {
  position: absolute; /* keep required for GOV.UK JS */
  left: 50%;
  top: 0.3rem;
  transform: translateX(-50%);
}

.horizontal-radios .govuk-radios__item {
  margin-bottom: 0 !important;
  margin-right: 2rem; /* spacing between items */
}

/* Remove margin-right on last item */
.horizontal-radios .govuk-radios__item:last-child {
  margin-right: 0 !important;
}

#feedback-banner-content.highlight {
  border: 3px solid #ffdd00;
}

#glossary-table .highlight {
  border: 3px solid #ffdd00;
  border-radius: 4px;
}

.govuk-table__body tr[id] {
  scroll-margin-top: 3rem;
}

.feedback-container {
  background-color: rgb(244, 248, 251);
  border-top-color: rgb(142, 184, 220);
  border-top-style: solid;
  border-top-width: 0.8px;
  color: rgb(11, 12, 12);
  display: block;
  font-family: "GDS Transport", arial, sans-serif;
  outline-color: rgb(11, 12, 12);
  outline-style: none;
  outline-width: 0px;
  unicode-bidi: isolate;
  margin-right: 50px;
  margin-left: 50px;
  margin-top: 60px;
}

.feedback-content {
  align-items: center;
  color: rgb(11, 12, 12);
  display: flex;
  flex-direction: row;
  align-items: center;
  font-family: "GDS Transport", arial, sans-serif;
  justify-content: space-between;
  padding-bottom: 0px;
  padding-left: 15px;
  padding-right: 15px;
  padding-top: 0px;
  unicode-bidi: isolate;
}

.feedback-list {
  display: flex;
  align-items: center;
  gap: 15px;
  margin: 0;
  padding: 0;
}

.feedback-questions {
  color: rgb(11, 12, 12);
  display: flex;
  align-items: center;
  font-family: "GDS Transport", arial, sans-serif;
  margin-bottom: 0px;
  margin-left: 15px;
  margin-right: 15px;
  margin-top: 0px;
  padding-bottom: 20px;
  padding-left: 0px;
  padding-right: 0px;
  padding-top: 20px;
  text-align: left;
  unicode-bidi: isolate;
}

.feedback-question-answer {
  align-items: center;
  color: rgb(11, 12, 12);
  display: flex;
  font-family: "GDS Transport", arial, sans-serif;
  text-align: left;
  text-size-adjust: 100%;
  unicode-bidi: isolate;
}

.feedback-list-item {
  display: flex; /* allow vertical centering */
  align-items: center; /* fixes button alignment */
  list-style-type: none;
  min-width: 100px;
  margin: 0;
  padding: 0;
  font-family: "GDS Transport", arial, sans-serif;
}

.feedback-button {
  display: inline-flex;
  align-items: center;
  justify-content: center;
  margin-bottom: 0;
  background-color: rgba(0, 0, 0, 0);
  border-bottom-color: rgb(11, 12, 12);
  color: rgb(11, 12, 12) !important;
  border-bottom-left-radius: 0px;
  border-bottom-right-radius: 0px;
  border-bottom-style: solid;
  border-bottom-width: 0.8px;
  border-image-outset: 0;
  border-image-repeat: stretch;
  border-image-slice: 100%;
  border-image-source: none;
  border-image-width: 1;
  border-left-color: rgb(11, 12, 12);
  border-left-style: solid;
  border-left-width: 0.8px;
  border-right-color: rgb(11, 12, 12);
  border-right-style: solid;
  border-right-width: 0.8px;
  border-top-color: rgb(11, 12, 12);
  border-top-left-radius: 0px;
  border-top-right-radius: 0px;
  border-top-style: solid;
  border-top-width: 0.8px;
  width: 100%;
}

.feedback-button:hover {
  background-color: #b1b4b6; /* GDS mid-grey hover */
  color: #0b0c0c; /* keep text black */
  border-color: #0b0c0c;
}